@@ -22,10 +22,13 @@
  *                                                                            *
  *  You should have received a copy of the GNU General Public License         *
  *  along with KSambaPlugin; if not, write to the Free Software                     *
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA  *
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA  *
  *                                                                            *
  ******************************************************************************/
 
+#ifndef KCM_SAMBACONF_SOCKETOPTIONSDLG_UI_H
+#define KCM_SAMBACONF_SOCKETOPTIONSDLG_UI_H
+
 void SocketOptionsDlg::setShare( SambaShare * share )
 {
     assert(share);
@@ -110,3 +113,5 @@ int SocketOptionsDlg::getIntValue( const QString & str, const QString & name )
     
     return 0;
 }
+
+#endif // KCM_SAMBACONF_SOCKETOPTIONSDLG_UI_H
