@@ -14,19 +14,18 @@
  * You should have received a copy of the GNU General Public
  * License along with this library; see the file COPYING.
  * If not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #ifndef _BDICT_H
 #define _BDICT_H
 
-#include <qdict.h>
-#include <qcstring.h> // QByteArray
+#include <q3dict.h>
 #include "bytetape.h"
 #include "bbase.h"
 
 // Some useful typedefs
-typedef QDict<BBase> BBaseHash;
-typedef QDictIterator<BBase> BBaseHashIterator;
+typedef Q3Dict<BBase> BBaseHash;
+typedef Q3DictIterator<BBase> BBaseHashIterator;
 
 // Forward declarations
 class BInt;
