@@ -14,20 +14,18 @@
  * You should have received a copy of the GNU General Public
  * License along with this library; see the file COPYING.
  * If not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #ifndef _BYTETAPE_H
 #define _BYTETAPE_H
 
 #include <ksharedptr.h>
 
-#include <qcstring.h>
-
 class ByteTapeShared : public KShared
 {
     public:
 
-    unsigned int pos;
+    int pos;
 };
 
 /**
@@ -73,7 +71,7 @@ class ByteTape
      * @param i the amount to increment the current position by
      * @return t reference to the object incremented
      */
-    ByteTape & operator += (const unsigned int i);
+    ByteTape & operator += (const int i);
 
     /**
      * Decrements the current position by @p i.  It is the responsibility
@@ -85,7 +83,7 @@ class ByteTape
      * @param i the amount to decrement the current position by
      * @return a reference to the object decremented
      */
-    ByteTape & operator -= (const unsigned int i);
+    ByteTape & operator -= (const int i);
 
     /**
      * Increments the current position by 1.  This is a postfix
@@ -138,7 +136,7 @@ class ByteTape
      * @return the byte at the given index.  0 may be returned on error,
      *         but does not necessarily indicate an error.
      */
-    char operator [] (const unsigned int i);
+    char operator [] (const int i);
 
     /**
      * Returns the byte at the tape's current position.  You can assign
@@ -157,14 +155,14 @@ class ByteTape
      * @return 0 if @p i is out of range, else the address of memory
      *         at that index
      */
-    char *at(const unsigned int i);
+    char *at(const int i);
 
     /**
      * Returns the current position of the tape head.
      *
      * @return the tape head's current position
      */
-    unsigned int pos() const { return m_shared->pos; }
+    int pos() const { return m_shared->pos; }
 
     /**
      * Sets the current position of the tape head to @p pos.  If the
@@ -174,7 +172,7 @@ class ByteTape
      * @param pos the new position of the tape head
      * @return whether the set operation was successful
      */
-    bool setPos(unsigned int pos);
+    bool setPos(int pos);
 
     /**
      * Returns a reference to the QByteArray used to hold all the data.
