@@ -1,7 +1,7 @@
 /*
     chatview.cpp - Chat View
 
-    Copyright (c) 2002-2004 by Olivier Goffart       <ogoffart @ kde.org>
+    Copyright (c) 2002-2004 by Olivier Goffart       <ogoffart@kde.org>
     Copyright (c) 2002-2003 by Martijn Klingens      <klingens@kde.org>
 
     Kopete    (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
@@ -18,41 +18,40 @@
 
 #include "chatview.h"
 
-#include "chatmemberslistwidget.h"
 #include "chatmessagepart.h"
 #include "chattexteditpart.h"
 #include "kopetechatwindow.h"
 #include "kopetechatsession.h"
 #include "kopetemetacontact.h"
 #include "kopetepluginmanager.h"
-#include "kopeteprefs.h"
 #include "kopeteprotocol.h"
 #include "kopeteaccount.h"
 #include "kopeteglobal.h"
 #include "kopetecontactlist.h"
 #include "kopeteviewmanager.h"
+#include "kopetebehaviorsettings.h"
 
 #include <kconfig.h>
 #include <ktabwidget.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kstringhandler.h>
-#include <kwin.h>
-#include <kurldrag.h>
+#include <kwindowsystem.h>
 #include <kglobalsettings.h>
 #include <kgenericfactory.h>
 #include <khtmlview.h>
-#include <ksyntaxhighlighter.h>
-#include <qscrollview.h>
-#include <qtimer.h>
 
-typedef KGenericFactory<ChatWindowPlugin> ChatWindowPluginFactory;
-K_EXPORT_COMPONENT_FACTORY( kopete_chatwindow, ChatWindowPluginFactory( "kopete_chatwindow" )  )
+#include <QTimer>
+#include <QSplitter>
+#include <Q3UriDrag>
 
-ChatWindowPlugin::ChatWindowPlugin(QObject *parent, const char *name, const QStringList &) :
-	Kopete::ViewPlugin( ChatWindowPluginFactory::instance(), parent, name )
+K_PLUGIN_FACTORY( ChatWindowPluginFactory, registerPlugin<ChatWindowPlugin>(); )
+K_EXPORT_PLUGIN( ChatWindowPluginFactory( "kopete_chatwindow" ) )
+
+ChatWindowPlugin::ChatWindowPlugin(QObject *parent, const QVariantList &) :
+	Kopete::ViewPlugin( ChatWindowPluginFactory::componentData(), parent )
 {}
 
 KopeteView* ChatWindowPlugin::createView( Kopete::ChatSession *manager )
@@ -68,42 +67,45 @@ public:
 	bool isActive;
 	bool sendInProgress;
 	bool visibleMembers;
+	QSplitter * splitter;
 };
 
-ChatView::ChatView( Kopete::ChatSession *mgr, ChatWindowPlugin *parent, const char *name )
-	 : KDockMainWindow( 0L, name, 0L ), KopeteView( mgr, parent )
+ChatView::ChatView( Kopete::ChatSession *mgr, ChatWindowPlugin *parent )
+	 : KVBox( 0l ), KopeteView( mgr, parent )
+         , d(new KopeteChatViewPrivate)
 {
-	d = new KopeteChatViewPrivate;
+	int i;
+
 	d->isActive = false;
 	d->visibleMembers = false;
 	d->sendInProgress = false;
 
+	KVBox *vbox=this;
 
 	m_mainWindow = 0L;
-	membersDock = 0L;
-	membersStatus = Smart;
 	m_tabState = Normal;
 
 
 	//FIXME: don't widgets start off hidden anyway?
 	hide();
 
-	//Create the view dock widget (KHTML Part), and set it to no docking (lock it in place)
-	viewDock = createDockWidget(QString::fromLatin1( "viewDock" ), QPixmap(),
-		0L,QString::fromLatin1("viewDock"), QString::fromLatin1(" "));
-	m_messagePart = new ChatMessagePart( mgr, viewDock, "m_messagePart" );
+	d->splitter = new QSplitter( Qt::Vertical, vbox );
 
-	viewDock->setWidget(messagePart()->widget());
-	viewDock->setDockSite(KDockWidget::DockBottom);
-	viewDock->setEnableDocking(KDockWidget::DockNone);
+	//Create the view dock widget (KHTML Part), and set it to no docking (lock it in place)
+	m_messagePart = new ChatMessagePart( mgr , this );
 
 	//Create the bottom dock widget, with the edit area, statusbar and send button
-	editDock = createDockWidget( QString::fromLatin1( "editDock" ), QPixmap(),
-		0L, QString::fromLatin1("editDock"), QString::fromLatin1(" ") );
-	m_editPart = new ChatTextEditPart( mgr, editDock, "kopeterichtexteditpart" );
+	m_editPart = new ChatTextEditPart( mgr, vbox );
+
+	d->splitter->addWidget(m_messagePart->view());
+	d->splitter->addWidget(m_editPart->widget());
+	d->splitter->setChildrenCollapsible( false );
+	QList<int> sizes;
+	sizes << 240 << 40;
+	d->splitter->setSizes( sizes ); 
 
 	// FIXME: is this used these days? it seems totally unnecessary
-	connect( editPart(), SIGNAL( toggleToolbar(bool)), this, SLOT(slotToggleRtfToolbar(bool)) );
+	connect( editPart(), SIGNAL( toolbarToggled(bool)), this, SLOT(slotToggleRtfToolbar(bool)) );
 
 	connect( editPart(), SIGNAL( messageSent( Kopete::Message & ) ),
 	         this, SIGNAL( messageSent( Kopete::Message & ) ) );
@@ -112,29 +114,21 @@ ChatView::ChatView( Kopete::ChatSession *mgr, ChatWindowPlugin *parent, const ch
 	connect( editPart(), SIGNAL( typing(bool) ),
 		 mgr, SLOT( typing(bool) ) );
 
-	//Make the edit area dockable for now
-	editDock->setWidget( editPart()->widget() );
-	editDock->setDockSite( KDockWidget::DockNone );
-	editDock->setEnableDocking(KDockWidget::DockBottom);
-
 	//Set the view as the main widget
-	setMainDockWidget( viewDock );
-	setView(viewDock);
+//	setView(viewDock);
 
 	//It is possible to drag and drop on this widget.
 	// I had to disable the acceptDrop in the khtml widget to be able to intercept theses events.
 	setAcceptDrops(true);
-	viewDock->setAcceptDrops(false);
-
-	m_remoteTypingMap.setAutoDelete( true );
+//	viewDock->setAcceptDrops(false);
 
 	//Manager signals
 	connect( mgr, SIGNAL( displayNameChanged() ),
 	         this, SLOT( slotChatDisplayNameChanged() ) );
 	connect( mgr, SIGNAL( contactAdded(const Kopete::Contact*, bool) ),
 	         this, SLOT( slotContactAdded(const Kopete::Contact*, bool) ) );
-	connect( mgr, SIGNAL( contactRemoved(const Kopete::Contact*, const QString&, Kopete::Message::MessageFormat, bool) ),
-	         this, SLOT( slotContactRemoved(const Kopete::Contact*, const QString&, Kopete::Message::MessageFormat, bool) ) );
+	connect( mgr, SIGNAL( contactRemoved(const Kopete::Contact*, const QString&, Qt::TextFormat, bool) ),
+	         this, SLOT( slotContactRemoved(const Kopete::Contact*, const QString&, Qt::TextFormat, bool) ) );
 	connect( mgr, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus & , const Kopete::OnlineStatus &) ),
 	         this, SLOT( slotContactStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
 	connect( mgr, SIGNAL( remoteTyping( const Kopete::Contact *, bool) ),
@@ -154,23 +148,19 @@ ChatView::ChatView( Kopete::ChatSession *mgr, ChatWindowPlugin *parent, const ch
 
 	// add contacts
 	slotContactAdded( mgr->myself(), true );
-	for ( QPtrListIterator<Kopete::Contact> it( mgr->members() ); it.current(); ++it )
-		slotContactAdded( *it, true );
+	for ( i = 0; i != mgr->members().size(); i++ )
+	{
+		slotContactAdded( mgr->members()[i], true );
+	}
 
 	setFocusProxy( editPart()->widget() );
+	m_messagePart->widget()->setFocusProxy( editPart()->widget() );
 	editPart()->widget()->setFocus();
 
-	// init actions
-	KStdAction::copy( this, SLOT(copy()), actionCollection() );
-	KStdAction::close( this, SLOT(closeView()),actionCollection() );
-
-	setCaption( m_manager->displayName(), false );
+	slotChatDisplayNameChanged();
 
 	// restore docking positions
 	readOptions();
-
-	// maybe show chat members
-	createMembersList();
 }
 
 ChatView::~ChatView()
@@ -184,7 +174,7 @@ ChatView::~ChatView()
 
 KTextEdit *ChatView::editWidget()
 {
-	return editPart()->widget();
+	return editPart()->textEdit();
 }
 
 QWidget *ChatView::mainWidget()
@@ -209,7 +199,7 @@ void ChatView::setCurrentMessage( const Kopete::Message &message )
 
 void ChatView::cut()
 {
-	editPart()->edit()->cut();
+	editPart()->textEdit()->cut();
 }
 
 void ChatView::copy()
@@ -217,12 +207,12 @@ void ChatView::copy()
 	if ( messagePart()->hasSelection() )
 		messagePart()->copy();
 	else
-		editPart()->edit()->copy();
+		editPart()->textEdit()->copy();
 }
 
 void ChatView::paste()
 {
-	editPart()->edit()->paste();
+	editPart()->textEdit()->paste();
 }
 
 void ChatView::nickComplete()
@@ -242,7 +232,8 @@ void ChatView::clear()
 
 void ChatView::setBgColor( const QColor &newColor )
 {
-	editPart()->setBgColor( newColor );
+	Q_UNUSED(newColor);
+// 	editPart()->setBackgroundColorColor( newColor );
 }
 
 void ChatView::setFont()
@@ -262,7 +253,14 @@ void ChatView::setFont( const QFont &font )
 
 void ChatView::setFgColor( const QColor &newColor )
 {
-	editPart()->setFgColor( newColor );
+    if ( newColor.isValid() )
+	{
+		editPart()->setTextColor( newColor );
+    }
+	else
+	{
+		editPart()->setTextColor();
+    }
 }
 
 void ChatView::raise( bool activate )
@@ -274,33 +272,24 @@ void ChatView::raise( bool activate )
 
 	if ( !m_mainWindow || !m_mainWindow->isActiveWindow() || activate )
 		makeVisible();
-
-	if ( !KWin::windowInfo( m_mainWindow->winId(), NET::WMDesktop ).onAllDesktops() )
-		if( KopetePrefs::prefs()->trayflashNotifySetCurrentDesktopToChatView() && activate )
-			KWin::setCurrentDesktop( KWin::windowInfo( m_mainWindow->winId(), NET::WMDesktop ).desktop() );
+#ifdef Q_WS_X11
+	if ( !KWindowSystem::windowInfo( m_mainWindow->winId(), NET::WMDesktop ).onAllDesktops() )
+		if( Kopete::BehaviorSettings::self()->trayflashNotifySetCurrentDesktopToChatView() && activate )
+			KWindowSystem::setCurrentDesktop( KWindowSystem::windowInfo( m_mainWindow->winId(), NET::WMDesktop ).desktop() );
 		else
-			KWin::setOnDesktop( m_mainWindow->winId(), KWin::currentDesktop() );
-
+			KWindowSystem::setOnDesktop( m_mainWindow->winId(), KWindowSystem::currentDesktop() );
+#endif
 	if(m_mainWindow->isMinimized())
 	{
-		m_mainWindow->showNormal();
+		KWindowSystem::unminimizeWindow( m_mainWindow->winId());
 	}
 
 
 	m_mainWindow->raise();
 
-	/* Removed Nov 2003
-	According to Zack, the user double-clicking a contact is not valid reason for a non-pager
-	to grab window focus. While I don't agree with this, and it runs contradictory to every other
-	IM out there, commenting this code out to agree with KWin policy.
-
-	Redirect any bugs relating to the widnow now not grabbing focus on clicking a contact to KWin.
-		- Jason K
-	*/
-
 	//Will not activate window if user was typing
 	if ( activate )
-		KWin::activateWindow( m_mainWindow->winId() );
+		KWindowSystem::activateWindow( m_mainWindow->winId() );
 
 }
 
@@ -309,6 +298,7 @@ void ChatView::makeVisible()
 	if ( !m_mainWindow )
 	{
 		m_mainWindow = KopeteChatWindow::window( m_manager );
+		m_mainWindow->setObjectName( QLatin1String("KopeteChatWindow") );
 // 		if ( root )
 // 			root->repaint( true );
 		emit windowCreated();
@@ -331,11 +321,6 @@ bool ChatView::isVisible()
 	return ( m_mainWindow && m_mainWindow->isVisible() );
 }
 
-bool ChatView::visibleMembersList()
-{
-	return d->visibleMembers;
-}
-
 bool ChatView::sendInProgress()
 {
 	return d->sendInProgress;
@@ -352,23 +337,23 @@ bool ChatView::closeView( bool force )
 			QString shortCaption = d->captionText;
 			shortCaption = KStringHandler::rsqueeze( shortCaption );
 
-			response = KMessageBox::warningContinueCancel( this, i18n("<qt>You are about to leave the group chat session <b>%1</b>.<br>"
-				"You will not receive future messages from this conversation.</qt>").arg( shortCaption ), i18n( "Closing Group Chat" ),
-				i18n( "Cl&ose Chat" ), QString::fromLatin1( "AskCloseGroupChat" ) );
+			response = KMessageBox::warningContinueCancel( this, i18n("<qt>You are about to leave the groupchat session <b>%1</b>.<br />"
+				"You will not receive future messages from this conversation.</qt>", shortCaption ), i18n( "Closing Group Chat" ),
+				KGuiItem( i18nc( "@action:button", "Close Chat" ) ), KStandardGuiItem::cancel(), QLatin1String( "AskCloseGroupChat" ) );
 		}
 
 		if ( !unreadMessageFrom.isNull() && ( response == KMessageBox::Continue ) )
 		{
 			response = KMessageBox::warningContinueCancel( this, i18n("<qt>You have received a message from <b>%1</b> in the last "
-				"second. Are you sure you want to close this chat?</qt>").arg( unreadMessageFrom ), i18n( "Unread Message" ),
-				i18n( "Cl&ose Chat" ), QString::fromLatin1("AskCloseChatRecentMessage" ) );
+				"second. Are you sure you want to close this chat?</qt>", unreadMessageFrom ), i18n( "Unread Message" ),
+				KGuiItem( i18nc( "@action:button", "Close Chat" ) ), KStandardGuiItem::cancel(), QLatin1String("AskCloseChatRecentMessage" ) );
 		}
 
 		if ( d->sendInProgress && ( response == KMessageBox::Continue ) )
 		{
 			response = KMessageBox::warningContinueCancel( this, i18n( "You have a message send in progress, which will be "
 				"aborted if this chat is closed. Are you sure you want to close this chat?" ), i18n( "Message in Transit" ),
-				i18n( "Cl&ose Chat" ), QString::fromLatin1( "AskCloseChatMessageInProgress" ) );
+				KGuiItem( i18nc( "@action:button", "Close Chat" ) ), KStandardGuiItem::cancel(), QLatin1String( "AskCloseChatMessageInProgress" ) );
 		}
 	}
 
@@ -403,8 +388,8 @@ void ChatView::updateChatState( KopeteTabState newState )
 
 	if( newState != Typing )
 	{
-		setStatusText( i18n( "One other person in the chat",
-			       "%n other people in the chat", m_manager->members().count() ) );
+		setStatusText( i18np( "One other person in the chat",
+			       "%1 other people in the chat", m_manager->members().count() ) );
 	}
 }
 
@@ -413,145 +398,43 @@ void ChatView::setMainWindow( KopeteChatWindow* parent )
 	m_mainWindow = parent;
 }
 
-void ChatView::createMembersList()
-{
-	if ( !membersDock )
-	{
-		//Create the chat members list
-		membersDock = createDockWidget( QString::fromLatin1( "membersDock" ), QPixmap(), 0L,
-			QString::fromLatin1( "membersDock" ), QString::fromLatin1( " " ) );
-		m_membersList = new ChatMembersListWidget( m_manager, this, "m_membersList" );
-
-		membersDock->setWidget( m_membersList );
-
-		Kopete::ContactPtrList members = m_manager->members();
-
-		if ( members.first() && members.first()->metaContact() != 0 )
-		{
-			membersStatus = static_cast<MembersListPolicy>
-			(
-				members.first()->metaContact()->pluginData
-				( m_manager->protocol(), QString::fromLatin1( "MembersListPolicy" ) ).toInt()
-			);
-		}
-		else
-		{
-			membersStatus = Smart;
-		}
-
-		if( membersStatus == Smart )
-			d->visibleMembers = ( m_manager->members().count() > 1 );
-		else
-			d->visibleMembers = ( membersStatus == Visible );
-
-		placeMembersList( membersDockPosition );
-	}
-}
-
-void ChatView::toggleMembersVisibility()
-{
-	if( membersDock )
-	{
-		d->visibleMembers = !d->visibleMembers;
-		membersStatus = d->visibleMembers ? Visible : Hidden;
-		placeMembersList( membersDockPosition );
-		Kopete::ContactPtrList members = m_manager->members();
-		if ( members.first()->metaContact() )
-		{
-			members.first()->metaContact()->setPluginData( m_manager->protocol(),
-				QString::fromLatin1( "MembersListPolicy" ), QString::number(membersStatus) );
-		}
-		//refreshView();
-	}
-}
-
-void ChatView::placeMembersList( KDockWidget::DockPosition dp )
-{
-// 	kdDebug(14000) << k_funcinfo << "Members list policy " << membersStatus <<
-// 			", visible " << d->visibleMembers << endl;
-
-	if ( d->visibleMembers )
-	{
-		membersDockPosition = dp;
-
-		// look up the dock width
-		int dockWidth;
-		KGlobal::config()->setGroup( QString::fromLatin1( "ChatViewDock" ) );
-
-		if( membersDockPosition == KDockWidget::DockLeft )
-		{
-			dockWidth = KGlobal::config()->readNumEntry(
-				QString::fromLatin1( "membersDock,viewDock:sepPos" ), 30);
-		}
-		else
-		{
-			dockWidth = KGlobal::config()->readNumEntry(
-				QString::fromLatin1( "viewDock,membersDock:sepPos" ), 70);
-		}
-
-		// Make sure it is shown then place it wherever
-		membersDock->setEnableDocking( KDockWidget::DockLeft | KDockWidget::DockRight );
-		membersDock->manualDock( viewDock, membersDockPosition, dockWidth );
-		membersDock->show();
-		membersDock->setEnableDocking( KDockWidget::DockNone );
-	}
-	else
-	{
-		// Dock it to the desktop then hide it
-		membersDock->undock();
-		membersDock->hide();
-	}
-
-	if( d->isActive )
-		m_mainWindow->updateMembersActions();
-
-	//refreshView();
-}
-
 void ChatView::remoteTyping( const Kopete::Contact *contact, bool isTyping )
 {
-	// Make sure we (re-)add the timer at the end, because the slot will
-	// remove the first timer
-	// And yes, the const_cast is a bit ugly, but it's only used as key
-	// value in this dictionary (no indirections) so it's basically
-	// harmless. Unfortunately there's no QConstPtrDictionary in Qt...
-	void *key = const_cast<Kopete::Contact *>( contact );
-	m_remoteTypingMap.remove( key );
+	TypingMap::iterator it = m_remoteTypingMap.find(contact);
+	if (it != m_remoteTypingMap.end())
+	{
+		if (it.value()->isActive())
+			it.value()->stop();
+		delete it.value();
+		m_remoteTypingMap.erase(it);
+	}
 	if( isTyping )
 	{
-		m_remoteTypingMap.insert( key, new QTimer(this) );
-		connect( m_remoteTypingMap[ key ], SIGNAL( timeout() ), SLOT( slotRemoteTypingTimeout() ) );
-		m_remoteTypingMap[ key ]->start( 6000, true );
+		m_remoteTypingMap.insert( contact, new QTimer(this) );
+		connect( m_remoteTypingMap[ contact ], SIGNAL( timeout() ), SLOT( slotRemoteTypingTimeout() ) );
+
+		m_remoteTypingMap[ contact ]->setSingleShot( true );
+		m_remoteTypingMap[ contact ]->start( 6000 );
 	}
 
 	// Loop through the map, constructing a string of people typing
 	QStringList typingList;
-	QPtrDictIterator<QTimer> it( m_remoteTypingMap );
 
-	for( ; it.current(); ++it )
+	for( it = m_remoteTypingMap.begin(); it != m_remoteTypingMap.end(); ++it )
 	{
-		Kopete::Contact *c = static_cast<Kopete::Contact*>( it.currentKey() );
-		QString nick;
-		if( c->metaContact() && c->metaContact() != Kopete::ContactList::self()->myself() )
-		{
-			nick = c->metaContact()->displayName();
-		}
-		else
-		{
-			nick = c->nickName();
-		}
-		typingList.append( nick );
+		const Kopete::Contact *c = it.key();
+		typingList.append( m_messagePart->formatName(c, Qt::PlainText) );
 	}
 
 	// Update the status area
 	if( !typingList.isEmpty() )
 	{
 		if ( typingList.count() == 1 )
-			setStatusText( i18n( "%1 is typing a message" ).arg( typingList.first() ) );
+			setStatusText( i18n( "%1 is typing a message", typingList.first() ) );
 		else
 		{
-			QString statusTyping = typingList.join( QString::fromLatin1( ", " ) );
-			setStatusText( i18n( "%1 is a list of names", "%1 are typing a message" ).arg( statusTyping ) );
+			QString statusTyping = typingList.join( QLatin1String( ", " ) );
+			setStatusText( i18nc( "%1 is a list of names", "%1 are typing a message", statusTyping ) );
 		}
 		updateChatState( Typing );
 	}
@@ -579,11 +462,26 @@ void ChatView::slotChatDisplayNameChanged()
 	// update the caption if it changed to avoid unneeded updates that
 	// could cause flickering
 	QString chatName = m_manager->displayName();
+
+	foreach (const Kopete::Contact *c, msgManager()->members())
+	{
+		QString contactName = m_messagePart->formatName(c, Qt::PlainText);
+		if ( c->metaContact() )
+		{
+			chatName.replace( c->metaContact()->displayName(), contactName );
+		}
+		else
+		{
+			chatName.replace( c->nickName(), contactName );
+		}
+	}
+
+
 	if ( chatName != d->captionText )
 		setCaption( chatName, true );
 }
 
-void ChatView::slotPropertyChanged( Kopete::Contact*, const QString &key,
+void ChatView::slotPropertyChanged( Kopete::PropertyContainer*, const QString &key,
 		const QVariant& oldValue, const QVariant &newValue  )
 {
 	if ( key == Kopete::Global::Properties::self()->nickName().key() )
@@ -591,34 +489,23 @@ void ChatView::slotPropertyChanged( Kopete::Contact*, const QString &key,
 		QString newName=newValue.toString();
 		QString oldName=oldValue.toString();
 
-		if(KopetePrefs::prefs()->showEvents())
+		if(Kopete::BehaviorSettings::self()->showEvents())
 			if ( oldName != newName && !oldName.isEmpty())
-				sendInternalMessage( i18n( "%1 is now known as %2" ). arg( oldName, newName ) );
+				sendInternalMessage( i18n( "%1 is now known as %2", oldName, newName ) );
 	}
 }
 
 void ChatView::slotDisplayNameChanged( const QString &oldValue, const QString &newValue )
 {
-	if( KopetePrefs::prefs()->showEvents() )
+	if( Kopete::BehaviorSettings::self()->showEvents() )
 	{
 		if( oldValue != newValue )
-			sendInternalMessage( i18n( "%1 is now known as %2" ). arg( oldValue, newValue ) );
+			sendInternalMessage( i18n( "%1 is now known as %2", oldValue, newValue ) );
 	}
 }
 
 void ChatView::slotContactAdded(const Kopete::Contact *contact, bool suppress)
 {
-	QString contactName;
-	// Myself metacontact is not a reliable source.
-	if( contact->metaContact() && contact->metaContact() != Kopete::ContactList::self()->myself() )
-	{
-		contactName = contact->metaContact()->displayName();
-	}
-	else
-	{
-		contactName = contact->nickName();
-	}
-
 	if( contact->metaContact() && contact->metaContact() != Kopete::ContactList::self()->myself() )
 	{
 		connect( contact->metaContact(), SIGNAL( displayNameChanged(const QString&, const QString&) ),
@@ -626,42 +513,30 @@ void ChatView::slotContactAdded(const Kopete::Contact *contact, bool suppress)
 	}
 	else
 	{
-		connect( contact, SIGNAL( propertyChanged( Kopete::Contact *, const QString &, const QVariant &, const QVariant & ) ),
-		this, SLOT( slotPropertyChanged( Kopete::Contact *, const QString &, const QVariant &, const QVariant & ) ) ) ;
+		connect( contact, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ),
+		this, SLOT( slotPropertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ) ) ;
 	}
 
+	QString contactName = m_messagePart->formatName(contact, Qt::PlainText);
 	if( !suppress && m_manager->members().count() > 1 )
-		sendInternalMessage(  i18n("%1 has joined the chat.").arg(contactName) );
-
-	if( membersStatus == Smart && membersDock )
-	{
-		bool shouldShowMembers = ( m_manager->members().count() > 1);
-		if( shouldShowMembers != d->visibleMembers )
-		{
-			d->visibleMembers = shouldShowMembers;
-			placeMembersList( membersDockPosition );
-		}
-	}
+		sendInternalMessage(  i18n("%1 has joined the chat.", contactName) );
 
 	updateChatState();
 	emit updateStatusIcon( this );
 }
 
-void ChatView::slotContactRemoved( const Kopete::Contact *contact, const QString &reason, Kopete::Message::MessageFormat format, bool suppressNotification )
+void ChatView::slotContactRemoved( const Kopete::Contact *contact, const QString &reason, Qt::TextFormat format, bool suppressNotification )
 {
-// 	kdDebug(14000) << k_funcinfo << endl;
+// 	kDebug(14000) ;
 	if ( contact != m_manager->myself() )
 	{
-		m_remoteTypingMap.remove( const_cast<Kopete::Contact *>( contact ) );
-
-		QString contactName;
-		if( contact->metaContact() && contact->metaContact() != Kopete::ContactList::self()->myself() )
+		TypingMap::iterator it = m_remoteTypingMap.find( contact );
+		if ( it != m_remoteTypingMap.end() )
 		{
-			contactName = contact->metaContact()->displayName();
-		}
-		else
-		{
-			contactName = contact->nickName();
+			if ((*it)->isActive())
+				(*it)->stop();
+			delete (*it);
+			m_remoteTypingMap.remove( contact );
 		}
 
 		// When the last person leaves, don't disconnect the signals, since we're in a one-to-one chat
@@ -674,17 +549,18 @@ void ChatView::slotContactRemoved( const Kopete::Contact *contact, const QString
 			}
 			else
 			{
-				disconnect(contact,SIGNAL(propertyChanged( Kopete::Contact *, const QString &, const QVariant &, const QVariant & )),
-				this, SLOT( slotPropertyChanged( Kopete::Contact *, const QString &, const QVariant &, const QVariant & ) ) ) ;
+				disconnect(contact,SIGNAL(propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & )),
+				this, SLOT( slotPropertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ) ) ;
 			}
 		}
 
 		if ( !suppressNotification )
 		{
+			QString contactName = m_messagePart->formatName(contact, Qt::PlainText);
 			if ( reason.isEmpty() )
-				sendInternalMessage( i18n( "%1 has left the chat." ).arg( contactName ), format ) ;
+				sendInternalMessage( i18n( "%1 has left the chat.", contactName ), format ) ;
 			else
-				sendInternalMessage( i18n( "%1 has left the chat (%2)." ).arg( contactName, reason ), format);
+				sendInternalMessage( i18n( "%1 has left the chat (%2).", contactName, reason ), format);
 		}
 	}
 
@@ -699,7 +575,7 @@ QString& ChatView::caption() const
 
 void ChatView::setCaption( const QString &text, bool modified )
 {
-// 	kdDebug(14000) << k_funcinfo << endl;
+// 	kDebug(14000) ;
 	QString newCaption = text;
 
 	//Save this caption
@@ -709,7 +585,7 @@ void ChatView::setCaption( const QString &text, bool modified )
 	newCaption = KStringHandler::rsqueeze( d->captionText, 20 );
 
 	//Call the original set caption
-	KDockMainWindow::setCaption( newCaption, false );
+	QWidget::setWindowTitle( newCaption );
 
 	emit updateChatTooltip( this, QString::fromLatin1("<qt>%1</qt>").arg( d->captionText ) );
 	emit updateChatLabel( this, newCaption );
@@ -749,23 +625,16 @@ void ChatView::appendMessage(Kopete::Message &message)
 
 	if( message.direction() == Kopete::Message::Inbound )
 	{
-		if( message.from()->metaContact() && message.from()->metaContact() != Kopete::ContactList::self()->myself() )
-		{
-			unreadMessageFrom = message.from()->metaContact()->displayName();
-		}
-		else
-		{
-			unreadMessageFrom = message.from()->nickName();
-		}
+		unreadMessageFrom = m_messagePart->formatName ( message.from(), Qt::PlainText );
 		QTimer::singleShot( 1000, this, SLOT( slotMarkMessageRead() ) );
 	}
 	else
-		unreadMessageFrom = QString::null;
+		unreadMessageFrom.clear();
 }
 
 void ChatView::slotMarkMessageRead()
 {
-	unreadMessageFrom = QString::null;
+	unreadMessageFrom.clear();
 }
 
 void ChatView::slotToggleRtfToolbar( bool enabled )
@@ -775,31 +644,22 @@ void ChatView::slotToggleRtfToolbar( bool enabled )
 
 void ChatView::slotContactStatusChanged( Kopete::Contact *contact, const Kopete::OnlineStatus &newStatus, const Kopete::OnlineStatus &oldStatus )
 {
- 	kdDebug(14000) << k_funcinfo << contact << endl;
+ 	kDebug(14000) << contact;
 	bool inhibitNotification = ( newStatus.status() == Kopete::OnlineStatus::Unknown ||
 	                             oldStatus.status() == Kopete::OnlineStatus::Unknown );
-	if ( contact && KopetePrefs::prefs()->showEvents() && !inhibitNotification )
+	if ( contact && Kopete::BehaviorSettings::self()->showEvents() && !inhibitNotification )
 	{
 		if ( contact->account() && contact == contact->account()->myself() )
 		{
 			// Separate notification for the 'self' contact
 			if ( newStatus.status() != Kopete::OnlineStatus::Connecting )
-				sendInternalMessage( i18n( "You are now marked as %1." ).arg( newStatus.description() ) );
+				sendInternalMessage( i18n( "You are now marked as %1.", newStatus.description() ) );
 		}
 		else if ( !contact->account() || !contact->account()->suppressStatusNotification() )
 		{
-			// Don't send notifications when we just connected ourselves, i.e. when suppressions are still active
-			if ( contact->metaContact() && contact->metaContact() != Kopete::ContactList::self()->myself() )
-			{
-				sendInternalMessage( i18n( "%2 is now %1." )
-					.arg( newStatus.description(), contact->metaContact()->displayName() ) );
-			}
-			else
-			{
-				QString nick=contact->nickName();
-				sendInternalMessage( i18n( "%2 is now %1." )
-					.arg( newStatus.description(), nick ) );
-			}
+			QString contactName = m_messagePart->formatName(contact, Qt::PlainText);
+			sendInternalMessage( i18n( "%2 is now %1.",
+				newStatus.description(), contactName ) );
 		}
 	}
 
@@ -808,11 +668,23 @@ void ChatView::slotContactStatusChanged( Kopete::Contact *contact, const Kopete:
 	emit updateStatusIcon( this );
 }
 
-void ChatView::sendInternalMessage(const QString &msg, Kopete::Message::MessageFormat format )
+void ChatView::sendInternalMessage(const QString &msg, Qt::TextFormat format )
 {
 	// When closing kopete, some internal message may be sent because some contact are deleted
 	// these contacts can already be deleted
-	Kopete::Message message = Kopete::Message( 0L /*m_manager->myself()*/ , 0L /*m_manager->members()*/, msg, Kopete::Message::Internal, format );
+	Kopete::Message message = Kopete::Message();
+	message.setDirection( Kopete::Message::Internal );
+	switch(format)
+	{
+		default:
+		case Qt::PlainText:
+			message.setPlainBody( msg );
+			break;
+		case Qt::RichText:
+			message.setHtmlBody( msg );
+			break;
+	}
+
 	// (in many case, this is useless to set myself as contact)
 	// TODO: set the contact which initiate the internal message,
 	// so we can later show a icon of it (for example, when he join a chat)
@@ -833,11 +705,9 @@ void ChatView::messageSentSuccessfully()
 
 void ChatView::saveOptions()
 {
-	KConfig *config = KGlobal::config();
-
-	writeDockConfig ( config, QString::fromLatin1( "ChatViewDock" ) );
-	config->setGroup( QString::fromLatin1( "ChatViewDock" ) );
-	config->writeEntry( QString::fromLatin1( "membersDockPosition" ), membersDockPosition );
+	KSharedConfig::Ptr config = KGlobal::config();
+	KConfigGroup kopeteChatWindowMainWinSettings( config, ( msgManager()->form() == Kopete::ChatSession::Chatroom ? QLatin1String( "KopeteChatWindowGroupMode" ) : QLatin1String( "KopeteChatWindowIndividualMode" ) ) );
+	kopeteChatWindowMainWinSettings.writeEntry( QLatin1String("ChatViewSplitter"), d->splitter->saveState().toBase64() );
 	saveChatSettings();
 	config->sync();
 }
@@ -850,22 +720,19 @@ void ChatView::saveChatSettings()
 		return;
 
 	Kopete::MetaContact* mc = contacts.first()->metaContact();
-	
+
 	if ( contacts.count() > 1 )
 		return; //can't save with more than one person in chatview
 
 	if ( !mc )
 		return;
 
-	KConfig* config = KGlobal::config();
-	
-	QString contactListGroup = QString::fromLatin1("chatwindow_") +
+	QString contactListGroup = QLatin1String("chatwindow_") +
 	                           mc->metaContactId();
-
-	config->setGroup( contactListGroup );
-	config->writeEntry( "EnableRichText", editPart()->richTextEnabled() );
-	config->writeEntry( "EnableAutoSpellCheck", editPart()->autoSpellCheckEnabled() );
-	config->sync();
+    KConfigGroup config = KGlobal::config()->group(contactListGroup);
+	config.writeEntry( "EnableRichText", editPart()->isRichTextEnabled() );
+	config.writeEntry( "EnableAutoSpellCheck", editPart()->checkSpellingEnabled() );
+	config.sync();
 }
 
 void ChatView::loadChatSettings()
@@ -875,45 +742,23 @@ void ChatView::loadChatSettings()
 		return; //can't load with more than one other person in the chat
 
 	//read settings for metacontact
-	QString contactListGroup = QString::fromLatin1("chatwindow_") +
+	QString contactListGroup = QLatin1String("chatwindow_") +
 	                           contacts.first()->metaContact()->metaContactId();
-	KConfig* config = KGlobal::config();
-	config->setGroup( contactListGroup );
-	bool enableRichText = config->readBoolEntry( "EnableRichText", true );
-	editPart()->slotSetRichTextEnabled( enableRichText );
-	emit rtfEnabled( this, editPart()->richTextEnabled() );
-	bool enableAutoSpell = config->readBoolEntry( "EnableAutoSpellCheck", false );
+	KConfigGroup config(KGlobal::config(), contactListGroup );
+	bool enableRichText = config.readEntry( "EnableRichText", true );
+	editPart()->setRichTextEnabled( enableRichText );
+	emit rtfEnabled( this, editPart()->isRichTextEnabled() );
+	bool enableAutoSpell = config.readEntry( "EnableAutoSpellCheck", Kopete::BehaviorSettings::self()->spellCheck() );
 	emit autoSpellCheckEnabled( this, enableAutoSpell );
 }
 
 void ChatView::readOptions()
 {
-	KConfig *config = KGlobal::config();
-
-	/** THIS IS BROKEN !!! */
-	//dockManager->readConfig ( config, QString::fromLatin1("ChatViewDock") );
-
-	//Work-around to restore dock widget positions
-	config->setGroup( QString::fromLatin1( "ChatViewDock" ) );
-
-	membersDockPosition = static_cast<KDockWidget::DockPosition>(
-		config->readNumEntry( QString::fromLatin1( "membersDockPosition" ), KDockWidget::DockRight ) );
-
-	QString dockKey = QString::fromLatin1( "viewDock" );
-	if ( d->visibleMembers )
-	{
-		if( membersDockPosition == KDockWidget::DockLeft )
-			dockKey.prepend( QString::fromLatin1( "membersDock," ) );
-		else if( membersDockPosition == KDockWidget::DockRight )
-			dockKey.append( QString::fromLatin1( ",membersDock" ) );
-	}
-
-	dockKey.append( QString::fromLatin1( ",editDock:sepPos" ) );
-	//kdDebug(14000) << k_funcinfo << "reading splitterpos from key: " << dockKey << endl;
-	int splitterPos = config->readNumEntry( dockKey, 70 );
-	editDock->manualDock( viewDock, KDockWidget::DockBottom, splitterPos );
-	viewDock->setDockSite( KDockWidget::DockLeft | KDockWidget::DockRight );
-	editDock->setEnableDocking( KDockWidget::DockNone );
+	KConfigGroup kopeteChatWindowMainWinSettings( KGlobal::config(), ( msgManager()->form() == Kopete::ChatSession::Chatroom ? QLatin1String( "KopeteChatWindowGroupMode" ) : QLatin1String( "KopeteChatWindowIndividualMode" ) ) );
+	//kDebug(14000) << "reading splitterpos from key: " << dockKey;
+	QByteArray state;
+	state = kopeteChatWindowMainWinSettings.readEntry( QLatin1String("ChatViewSplitter"), state );
+	d->splitter->restoreState( QByteArray::fromBase64( state ) );
 }
 
 void ChatView::setActive( bool value )
@@ -929,24 +774,24 @@ void ChatView::setActive( bool value )
 void ChatView::slotRemoteTypingTimeout()
 {
 	// Remove the topmost timer from the list. Why does QPtrDict use void* keys and not typed keys? *sigh*
+	// FIXME: should remove the right item, not the topmost
 	if ( !m_remoteTypingMap.isEmpty() )
-		remoteTyping( reinterpret_cast<const Kopete::Contact *>( QPtrDictIterator<QTimer>(m_remoteTypingMap).currentKey() ), false );
+		remoteTyping( m_remoteTypingMap.begin().key(), false );
 }
 
 void ChatView::dragEnterEvent ( QDragEnterEvent * event )
 {
 	if( event->provides( "kopete/x-contact" ) )
 	{
-		QStringList lst=QStringList::split( QChar( 0xE000 ) , QString::fromUtf8(event->encodedData ( "kopete/x-contact" )) );
+		QStringList lst = QString::fromUtf8(event->encodedData ( "kopete/x-contact" )).split( QChar( 0xE000 ) , QString::SkipEmptyParts );
 		if(m_manager->mayInvite() && m_manager->protocol()->pluginId() == lst[0] && m_manager->account()->accountId() == lst[1])
 		{
 			QString contact=lst[2];
 
 			bool found =false;
-			QPtrList<Kopete::Contact> cts=m_manager->members();
-			for ( QPtrListIterator<Kopete::Contact> it( cts ); it.current(); ++it )
+			foreach(Kopete::Contact * cts, m_manager->members())
 			{
-				if(it.current()->contactId() == contact)
+				if(cts->contactId() == contact)
 				{
 					found=true;
 					break;
@@ -960,17 +805,14 @@ void ChatView::dragEnterEvent ( QDragEnterEvent * event )
 	else if( event->provides( "kopete/x-metacontact" ) )
 	{
 		QString metacontactID=QString::fromUtf8(event->encodedData ( "kopete/x-metacontact" ));
-		Kopete::MetaContact *m=Kopete::ContactList::self()->metaContact(metacontactID);
-
-		if( m && m_manager->mayInvite())
+		Kopete::MetaContact *parent = Kopete::ContactList::self()->metaContact(metacontactID);
+		if ( parent && m_manager->mayInvite() )
 		{
-			QPtrList<Kopete::Contact> cts=m->contacts();
-			for ( QPtrListIterator<Kopete::Contact> it( cts ); it.current(); ++it )
+			foreach ( Kopete::Contact * candidate, parent->contacts() )
 			{
-				Kopete::Contact *c=it.current();
-				if(c && c->account() == m_manager->account())
+				if( candidate && candidate->account() == m_manager->account() && candidate->isOnline())
 				{
-					if( c != m_manager->myself() &&  !m_manager->members().contains(c)  && c->isOnline())
+					if( candidate != m_manager->myself() &&  !m_manager->members().contains( candidate ) )
 						event->accept();
 				}
 			}
@@ -986,23 +828,24 @@ void ChatView::dragEnterEvent ( QDragEnterEvent * event )
 			event->accept();
 	}
 	else
-		KDockMainWindow::dragEnterEvent(event);
+		QWidget::dragEnterEvent(event);
 }
 
 void ChatView::dropEvent ( QDropEvent * event )
 {
+	Kopete::ContactPtrList contacts;
+
 	if( event->provides( "kopete/x-contact" ) )
 	{
-		QStringList lst=QStringList::split( QChar( 0xE000 ) , QString::fromUtf8(event->encodedData ( "kopete/x-contact" )) );
+		QStringList lst = QString::fromUtf8(event->encodedData ( "kopete/x-contact" )).split( QChar( 0xE000 ) , QString::SkipEmptyParts );
 		if(m_manager->mayInvite() && m_manager->protocol()->pluginId() == lst[0] && m_manager->account()->accountId() == lst[1])
 		{
 			QString contact=lst[2];
 
 			bool found =false;
-			QPtrList<Kopete::Contact> cts=m_manager->members();
-			for ( QPtrListIterator<Kopete::Contact> it( cts ); it.current(); ++it )
+			foreach ( Kopete::Contact * candidate, m_manager->members() )
 			{
-				if(it.current()->contactId() == contact)
+				if(candidate->contactId() == contact)
 				{
 					found=true;
 					break;
@@ -1015,17 +858,15 @@ void ChatView::dropEvent ( QDropEvent * event )
 	else if( event->provides( "kopete/x-metacontact" ) )
 	{
 		QString metacontactID=QString::fromUtf8(event->encodedData ( "kopete/x-metacontact" ));
-		Kopete::MetaContact *m=Kopete::ContactList::self()->metaContact(metacontactID);
-		if(m && m_manager->mayInvite())
+		Kopete::MetaContact *parent = Kopete::ContactList::self()->metaContact(metacontactID);
+		if ( parent && m_manager->mayInvite() )
 		{
-			QPtrList<Kopete::Contact> cts=m->contacts();
-			for ( QPtrListIterator<Kopete::Contact> it( cts ); it.current(); ++it )
+			foreach ( Kopete::Contact * candidate, parent->contacts() )
 			{
-				Kopete::Contact *c=it.current();
-				if(c && c->account() == m_manager->account() && c->isOnline())
+				if( candidate && candidate->account() == m_manager->account() && candidate->isOnline())
 				{
-					if( c != m_manager->myself() &&  !m_manager->members().contains(c) )
-						m_manager->inviteContact(c->contactId());
+					if( candidate != m_manager->myself() &&  !m_manager->members().contains( candidate ) )
+						m_manager->inviteContact(candidate->contactId());
 				}
 			}
 		}
@@ -1035,16 +876,15 @@ void ChatView::dropEvent ( QDropEvent * event )
 		Kopete::ContactPtrList members = m_manager->members();
 		Kopete::Contact *contact = members.first();
 
-		if ( !contact || !contact->canAcceptFiles() || !QUriDrag::canDecode( event ) )
+		if ( !contact || !contact->canAcceptFiles() || !Q3UriDrag::canDecode( event ) )
 		{
 			event->ignore();
 			return;
 		}
 
-		KURL::List urlList;
-		KURLDrag::decode( event, urlList );
+		KUrl::List urlList = KUrl::List::fromMimeData( event->mimeData() );
 
-		for ( KURL::List::Iterator it = urlList.begin(); it != urlList.end(); ++it )
+		for ( KUrl::List::Iterator it = urlList.begin(); it != urlList.end(); ++it )
 		{
 			if ( (*it).isLocalFile() )
 			{ //send a file
@@ -1055,18 +895,18 @@ void ChatView::dropEvent ( QDropEvent * event )
 				addText( (*it).url() );
 			}
 		}
-		event->acceptAction();
+		event->accept();
 		return;
 	}
 	else
-		KDockMainWindow::dropEvent(event);
+		QWidget::dropEvent(event);
 
 }
 
 void ChatView::registerContextMenuHandler( QObject *target, const char* slot )
 {
 	connect( m_messagePart,
-		SIGNAL( contextMenuEvent( Kopete::Message &, const QString &, KPopupMenu * ) ),
+		SIGNAL( contextMenuEvent( Kopete::Message &, const QString &, KMenu * ) ),
 		target,
 		slot
 	);
