@@ -1,7 +1,7 @@
 /*
     Adium(and Kopete) ChatWindowStyle format rendering test suite
 
-    Copyright (c) 2005      by Michaël Larouche       <michael.larouche@kdemail.net>
+    Copyright (c) 2005      by Michaël Larouche       <larouche@kde.org>
 
     Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
 
@@ -27,9 +27,8 @@
 #include <qtextstream.h>
 
 // KDE includes
-#include <kapplication.h>
 #include <kunittest/module.h>
-#include <kinstance.h>
+#include <kcomponentdata.h>
 #include <kdebug.h>
 #include <kglobal.h>
 #include <klocale.h>
@@ -61,7 +60,7 @@ public:
 class FakeProtocol : public Kopete::Protocol
 {
 public:
-FakeProtocol( KInstance *instance, QObject *parent, const char *name ) : Kopete::Protocol(instance, parent, name)
+FakeProtocol( const KComponentData &instance, QObject *parent, const char *name ) : Kopete::Protocol(instance, parent, name)
 {
 	
 }
@@ -122,7 +121,7 @@ class ChatWindowStyleRendering_Test::Private
 public:
 	Private()
 	{
-		protocol = new FakeProtocol( new KInstance(QCString("test-kopete-message")), 0L, "test-kopete-message");
+		protocol = new FakeProtocol( KComponentData(QCString("test-kopete-message")), 0L, "test-kopete-message");
 		account = new FakeAccount(protocol, QString("testaccount"), 0);
 
 		// Create fake meta/contacts
@@ -181,10 +180,10 @@ ChatWindowStyleRendering_Test::~ChatWindowStyleRendering_Test()
 void ChatWindowStyleRendering_Test::allTests()
 {
 	// change user data dir to avoid messing with user's .kde dir
-	setenv( "KDEHOME", QFile::encodeName( QDir::homeDirPath() + "/.kopete-unittest" ), true );
+	setenv( "KDEHOME", QFile::encodeName( QDir::homePath() + "/.kopete-unittest" ), true );
 
-	KApplication::disableAutoDcopRegistration();
-	//KCmdLineArgs::init(argc,argv,"testkopetemessage", 0, 0, 0, 0);
+	//KApplication::disableAutoDcopRegistration();
+	//KCmdLineArgs::init(argc,argv,"testkopetemessage", 0, KLocalizedString(), 0, KLocalizedString());
 	KApplication app;
 
 	chatPart = new ChatMessagePart(d->fakeChatSession, 0, 0);
@@ -198,14 +197,14 @@ void ChatWindowStyleRendering_Test::allTests()
 void ChatWindowStyleRendering_Test::testHeaderRendering()
 {
 	QString expectedHtml = QString(
-"<div><span id=\"KopeteHeaderChatNameInternal\">Test Session</span></div>\n"
+"<div>Test Session</div>\n"
 "<div>Bob</div>\n"
 "<div>Audrey</div>\n"
 "<div>Incoming/buddy_icon.png</div>\n"
 "<div>Outgoing/buddy_icon.png</div>\n"
 "<div>%1</div>\n"
 "<div>%2</div>"
-	).arg(KGlobal::locale()->formatDateTime( QDateTime::currentDateTime(), true, true ) )
+	).arg(KGlobal::locale()->formatDateTime( QDateTime::currentDateTime()))
 	.arg(QDateTime::currentDateTime().toString("hh:mm"));
 
 	QString headerHtml = d->testStyle->getHeaderHtml();
@@ -213,7 +212,7 @@ void ChatWindowStyleRendering_Test::testHeaderRendering()
 
 	resultHtml = chatPart->formatStyleKeywords(headerHtml);
 
-	kdDebug(14000) << "Result HTML: " << resultHtml << endl;
+	kDebug(14000) << "Result HTML: " << resultHtml;
 
 	CHECK(resultHtml, expectedHtml);
 }
@@ -223,26 +222,28 @@ void ChatWindowStyleRendering_Test::testMessageRendering()
 	QString expectedIncomingHtml = QString(
 "Incoming:\n"
 "<div>Incoming/buddy_icon.png</div>\n"
-"<div><a href=\"kopetemessage://audrey@localhost/?protocolId=Kopete::Protocol&amp;accountId=testaccount\" class=\"KopeteDisplayName\">audrey@localhost</a></div>\n"
-"<div><a href=\"kopetemessage://audrey@localhost/?protocolId=Kopete::Protocol&amp;accountId=testaccount\" class=\"KopeteDisplayName\">Audrey</a></div>\n"
+"<div>audrey@localhost</div>\n"
+"<div>Audrey</div>\n"
 "<div>Kopete</div>\n"
-"<div><span style=\"\"class=\"KopeteMessageBody\">Test</span></div>\n"
+"<div>Test</div>\n"
 "<div>%1</div>\n"
 "<div>%2</div>\n"
 "<div id=\"insert\">"
-	).arg( QDateTime::currentDateTime().toString( "hh:mm:ss" ), QDateTime::currentDateTime().toString( "hh:mm" ) );
+	).arg(KGlobal::locale()->formatDateTime( QDateTime::currentDateTime()))
+	.arg(QDateTime::currentDateTime().toString("hh:mm"));
 
 	QString expectedOutgoingHtml = QString(
 "Outgoing:\n"
 "<div>Outgoing/buddy_icon.png</div>\n"
-"<div><a href=\"kopetemessage://bob@localhost/?protocolId=Kopete::Protocol&amp;accountId=testaccount\" class=\"KopeteDisplayName\">bob@localhost</a></div>\n"
-"<div><a href=\"kopetemessage://bob@localhost/?protocolId=Kopete::Protocol&amp;accountId=testaccount\" class=\"KopeteDisplayName\">Bob</a></div>\n"
+"<div>bob@localhost</div>\n"
+"<div>Bob</div>\n"
 "<div>Kopete</div>\n"
-"<div><span style=\"\"class=\"KopeteMessageBody\">Hello there</span></div>\n"
+"<div>Hello there</div>\n"
 "<div>%1</div>\n"
 "<div>%2</div>\n"
 "<div id=\"insert\">"
-	).arg( QDateTime::currentDateTime().toString( "hh:mm:ss" ), QDateTime::currentDateTime().toString( "hh:mm" ) );
+	).arg(KGlobal::locale()->formatDateTime( QDateTime::currentDateTime()))
+	.arg(QDateTime::currentDateTime().toString("hh:mm"));
 
 
 	QString tempHtml;
@@ -254,14 +255,14 @@ void ChatWindowStyleRendering_Test::testMessageRendering()
 	tempHtml = d->testStyle->getIncomingHtml();
 	resultHtml = chatPart->formatStyleKeywords(tempHtml, msgIn);
 
-	kdDebug(14000) << "Message incoming HTML: " << resultHtml << endl;
+	kDebug(14000) << "Message incoming HTML: " << resultHtml;
 
 	CHECK(resultHtml, expectedIncomingHtml);
 
 	tempHtml = d->testStyle->getOutgoingHtml();
 	resultHtml = chatPart->formatStyleKeywords(tempHtml, msgOut);
 
-	kdDebug(14000) << "Message outgoing HTML: " << resultHtml << endl;
+	kDebug(14000) << "Message outgoing HTML: " << resultHtml;
 
 	CHECK(resultHtml, expectedOutgoingHtml);
 }
@@ -269,10 +270,11 @@ void ChatWindowStyleRendering_Test::testMessageRendering()
 void ChatWindowStyleRendering_Test::testStatusRendering()
 {
 	QString expectedStatusHtml = QString(
-"<div><span style=\"\"class=\"KopeteMessageBody\">A contact went offline.</span></div>\n"
+"<div>A contact went offline.</div>\n"
 "<div>%1</div>\n"
 "<div>%2</div>"
-	).arg( QDateTime::currentDateTime().toString( "hh:mm:ss" ), QDateTime::currentDateTime().toString( "hh:mm" ) );
+	).arg(KGlobal::locale()->formatDateTime( QDateTime::currentDateTime()))
+	.arg(QDateTime::currentDateTime().toString("hh:mm"));
 
 	QString statusHtml = d->testStyle->getStatusHtml();
 	QString resultHtml;
@@ -314,7 +316,7 @@ void ChatWindowStyleRendering_Test::testFullRendering()
 
 	// Read the expected(sample) HTML from file.
 	QFile sampleHtml(QString(SRCDIR)+"sample.html");
-	if(sampleHtml.open(IO_ReadOnly))
+	if(sampleHtml.open(QIODevice::ReadOnly))
 	{
 		QTextStream stream(&sampleHtml);
 		stream.setEncoding(QTextStream::UnicodeUTF8);
