@@ -20,9 +20,6 @@
 */
 
 #include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qlistview.h>
-#include <qptrlist.h>
 #include <qmap.h>
 
 #include <klocale.h>
@@ -37,82 +34,97 @@
 #include <kabcpersistence.h>
 #include <kopetecontact.h>
 #include <kopetecontactlist.h>
-#include <kopetecontactproperty.h>
+#include <kopeteproperty.h>
 #include <kopeteglobal.h>
 #include <kopetemetacontact.h>
-
-#include "kabcpersistence.h"
+#include <kopetepicture.h>
 
 #include "kabcexport.h"
 
-class ContactLVI : public QCheckListItem
+class ContactLVI : public QListWidgetItem
 {
 	public:
-		ContactLVI ( Kopete::MetaContact * mc, QListView * parent, const QString & text, Type tt = RadioButtonController ) : QCheckListItem( parent, text, tt ), mc( mc )
-		{	}
+		ContactLVI ( Kopete::MetaContact * mc, QListWidget * parent, const QString & text, QListWidgetItem::ItemType tt = Type ) : QListWidgetItem( text,parent, tt ), mc( mc )
+		{
+			
+		}
 		Kopete::MetaContact * mc;
 		QString uid;
 };
 
 // ctor populates the resource list and contact list, and enables the next button on the first page 
-KabcExportWizard::KabcExportWizard( QWidget *parent, const char *name )
-	: KabcExportWizard_Base( parent, name )
+KabcExportWizard::KabcExportWizard( QWidget *parent )
+	: KAssistantDialog(parent)
 {
-	connect( m_addrBooks, SIGNAL( selectionChanged( QListBoxItem * ) ), SLOT( slotResourceSelectionChanged( QListBoxItem * ) ) );
+	QWidget *page1Widget=new QWidget(this);
+	m_page1.setupUi(page1Widget);
+	m_page1WidgetItem=addPage(page1Widget,i18n("Select Address Book"));
+	QWidget *page2Widget=new QWidget(this);
+	m_page2.setupUi(page2Widget);
+	m_page2WidgetItem=addPage(page2Widget,i18n("Select Contact"));
+	
 
-	connect( m_btnSelectAll, SIGNAL( clicked() ), SLOT( slotSelectAll() ) );
-	connect( m_btnDeselectAll, SIGNAL( clicked() ), SLOT( slotDeselectAll() ) );
+	connect( m_page1.addrBooks, SIGNAL( currentItemChanged ( QListWidgetItem * , QListWidgetItem * )  ),
+		  SLOT( slotResourceSelectionChanged( QListWidgetItem * )));
+
+	connect( m_page2.btnSelectAll, SIGNAL( clicked() ), SLOT( slotSelectAll() ) );
+	connect( m_page2.btnDeselectAll, SIGNAL( clicked() ), SLOT( slotDeselectAll() ) );
 	
 	// fill resource selector
 	m_addressBook = Kopete::KABCPersistence::self()->addressBook();
 
-	QPtrList<KABC::Resource> kabcResources = m_addressBook->resources();
+	QList<KABC::Resource*> kabcResources = m_addressBook->resources();
 
-	QPtrListIterator<KABC::Resource> resIt( kabcResources );
+	QListIterator<KABC::Resource*> resIt( kabcResources );
 	KABC::Resource *resource;
 	
 	uint counter = 0;
-	while ( ( resource = resIt.current() ) != 0 ) 
+	while ( resIt.hasNext() ) 
 	{
-		++resIt;
+		resource = resIt.next();
 		if ( !resource->readOnly() ) 
 		{
 			m_resourceMap.insert( counter, resource );
-			m_addrBooks->insertItem( resource->resourceName() );
+			m_page1.addrBooks->addItem( resource->resourceName() );
 			counter++;
 		}
 	}
-	setNextEnabled( QWizard::page( 0 ), false );
-	setFinishEnabled( QWizard::page( 1 ), true );
+
+	setValid(m_page1WidgetItem,false);
+
 	// if there were no writable address books, tell the user
 	if ( counter == 0 )
 	{
-		m_addrBooks->insertItem( i18n( "No writeable addressbook resource found." ) );
-		m_addrBooks->insertItem( i18n( "Add or enable one using the KDE Control Center." ) );
-		m_addrBooks->setEnabled( false );
+		m_page1.addrBooks->addItem( i18n( "No writeable addressbook resource found." ) );
+		m_page1.addrBooks->addItem( i18n( "Add or enable one using the KDE Control Center." ) );
+		m_page1.addrBooks->setEnabled( false );
 	}
 
-	if ( m_addrBooks->count() == 1 )
-		m_addrBooks->setSelected( 0, true );
+	if ( m_page1.addrBooks->count() == 1 )
+		m_page1.addrBooks->setCurrentRow( 0 );
 	
 	// fill contact list
-	QPtrList<Kopete::MetaContact> contacts = Kopete::ContactList::self()->metaContacts();
-	QPtrListIterator<Kopete::MetaContact> it( contacts );
+	QList<Kopete::MetaContact*> contacts = Kopete::ContactList::self()->metaContacts();
+	QList<Kopete::MetaContact*>::iterator it, itEnd = contacts.end();
 	counter = 0;
 	QString alreadyIn = i18n( " (already in address book)" );
-	for (; it.current(); ++it)
+	for ( it = contacts.begin(); it != itEnd; ++it)
 	{
-		m_contactMap.insert( counter, it.current() );
-		QCheckListItem * lvi = new ContactLVI( it.current(), m_contactList,
-				it.current()->displayName(), QCheckListItem::CheckBox );
-		lvi->setOn( false );
-		if ( it.current()->metaContactId().contains(':') )
+		Kopete::MetaContact* mc = (*it);
+		m_contactMap.insert( counter, mc );
+		QListWidgetItem * lvi = new ContactLVI( mc, m_page2.contactList,
+				mc->displayName() );
+		lvi->setCheckState( Qt::Unchecked );
+		if ( mc->metaContactId().contains(':') )
 		{
-			lvi->setOn( true );
-			lvi->setEnabled( true );
+			lvi->setCheckState( Qt::Checked );
+			lvi->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);	
 		}
 		else
-			lvi->setText( 0, lvi->text( 0 ) + alreadyIn );
+		{
+			lvi->setText( lvi->text() + alreadyIn );
+			lvi->setFlags( 0 );
+		}
 	}
 }
 
@@ -123,31 +135,26 @@ KabcExportWizard::~KabcExportWizard()
 
 void KabcExportWizard::slotDeselectAll()
 {
-	QListViewItemIterator it( m_contactList );
-	while ( it.current() )
+	for(int i=0;i<m_page2.contactList->count();i++)
 	{
-		ContactLVI *item = static_cast<ContactLVI *>( it.current() );
-		item->setOn( false );
-		++it;
+		ContactLVI *item = static_cast<ContactLVI *>( m_page2.contactList->item(i) );
+		item->setCheckState( Qt::Unchecked );
 	}
 }
 
 void KabcExportWizard::slotSelectAll()
 {
-	QListViewItemIterator it( m_contactList );
-	while ( it.current() )
+	for(int i=0;i<m_page2.contactList->count();i++)
 	{
-		ContactLVI *item = static_cast<ContactLVI *>( it.current() );
-		++it;
-		if ( !item->isEnabled() )
-			continue;
-		item->setOn( true );
+		ContactLVI *item = static_cast<ContactLVI *>( m_page2.contactList->item(i) );
+		if ( item->flags() & Qt::ItemIsEnabled)
+			item->setCheckState( Qt::Checked );
 	}
 }
 
-void KabcExportWizard::slotResourceSelectionChanged( QListBoxItem * lbi )
+void KabcExportWizard::slotResourceSelectionChanged( QListWidgetItem * lbi )
 {
-	setNextEnabled( QWizard::page( 0 ), lbi->isSelected() );
+	setValid( m_page1WidgetItem,true );
 }
 
 // accept runs the export algorithm
@@ -156,29 +163,28 @@ void KabcExportWizard::accept()
 	// first add an addressee to the selected resource 
 	// then set the metacontactId of each MC to that of the new addressee
 	KABC::Resource * selectedResource = 
-			m_resourceMap[ ( m_addrBooks->index( m_addrBooks->selectedItem() ) ) ];
+			m_resourceMap[ ( m_page1.addrBooks->currentRow() ) ];
 	// for each item checked
 	{
-		QListViewItemIterator it( m_contactList );
-		while ( it.current() )
+		for(int i=0;i<m_page2.contactList->count();i++)
 		{
-			ContactLVI *item = static_cast<ContactLVI *>( it.current() );
+			ContactLVI *item = static_cast<ContactLVI *>(  m_page2.contactList->item(i) );
 			// if it is checked and enabled
-			if ( item->isEnabled() && item->isOn() )
+			if ( item->flags() & Qt::ItemIsEnabled && item->checkState() & Qt::Checked)
 			{
 				KABC::Addressee addr;
 				addr = m_addressBook->findByUid( item->mc->metaContactId() );
 				if ( addr.isEmpty() ) // unassociated contact
 				{
-					kdDebug( 14000 ) << "creating addressee " << item->mc->displayName() << " in address book " << selectedResource->resourceName() << endl;
+					kDebug( 14000 ) << "creating addressee " << item->mc->displayName() << " in address book " << selectedResource->resourceName();
 					// create a new addressee in the selected resource
 					addr.setResource( selectedResource );
 
 					// set name
-					QPtrList<Kopete::Contact> contacts = item->mc->contacts();
+					QList<Kopete::Contact*> contacts = item->mc->contacts();
 					if ( contacts.count() == 1 )
 					{
-						Kopete::ContactProperty prop;
+						Kopete::Property prop;
 						prop = contacts.first()->property(
 								Kopete::Global::Properties::self()->fullName() );
 						if ( prop.isNull() )
@@ -202,7 +208,6 @@ void KabcExportWizard::accept()
 					m_addressBook->insertAddressee( addr );
 				}
 			}
-			++it;
 		}
 	}
 	// request a write in case we only changed details on existing linked addressee
@@ -212,12 +217,11 @@ void KabcExportWizard::accept()
 
 void KabcExportWizard::exportDetails( Kopete::MetaContact * mc, KABC::Addressee & addr )
 {
-	// for each contact
-	QPtrList<Kopete::Contact> contacts = mc->contacts();
-	QPtrListIterator<Kopete::Contact> cit( contacts );
-	for( ; cit.current(); ++cit )
+	QList<Kopete::Contact*> contacts = mc->contacts();
+	QList<Kopete::Contact*>::iterator cit, citEnd = contacts.begin();
+	for( cit = contacts.begin(); cit != citEnd; ++cit )
 	{
-		Kopete::ContactProperty prop;
+		Kopete::Property prop;
 		prop = (*cit)->property( Kopete::Global::Properties::self()->emailAddress() );
 		if ( !prop.isNull() )
 		{
@@ -240,10 +244,12 @@ void KabcExportWizard::exportDetails( Kopete::MetaContact * mc, KABC::Addressee
 		}
 	
 	}
-	// metacontact photo
-	QImage photo = mc->photo();
-	if ( !photo.isNull() )
+	
+	if( !mc->picture().isNull() )
+	{
+		QImage photo = mc->picture().image();
 		addr.setPhoto( KABC::Picture( photo ) );
+	}
 }
 
 #include "kabcexport.moc"
