@@ -4,7 +4,7 @@
     Logic for exporting data acquired from messaging systems to the 
     KDE address book
 
-    Copyright (c) 2004 by Will Stephenson <lists@stevello.free-online.co.uk>
+    Copyright (c) 2004 by Will Stephenson <wstephenson@kde.org>
 
     Kopete    (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
 
@@ -21,10 +21,12 @@
 #include <kabc/phonenumber.h>
 #include <qcombobox.h>
 #include <qlabel.h>
+//Added by qt3to4:
+#include <QPixmap>
 
-#include <kdialogbase.h>
+#include <kdialog.h>
 #include <kiconloader.h>
-#include <klistbox.h>
+#include <k3listbox.h>
 #include <klocale.h>
 
 #include "kopeteaccount.h"
@@ -33,9 +35,8 @@
 #include "kopetecontact.h"
 
 #include "kopeteaddrbookexport.h"
-#include "kopeteaddrbookexportui.h"
 
-KopeteAddressBookExport::KopeteAddressBookExport( QWidget *parent, Kopete::MetaContact *mc ) : QObject( parent )
+KopeteAddressBookExport::KopeteAddressBookExport( QWidget *parent, Kopete::MetaContact *mc ) : QObject( parent ), Ui::AddressBookExportUI()
 {
 	// instantiate dialog and populate widgets
 	mParent = parent;
@@ -52,13 +53,13 @@ void KopeteAddressBookExport::initLabels()
 {
 	if ( !mAddressee.isEmpty() )
 	{
-		mUI->mLblFirstName->setText( mAddressee.givenNameLabel() );
-		mUI->mLblLastName->setText( mAddressee.familyNameLabel() );
-		mUI->mLblEmail->setText( mAddressee.emailLabel() );
-		mUI->mLblUrl->setText( mAddressee.urlLabel() );
-		mUI->mLblHomePhone->setText( mAddressee.homePhoneLabel() );
-		mUI->mLblWorkPhone->setText( mAddressee.businessPhoneLabel() );
-		mUI->mLblMobilePhone->setText( mAddressee.mobilePhoneLabel() );
+		mLblFirstName->setText( mAddressee.givenNameLabel() );
+		mLblLastName->setText( mAddressee.familyNameLabel() );
+		mLblEmail->setText( mAddressee.emailLabel() );
+		mLblUrl->setText( mAddressee.urlLabel() );
+		mLblHomePhone->setText( mAddressee.homePhoneLabel() );
+		mLblWorkPhone->setText( mAddressee.businessPhoneLabel() );
+		mLblMobilePhone->setText( mAddressee.mobilePhoneLabel() );
 	}
 }
 
@@ -66,48 +67,48 @@ void KopeteAddressBookExport::fetchKABCData()
 {
 	if ( !mAddressee.isEmpty() )
 	{
-		mAddrBookIcon = SmallIcon( "kaddressbook" );
+		mAddrBookIcon = SmallIcon( "office-address-book" );
 		
 		// given name
 		QString given = mAddressee.givenName();
 		if ( !given.isEmpty() )
-			mUI->mFirstName->insertItem( mAddrBookIcon, given );
+			mFirstName->addItem( QIcon(mAddrBookIcon), given );
 		else
-			mUI->mFirstName->insertItem( mAddrBookIcon, i18n("<Not Set>") );
+			mFirstName->addItem( QIcon(mAddrBookIcon), i18n("<Not Set>") );
 			
 		// family name
 		QString family = mAddressee.familyName();
 		if ( !family.isEmpty() )
-			mUI->mLastName->insertItem( mAddrBookIcon, family );
+			mLastName->addItem( QIcon(mAddrBookIcon), family );
 		else
-			mUI->mLastName->insertItem( mAddrBookIcon, i18n("<Not Set>") );
+			mLastName->addItem( QIcon(mAddrBookIcon), i18n("<Not Set>") );
 		
 		// url
 		QString url = mAddressee.url().url();
 		if ( !url.isEmpty() )
-			mUI->mUrl->insertItem( mAddrBookIcon, url );
+			mUrl->addItem( QIcon(mAddrBookIcon), url );
 		else
-			mUI->mUrl->insertItem( mAddrBookIcon, i18n("<Not Set>") );
+			mUrl->addItem( QIcon(mAddrBookIcon), i18n("<Not Set>") );
 		
 		// emails
 		QStringList emails = mAddressee.emails();
 		numEmails = emails.count();
 		for ( QStringList::Iterator it = emails.begin(); it != emails.end(); ++it )
-			mUI->mEmails->insertItem( mAddrBookIcon, *it );
+			mEmails->insertItem( mAddrBookIcon, *it );
 		if ( numEmails == 0 )
 		{
-			mUI->mEmails->insertItem( mAddrBookIcon, i18n("<Not Set>") );
+			mEmails->insertItem( mAddrBookIcon, i18n("<Not Set>") );
 			numEmails = 1;
 		}
 		
 		// phone numbers
-		fetchPhoneNumbers( mUI->mHomePhones, KABC::PhoneNumber::Home, numHomePhones );
-		fetchPhoneNumbers( mUI->mWorkPhones, KABC::PhoneNumber::Work, numWorkPhones );
-		fetchPhoneNumbers( mUI->mMobilePhones, KABC::PhoneNumber::Cell, numMobilePhones );
+		fetchPhoneNumbers( mHomePhones, KABC::PhoneNumber::Home, numHomePhones );
+		fetchPhoneNumbers( mWorkPhones, KABC::PhoneNumber::Work, numWorkPhones );
+		fetchPhoneNumbers( mMobilePhones, KABC::PhoneNumber::Cell, numMobilePhones );
 	}
 }
 
-void KopeteAddressBookExport::fetchPhoneNumbers( KListBox * listBox, int type, uint& counter )
+void KopeteAddressBookExport::fetchPhoneNumbers( K3ListBox * listBox, KABC::PhoneNumber::Type type, uint& counter )
 {
 	KABC::PhoneNumber::List phones = mAddressee.phoneNumbers( type );
 	counter = phones.count();
@@ -123,42 +124,42 @@ void KopeteAddressBookExport::fetchPhoneNumbers( KListBox * listBox, int type, u
 
 void KopeteAddressBookExport::fetchIMData()
 {	
-	QPtrList<Kopete::Contact> contacts = mMetaContact->contacts();
-	QPtrListIterator<Kopete::Contact> cit( contacts );
-	for( ; cit.current(); ++cit )
+	QList<Kopete::Contact*> contacts = mMetaContact->contacts();
+	QList<Kopete::Contact*>::iterator cit, citEnd = contacts.end();
+	for( cit = contacts.begin(); cit != citEnd; ++cit )
 	{
 		// for each contact, get the property content
-		Kopete::Contact* c = cit.current();
+		Kopete::Contact* c = (*cit);
 		QPixmap contactIcon = c->account()->accountIcon( 16 );
 		// given name
-		populateIM( c, contactIcon, mUI->mFirstName, Kopete::Global::Properties::self()->firstName() );
+		populateIM( c, contactIcon, mFirstName, Kopete::Global::Properties::self()->firstName() );
 		// family name
-		populateIM( c, contactIcon, mUI->mLastName, Kopete::Global::Properties::self()->lastName() );
+		populateIM( c, contactIcon, mLastName, Kopete::Global::Properties::self()->lastName() );
 		// url
 		// TODO: make URL/homepage a global template, currently only in IRC channel contact
 		// emails
-		populateIM( c, contactIcon, mUI->mEmails, Kopete::Global::Properties::self()->emailAddress() );
+		populateIM( c, contactIcon, mEmails, Kopete::Global::Properties::self()->emailAddress() );
 		// home phone
-		populateIM( c, contactIcon, mUI->mHomePhones, Kopete::Global::Properties::self()->privatePhone() );
+		populateIM( c, contactIcon, mHomePhones, Kopete::Global::Properties::self()->privatePhone() );
 		// work phone
-		populateIM( c, contactIcon, mUI->mWorkPhones, Kopete::Global::Properties::self()->workPhone() );
+		populateIM( c, contactIcon, mWorkPhones, Kopete::Global::Properties::self()->workPhone() );
 		// mobile phone
-		populateIM( c, contactIcon, mUI->mMobilePhones, Kopete::Global::Properties::self()->privateMobilePhone() );
+		populateIM( c, contactIcon, mMobilePhones, Kopete::Global::Properties::self()->privateMobilePhone() );
 	}
 }
 
-void KopeteAddressBookExport::populateIM( const Kopete::Contact *contact, const QPixmap &icon, QComboBox *combo, const Kopete::ContactPropertyTmpl &property )
+void KopeteAddressBookExport::populateIM( const Kopete::Contact *contact, const QPixmap &icon, QComboBox *combo, const Kopete::PropertyTmpl &property )
 {
-	Kopete::ContactProperty prop = contact->property( property );
+	Kopete::Property prop = contact->property( property );
 	if ( !prop.isNull() )
 	{
-		combo->insertItem( icon, prop.value().toString() );
+		combo->addItem( QIcon(icon), prop.value().toString() );
 	}	
 }
 
-void KopeteAddressBookExport::populateIM( const Kopete::Contact *contact, const QPixmap &icon, KListBox *listBox, const Kopete::ContactPropertyTmpl &property )
+void KopeteAddressBookExport::populateIM( const Kopete::Contact *contact, const QPixmap &icon, K3ListBox *listBox, const Kopete::PropertyTmpl &property )
 {
-	Kopete::ContactProperty prop = contact->property( property );
+	Kopete::Property prop = contact->property( property );
 	if ( !prop.isNull() )
 	{
 		listBox->insertItem( icon, prop.value().toString() );
@@ -174,11 +175,15 @@ int KopeteAddressBookExport::showDialog()
 		numHomePhones = 0;
 		numWorkPhones = 0;
 		numMobilePhones = 0;
-		mDialog = new KDialogBase( mParent, "addressbookexportdialog", true, i18n("Export to Address Book"), KDialogBase::Ok|KDialogBase::Cancel );
-		mUI = new AddressBookExportUI( mDialog );
-		mDialog->setMainWidget( mUI );
-		mDialog->setButtonOK( KGuiItem( i18n( "Export" ), 
-							  QString::null, i18n( "Set address book fields using the selected data from Kopete" ) ) ); 
+		mDialog = new KDialog( mParent );
+		mDialog->setCaption( i18n("Export to Address Book") );
+		mDialog->setButtons( KDialog::Ok|KDialog::Cancel );
+		
+		QWidget* w = new QWidget( mDialog );
+		setupUi( w );
+		mDialog->setMainWidget( w );
+		mDialog->setButtonGuiItem( KDialog::Ok, KGuiItem( i18n( "Export" ), 
+							  QString(), i18n( "Set address book fields using the selected data from Kopete" ) ) );
 
 		initLabels();
 		// fetch existing data from kabc
@@ -198,48 +203,48 @@ void KopeteAddressBookExport::exportData()
 	// update the Addressee
 	// first name
 	bool dirty = false;
-	if ( newValue( mUI->mFirstName ) )
+	if ( newValue( mFirstName ) )
 	{
 		dirty = true;
-		mAddressee.setGivenName( mUI->mFirstName->currentText() );
+		mAddressee.setGivenName( mFirstName->currentText() );
 	}
 	// last name
-	if ( newValue( mUI->mLastName ) )
+	if ( newValue( mLastName ) )
 	{
 		dirty = true;
-		mAddressee.setFamilyName( mUI->mLastName->currentText() );
+		mAddressee.setFamilyName( mLastName->currentText() );
 	}
 	// url
-	if ( newValue( mUI->mUrl ) )
+	if ( newValue( mUrl ) )
 	{
 		dirty = true;
-		mAddressee.setUrl( KURL( mUI->mUrl->currentText() ) );
+		mAddressee.setUrl( KUrl( mUrl->currentText() ) );
 	}
 
 	QStringList newVals;
 	// email
-	newVals = newValues( mUI->mEmails, numEmails );
+	newVals = newValues( mEmails, numEmails );
 	for ( QStringList::Iterator it = newVals.begin(); it != newVals.end(); ++it )
 	{
 		dirty = true;
 		mAddressee.insertEmail( *it );
 	}
 	// home phone
-	newVals = newValues( mUI->mHomePhones, numHomePhones );
+	newVals = newValues( mHomePhones, numHomePhones );
 	for ( QStringList::Iterator it = newVals.begin(); it != newVals.end(); ++it )
 	{
 		dirty = true;
 		mAddressee.insertPhoneNumber( KABC::PhoneNumber( *it, KABC::PhoneNumber::Home ) );
 	}
 	// work phone
-	newVals = newValues( mUI->mWorkPhones, numWorkPhones );
+	newVals = newValues( mWorkPhones, numWorkPhones );
 	for ( QStringList::Iterator it = newVals.begin(); it != newVals.end(); ++it )
 	{
 		dirty = true;
 		mAddressee.insertPhoneNumber( KABC::PhoneNumber( *it, KABC::PhoneNumber::Work ) );
 	}
 	// mobile
-	newVals = newValues( mUI->mMobilePhones, numMobilePhones );
+	newVals = newValues( mMobilePhones, numMobilePhones );
 	for ( QStringList::Iterator it = newVals.begin(); it != newVals.end(); ++it )
 	{
 		dirty = true;
@@ -253,16 +258,16 @@ void KopeteAddressBookExport::exportData()
 	
 		KABC::Ticket *ticket = mAddressBook->requestSaveTicket();
 		if ( !ticket )
-			kdWarning( 14000 ) << k_funcinfo << "WARNING: Resource is locked by other application!" << endl;
+			kWarning( 14000 ) << "WARNING: Resource is locked by other application!";
 		else
 		{
 			if ( !mAddressBook->save( ticket ) )
 			{
-				kdWarning( 14000 ) << k_funcinfo << "ERROR: Saving failed!" << endl;
+				kWarning( 14000 ) << "ERROR: Saving failed!";
 				mAddressBook->releaseSaveTicket( ticket );
 			}
 		}
-		kdDebug( 14000 ) << k_funcinfo << "Finished writing KABC" << endl;
+		kDebug( 14000 ) << "Finished writing KABC";
 	}
 }
 
@@ -270,11 +275,11 @@ bool KopeteAddressBookExport::newValue( QComboBox *combo )
 {
 	// all data in position 0 is from KABC, so if position 0 is selected,
 	// or if the selection is the same as the data at 0, return false
-	return !( combo->currentItem() == 0 || 
-			( combo->text( combo->currentItem() ) == combo->text( 0 ) ) );
+	return !( combo->currentIndex() == 0 || 
+			( combo->itemText( combo->currentIndex() ) == combo->itemText( 0 ) ) );
 }
 
-QStringList KopeteAddressBookExport::newValues( KListBox *listBox, uint counter )
+QStringList KopeteAddressBookExport::newValues( K3ListBox *listBox, uint counter )
 {
 	QStringList newValues;
 	// need to iterate all items except those from KABC and check if selected and not same as the first
