@@ -25,37 +25,41 @@
 
 #include <kconfig.h>
 #include <kdebug.h>
+#include <kglobal.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kmessagebox.h>
+#include <solid/networking.h>
 
 #include "addaccountwizard.h"
 #include "kabcpersistence.h"
 #include "kopeteaccount.h"
 #include "kopeteaccountmanager.h"
+#include "kopetebehaviorsettings.h"
 #include "kopetecommandhandler.h"
 #include "kopetecontactlist.h"
 #include "kopeteglobal.h"
-#include "kopetemimesourcefactory.h"
+#include "kopetefileengine.h"
 #include "kopetemimetypehandler.h"
 #include "kopetepluginmanager.h"
 #include "kopeteprotocol.h"
 #include "kopetestdaction.h"
 #include "kopeteuiglobal.h"
 #include "kopetewindow.h"
-#include "kopeteprefs.h"
 #include "kopeteviewmanager.h"
-#include "videodevice.h"
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "kopeteidentitymanager.h"
+#include "kopetedbusinterface.h"
 
 KopeteApplication::KopeteApplication()
-: KUniqueApplication( true, true, true )
+: KUniqueApplication( true, true )
 {
+	setQuitOnLastWindowClosed( false );
 	m_isShuttingDown = false;
-	m_mainWindow = new KopeteWindow( 0, "mainWindow" );
+
+	//Create the identity manager
+	Kopete::IdentityManager::self()->load();
+
+	m_mainWindow = new KopeteWindow( 0 );
 
 	Kopete::PluginManager::self();
 
@@ -72,7 +76,7 @@ KopeteApplication::KopeteApplication()
 	 * QApplication thinks the application shuts down (this is usually the case
 	 * when the loop_level goes down to zero) . So it emits aboutToQuit(), to
 	 * which KApplication is connected and re-emits shutdown() , to which again
-	 * KMainWindow (a KopeteWindow instance exists already) is connected. KMainWindow's
+	 * KXmlGuiWindow (a KopeteWindow instance exists already) is connected. KXmlGuiWindow's
 	 * shuttingDown() slot calls queryExit() which results in KopeteWindow::queryExit()
 	 * calling unloadPlugins() . This of course is wrong and just shouldn't happen.
 	 * The workaround is to simply delay the initialization of all this to a point
@@ -85,21 +89,23 @@ KopeteApplication::KopeteApplication()
 	 */
 	QTimer::singleShot( 0, this, SLOT( slotLoadPlugins() ) );
 
-	m_mimeFactory = new Kopete::MimeSourceFactory;
-	QMimeSourceFactory::addFactory( m_mimeFactory );
+	m_fileEngineHandler = new Kopete::FileEngineHandler();
 
 	//Create the emoticon installer
 	m_emoticonHandler = new Kopete::EmoticonMimeTypeHandler;
+
+	//Create the DBus interface for org.kde.kopete
+	new KopeteDBusInterface(this);
 }
 
 KopeteApplication::~KopeteApplication()
 {
-	kdDebug( 14000 ) << k_funcinfo << endl;
+	kDebug( 14000 ) ;
 
-	delete m_mainWindow;
+	delete m_fileEngineHandler;
 	delete m_emoticonHandler;
-	delete m_mimeFactory;
-	//kdDebug( 14000 ) << k_funcinfo << "Done" << endl;
+	delete m_mainWindow;
+	//kDebug( 14000 ) << "Done";
 }
 
 void KopeteApplication::slotLoadPlugins()
@@ -115,24 +121,25 @@ void KopeteApplication::slotLoadPlugins()
 	//Create the view manager
 	KopeteViewManager::viewManager();
 
+	// the account manager should be created after the identity manager is created
 	Kopete::AccountManager::self()->load();
 	Kopete::ContactList::self()->load();
 
-	KConfig *config = KGlobal::config();
+	KSharedConfig::Ptr config = KGlobal::config();
 
 	// Parse command-line arguments
 	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
 	bool showConfigDialog = false;
 
-	config->setGroup( "Plugins" );
+	KConfigGroup pluginsGroup = config->group( "Plugins" );
 
 	/* FIXME: This is crap, if something purged that groups but your accounts
 	 * are still working kopete will load the necessary plugins but still show the
 	 * stupid accounts dialog (of course empty at that time because account data
 	 * gets loaded later on). [mETz - 29.05.2004]
 	 */
-	if ( !config->hasGroup( "Plugins" ) )
+	if ( !pluginsGroup.exists() )
 		showConfigDialog = true;
 
 	// Listen to arguments
@@ -148,21 +155,19 @@ void KopeteApplication::slotLoadPlugins()
 	*/
 
 	// Prevent plugins from loading? (--disable=foo,bar)
-	QStringList disableArgs = QStringList::split( ',', args->getOption( "disable" ) );
-	for ( QStringList::ConstIterator it = disableArgs.begin(); it != disableArgs.end(); ++it )
+	foreach ( const QString &disableArg, args->getOption( "disable" ).split( ',' ))
 	{
 		showConfigDialog = false;
-		Kopete::PluginManager::self()->setPluginEnabled( *it, false );
+		Kopete::PluginManager::self()->setPluginEnabled( disableArg, false );
 	}
 
 	// Load some plugins exclusively? (--load-plugins=foo,bar)
 	if ( args->isSet( "load-plugins" ) )
 	{
-		config->deleteGroup( "Plugins", true );
+		pluginsGroup.deleteGroup( KConfigBase::Global );
 		showConfigDialog = false;
-		QStringList plugins = QStringList::split( ',', args->getOption( "load-plugins" ) );
-		for ( QStringList::ConstIterator it = plugins.begin(); it != plugins.end(); ++it )
-			Kopete::PluginManager::self()->setPluginEnabled( *it, true );
+		foreach ( const QString &plugin, args->getOption( "load-plugins" ).split( ',' ))
+			Kopete::PluginManager::self()->setPluginEnabled( plugin, true );
 	}
 
 	config->sync();
@@ -198,9 +203,9 @@ void KopeteApplication::slotLoadPlugins()
 		//        as it also allows for other features. - Martijn
 		// FIXME: Possibly we need to influence the showConfigDialog bool based on the
 		//        command line arguments processed below. But how exactly? - Martijn
-		// NB: the command line args are completely broken atm.  
+		// NB: the command line args are completely broken atm.
 		// I don't want to fix them for 3.5 as plugin loading will change for KDE4.	- Will
-		AddAccountWizard *m_addwizard = new AddAccountWizard( Kopete::UI::Global::mainWidget(), "addAccountWizard", true, true );
+		AddAccountWizard *m_addwizard = new AddAccountWizard( Kopete::UI::Global::mainWidget(), true );
 		m_addwizard->exec();
 		Kopete::AccountManager::self()->save();
 	}
@@ -210,29 +215,28 @@ void KopeteApplication::slotAllPluginsLoaded()
 {
 	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
+	//FIXME: this should probably ask for the identities to connect instead of all accounts
 	// --noconnect not specified?
-	if ( args->isSet( "connect" )  && KopetePrefs::prefs()->autoConnect() )
-		Kopete::AccountManager::self()->connectAll();
+	if ( args->isSet( "connect" )  && Kopete::BehaviorSettings::self()->autoConnect() &&
+			( Solid::Networking::status() == Solid::Networking::Unknown ||
+			  Solid::Networking::status() == Solid::Networking::Connected ) )
+		Kopete::AccountManager::self()->setOnlineStatus( Kopete::OnlineStatusManager::Online, QString(), Kopete::AccountManager::ConnectIfOffline );
 
+	QStringList connectArgs = args->getOptionList( "autoconnect" );
 
-	// Handle things like '--autoconnect foo,bar --autoconnect foobar'
-	QCStringList connectArgsC = args->getOptionList( "autoconnect" );
-	QStringList connectArgs;
+	// toConnect will contain all the protocols to connect to
+	QStringList toConnect;
 
-	for ( QCStringList::ConstIterator it = connectArgsC.begin(); it != connectArgsC.end(); ++it )
+	for ( QStringList::ConstIterator i = connectArgs.constBegin(); i != connectArgs.constEnd(); ++i )
 	{
-		QStringList split = QStringList::split( ',', QString::fromLatin1( *it ) );
-
-		for ( QStringList::ConstIterator it2 = split.begin(); it2 != split.end(); ++it2 )
-		{
-			connectArgs.append( *it2 );
-		}
+		foreach ( const QString connectArg, (*i).split(','))
+			toConnect.append( connectArg );
 	}
-	
-	for ( QStringList::ConstIterator i = connectArgs.begin(); i != connectArgs.end(); ++i )
+
+	for ( QStringList::ConstIterator i = toConnect.constBegin(); i != toConnect.constEnd(); ++i )
 	{
-		QRegExp rx( QString::fromLatin1( "([^\\|]*)\\|\\|(.*)" ) );
-		rx.search( *i );
+		QRegExp rx( QLatin1String( "([^\\|]*)\\|\\|(.*)" ) );
+		rx.indexIn( *i );
 		QString protocolId = rx.cap( 1 );
 		QString accountId = rx.cap( 2 );
 
@@ -244,12 +248,11 @@ void KopeteApplication::slotAllPluginsLoaded()
 				continue;
 		}
 
-		QPtrListIterator<Kopete::Account> it( Kopete::AccountManager::self()->accounts() );
+		QListIterator<Kopete::Account *> it( Kopete::AccountManager::self()->accounts() );
 		Kopete::Account *account;
-		while ( ( account = it.current() ) != 0 )
+		while ( it.hasNext() )
 		{
-			++it;
-
+			account = it.next();
 			if ( ( account->accountId() == accountId ) )
 			{
 				if ( protocolId.isEmpty() || account->protocol()->pluginId() == protocolId )
@@ -267,40 +270,22 @@ void KopeteApplication::slotAllPluginsLoaded()
 
 int KopeteApplication::newInstance()
 {
-//	kdDebug(14000) << k_funcinfo << endl;
+//	kDebug(14000) ;
 	handleURLArgs();
 
-	/**
-	 * The following three lines work around a problem that
-	 * Kopete has since it has multiple main windows so
-	 * qapp->mainWidget() returns 0, which breaks the normal
-	 * KUniqueApplication::newInstance() behavior that raises
-	 * the window when we run a new instance.
-	 *
-	 * 1. Set the main widget to the contact list window
-	 * 2. Call KUniqueApplication::newInstance()
-	 * 3. Set the main widget back to 0
-	 *
-	 * This little workaround fixes the problem. -Matt
-	 */
-
-	setMainWidget( m_mainWindow );
-	int kUniqAppReturnCode = KUniqueApplication::newInstance();
-	setMainWidget( 0L );
-
-	return kUniqAppReturnCode;
+	return KUniqueApplication::newInstance();
 }
 
 void KopeteApplication::handleURLArgs()
 {
 	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
-//	kdDebug(14000) << k_funcinfo << "called with " << args->count() << " arguments to handle." << endl;
+//	kDebug(14000) << "called with " << args->count() << " arguments to handle.";
 
 	if ( args->count() > 0 )
 	{
 		for ( int i = 0; i < args->count(); i++ )
 		{
-			KURL u( args->url( i ) );
+			KUrl u( args->url( i ) );
 			if ( !u.isValid() )
 				continue;
 
@@ -311,15 +296,16 @@ void KopeteApplication::handleURLArgs()
 
 void KopeteApplication::quitKopete()
 {
-	kdDebug( 14000 ) << k_funcinfo << endl;
+	kDebug( 14000 ) ;
 
 	m_isShuttingDown = true;
 
 	// close all windows
-	QPtrListIterator<KMainWindow> it(*KMainWindow::memberList);
-	for (it.toFirst(); it.current(); ++it)
+	QList<KMainWindow*> members = KMainWindow::memberList();
+	QList<KMainWindow*>::iterator it, itEnd = members.end();
+	for ( it = members.begin(); it != itEnd; ++it)
 	{
-		if ( !it.current()->close() )
+		if ( !(*it)->close() )
 		{
 			m_isShuttingDown = false;
 			break;
