@@ -1,9 +1,11 @@
 /*
     kopeteaccount.cpp - Kopete Account
 
-    Copyright (c) 2003-2005 by Olivier Goffart       <ogoffart@ kde.org>
+    Copyright (c) 2003-2005 by Olivier Goffart       <ogoffart@kde.org>
     Copyright (c) 2003-2004 by Martijn Klingens      <klingens@kde.org>
     Copyright (c) 2004      by Richard Smith         <kde@metafoo.co.uk>
+    Copyright (c) 2007         Will Stephenson       <wstephenson@kde.org>
+
     Kopete    (c) 2002-2005 by the Kopete developers <kopete-devel@kde.org>
 
     *************************************************************************
@@ -17,30 +19,37 @@
 */
 
 #include <qapplication.h>
-#include <qtimer.h>
+#include <QTimer>
+#include <QPixmap>
+#include <QIcon>
 
 #include <kconfig.h>
 #include <kdebug.h>
+#include <kdialog.h>
 #include <kdeversion.h>
-#include <kdialogbase.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kiconeffect.h>
+#include <kicon.h>
 #include <kaction.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kmessagebox.h>
-#include <knotifyclient.h>
+#include <kcomponentdata.h>
+#include <kactionmenu.h>
+#include <kconfiggroup.h>
 
+#include "kopeteaccount.h"
+#include "kopeteidentity.h"
+#include "kopeteidentitymanager.h"
 #include "kabcpersistence.h"
 #include "kopetecontactlist.h"
-#include "kopeteaccount.h"
 #include "kopeteaccountmanager.h"
 #include "kopetecontact.h"
 #include "kopetemetacontact.h"
 #include "kopeteprotocol.h"
 #include "kopetepluginmanager.h"
 #include "kopetegroup.h"
-#include "kopeteprefs.h"
+#include "kopetebehaviorsettings.h"
 #include "kopeteutils.h"
 #include "kopeteuiglobal.h"
 #include "kopeteblacklister.h"
@@ -56,10 +65,10 @@ class Account::Private
 public:
 	Private( Protocol *protocol, const QString &accountId )
 	 : protocol( protocol ), id( accountId )
-	 , excludeconnect( true ), priority( 0 ), myself( 0 )
+	 , excludeconnect( true ), priority( 0 )
+	 , connectionTry(0), identity( 0 ), myself( 0 )
 	 , suppressStatusTimer( 0 ), suppressStatusNotification( false )
 	 , blackList( new Kopete::BlackLister( protocol->pluginId(), accountId ) )
-	 , connectionTry(0)
 	{ }
 
 
@@ -70,28 +79,29 @@ public:
 	QString accountLabel;
 	bool excludeconnect;
 	uint priority;
-	QDict<Contact> contacts;
+	QHash<QString, Contact*> contacts;
 	QColor color;
+	uint connectionTry;
+	Identity *identity;
 	Contact *myself;
 	QTimer suppressStatusTimer;
 	bool suppressStatusNotification;
 	Kopete::BlackLister *blackList;
 	KConfigGroup *configGroup;
-	uint connectionTry;
 	QString customIcon;
 	Kopete::OnlineStatus restoreStatus;
 	QString restoreMessage;
 };
 
-Account::Account( Protocol *parent, const QString &accountId, const char *name )
- : QObject( parent, name ), d( new Private( parent, accountId ) )
+Account::Account( Protocol *parent, const QString &accountId )
+ : QObject( parent ), d( new Private( parent, accountId ) )
 {
 	d->configGroup=new KConfigGroup(KGlobal::config(), QString::fromLatin1( "Account_%1_%2" ).arg( d->protocol->pluginId(), d->id ));
 
-	d->excludeconnect = d->configGroup->readBoolEntry( "ExcludeConnect", false );
-	d->color = d->configGroup->readColorEntry( "Color", &d->color );
+	d->excludeconnect = d->configGroup->readEntry( "ExcludeConnect", false );
+	d->color = d->configGroup->readEntry( "Color" , QColor() );
 	d->customIcon = d->configGroup->readEntry( "Icon", QString() );
-	d->priority = d->configGroup->readNumEntry( "Priority", 0 );
+	d->priority = d->configGroup->readEntry( "Priority", 0 );
 
 	d->restoreStatus = Kopete::OnlineStatus::Online;
 	d->restoreMessage = "";
@@ -103,12 +113,12 @@ Account::Account( Protocol *parent, const QString &accountId, const char *name )
 Account::~Account()
 {
 	d->contacts.remove( d->myself->contactId() );
-	
 	// Delete all registered child contacts first
-	while ( !d->contacts.isEmpty() )
-		delete *QDictIterator<Contact>( d->contacts );
+	foreach (Contact* c, d->contacts) QObject::disconnect(c, SIGNAL( contactDestroyed( Kopete::Contact * ) ), this, 0);
+	qDeleteAll(d->contacts);
+	d->contacts.clear();
 
-	kdDebug( 14010 ) << k_funcinfo << " account '" << d->id << "' about to emit accountDestroyed " << endl;
+	kDebug( 14010 ) << " account '" << d->id << "' about to emit accountDestroyed ";
 	emit accountDestroyed(this);
 
 	delete d->myself;
@@ -118,19 +128,19 @@ Account::~Account()
 
 void Account::reconnect()
 {
-	kdDebug( 14010 ) << k_funcinfo << "account " << d->id << " restoreStatus " << d->restoreStatus.status() << " restoreMessage " << d->restoreMessage << endl;
+	kDebug( 14010 ) << "account " << d->id << " restoreStatus " << d->restoreStatus.status() << " restoreMessage " << d->restoreMessage;
 	setOnlineStatus( d->restoreStatus, d->restoreMessage );
 }
 
 void Account::disconnected( DisconnectReason reason )
 {
-	kdDebug( 14010 ) << k_funcinfo << reason << endl;
+	kDebug( 14010 ) << reason;
 	//reconnect if needed
 	if(reason == BadPassword )
 	{
 		QTimer::singleShot(0, this, SLOT(reconnect()));
 	}
-	else if ( KopetePrefs::prefs()->reconnectOnDisconnect() == true && reason > Manual )
+	else if ( Kopete::BehaviorSettings::self()->reconnectOnDisconnect() == true && reason > Manual )
 	{
 		d->connectionTry++;
 		//use a timer to allow the plugins to clean up after return
@@ -139,7 +149,7 @@ void Account::disconnected( DisconnectReason reason )
 	}
 	if(reason== OtherClient)
 	{
-		Kopete::Utils::notifyConnectionLost(this, i18n("You have been disconnected"), i18n( "You have connected from another client or computer to the account '%1'" ).arg(d->id), i18n("Most proprietary Instant Messaging services do not allow you to connect from more than one location. Check that nobody is using your account without your permission. If you need a service that supports connection from various locations at the same time, use the Jabber protocol."));
+		Kopete::Utils::notifyConnectionLost(this, i18n("You have been disconnected"), i18n( "You have connected from another client or computer to the account '%1'" , d->id), i18n("Most proprietary Instant Messaging services do not allow you to connect from more than one location. Check that nobody is using your account without your permission. If you need a service that supports connection from various locations at the same time, use the Jabber protocol."));
 	}
 }
 
@@ -183,10 +193,10 @@ uint Account::priority() const
 QPixmap Account::accountIcon(const int size) const
 {
 	QString icon= d->customIcon.isEmpty() ? d->protocol->pluginIcon() : d->customIcon;
-	
+
 	// FIXME: this code is duplicated with OnlineStatus, can we merge it somehow?
-	QPixmap base = KGlobal::instance()->iconLoader()->loadIcon(
-		icon, KIcon::Small, size );
+	QPixmap base = KIconLoader::global()->loadIcon(
+		icon, KIconLoader::Small, size );
 
 	if ( d->color.isValid() )
 	{
@@ -196,7 +206,7 @@ QPixmap Account::accountIcon(const int size) const
 
 	if ( size > 0 && base.width() != size )
 	{
-		base = QPixmap( base.convertToImage().smoothScale( size, size ) );
+		base.scaled( size, size, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
 	}
 
 	return base;
@@ -243,7 +253,7 @@ void Account::contactDestroyed( Contact *c )
 }
 
 
-const QDict<Contact>& Account::contacts()
+const QHash<QString, Contact*>& Account::contacts()
 {
 	return d->contacts;
 }
@@ -255,11 +265,11 @@ Kopete::MetaContact* Account::addContact( const QString &contactId, const QStrin
 	if ( contactId == d->myself->contactId() )
 	{
 		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error,
-			i18n("You are not allowed to add yourself to the contact list. The addition of \"%1\" to account \"%2\" will not take place.").arg(contactId,accountId()), i18n("Error Creating Contact")
+			i18n("You are not allowed to add yourself to the contact list. The addition of \"%1\" to account \"%2\" will not take place.", contactId, accountId()), i18n("Error Creating Contact")
 		);
 		return false;
 	}
- 
+
 	bool isTemporary = mode == Temporary;
 
 	Contact *c = d->contacts[ contactId ];
@@ -271,7 +281,7 @@ Kopete::MetaContact* Account::addContact( const QString &contactId, const QStrin
 	{
 		if ( c->metaContact()->isTemporary() && !isTemporary )
 		{
-			kdDebug( 14010 ) << k_funcinfo <<  " You are trying to add an existing temporary contact. Just add it on the list" << endl;
+			kDebug( 14010 ) <<  " You are trying to add an existing temporary contact. Just add it on the list";
 
 			c->metaContact()->setTemporary(false, group );
 			ContactList::self()->addMetaContact(c->metaContact());
@@ -279,7 +289,7 @@ Kopete::MetaContact* Account::addContact( const QString &contactId, const QStrin
 		else
 		{
 			// should we here add the contact to the parentContact if any?
-			kdDebug( 14010 ) << k_funcinfo << "Contact already exists" << endl;
+			kDebug( 14010 ) << "Contact already exists";
 		}
 		return c->metaContact();
 	}
@@ -299,7 +309,7 @@ Kopete::MetaContact* Account::addContact( const QString &contactId, const QStrin
 		c->setMetaContact( parentContact );
 		if ( mode == ChangeKABC )
 		{
-			kdDebug( 14010 ) << k_funcinfo << " changing KABC" << endl;
+			kDebug( 14010 ) << " changing KABC";
 			KABCPersistence::self()->write( parentContact );
 		}
 	}
@@ -321,7 +331,7 @@ bool Account::addContact(const QString &contactId , MetaContact *parent, AddMode
 	if ( contactId == myself()->contactId() )
 	{
 	    	KMessageBox::error( Kopete::UI::Global::mainWidget(),
-			i18n("You are not allowed to add yourself to the contact list. The addition of \"%1\" to account \"%2\" will not take place.").arg(contactId,accountId()), i18n("Error Creating Contact")
+			i18n("You are not allowed to add yourself to the contact list. The addition of \"%1\" to account \"%2\" will not take place.", contactId, accountId()), i18n("Error Creating Contact")
 		);
 		return 0L;
 	}
@@ -332,7 +342,7 @@ bool Account::addContact(const QString &contactId , MetaContact *parent, AddMode
 	{
 		if ( c->metaContact()->isTemporary() && !isTemporary )
 		{
-			kdDebug( 14010 ) <<
+			kDebug( 14010 ) <<
 				"Account::addContact: You are trying to add an existing temporary contact. Just add it on the list" << endl;
 
 				//setMetaContact ill take care about the deletion of the old contact
@@ -342,7 +352,7 @@ bool Account::addContact(const QString &contactId , MetaContact *parent, AddMode
 		else
 		{
 			// should we here add the contact to the parentContact if any?
-			kdDebug( 14010 ) << "Account::addContact: Contact already exists" << endl;
+			kDebug( 14010 ) << "Account::addContact: Contact already exists";
 		}
 		return false; //(the contact is not in the correct metacontact, so false)
 	}
@@ -351,30 +361,44 @@ bool Account::addContact(const QString &contactId , MetaContact *parent, AddMode
 
 	if ( success && mode == ChangeKABC )
 	{
-		kdDebug( 14010 ) << k_funcinfo << " changing KABC" << endl;
+		kDebug( 14010 ) << " changing KABC";
 		KABCPersistence::self()->write( parent );
 	}
 
 	return success;
 }
 
-KActionMenu * Account::actionMenu()
+void Account::fillActionMenu( KActionMenu *actionMenu )
 {
 	//default implementation
-	KActionMenu *menu = new KActionMenu( accountId(), myself()->onlineStatus().iconFor( this ),  this );
-	QString nick = myself()->property( Kopete::Global::Properties::self()->nickName()).value().toString();
+// 	KActionMenu *menu = new KActionMenu( QIcon(myself()->onlineStatus().iconFor( this )), accountId(), 0, 0);
+#ifdef __GNUC__
+#warning No icon shown, we should go away from QPixmap genered icons with overlays.
+#endif
+	QString nick;
+       	if (identity()->hasProperty( Kopete::Global::Properties::self()->nickName().key() ))
+		nick = identity()->property( Kopete::Global::Properties::self()->nickName() ).value().toString();
+	else
+		nick = myself()->nickName();
 
-	menu->popupMenu()->insertTitle( myself()->onlineStatus().iconFor( myself() ),
-		nick.isNull() ? accountLabel() : i18n( "%2 <%1>" ).arg( accountLabel(), nick )
+	// Always add title at the beginning of actionMenu
+	QAction *before = actionMenu->menu()->actions().value( 0, 0 );
+	actionMenu->menu()->addTitle( myself()->onlineStatus().iconFor( myself() ),
+		nick.isNull() ? accountLabel() : i18n( "%2 <%1>", accountLabel(), nick ),
+		before
 	);
 
-	OnlineStatusManager::self()->createAccountStatusActions(this, menu);
-	menu->popupMenu()->insertSeparator();
-	menu->insert( new KAction ( i18n( "Properties" ),  0, this, SLOT( editAccount() ), menu, "actionAccountProperties" ) );
+	actionMenu->menu()->addSeparator();
 
-	return menu;
+	KAction *propertiesAction = new KAction( i18n("Properties"), actionMenu );
+	QObject::connect( propertiesAction, SIGNAL(triggered(bool)), this, SLOT( editAccount() ) );
+	actionMenu->addAction( propertiesAction );
 }
 
+bool Account::hasCustomStatusMenu() const
+{
+	return false;
+}
 
 bool Account::isConnected() const
 {
@@ -385,6 +409,28 @@ bool Account::isAway() const
 {
 	return d->myself && ( d->myself->onlineStatus().status() == Kopete::OnlineStatus::Away );
 }
+Identity * Account::identity() const
+{
+	return d->identity;
+}
+
+bool Account::setIdentity( Identity *ident )
+{
+	if ( d->identity == ident )
+	{
+		return false;
+	}
+
+	if (d->identity)
+	{
+		d->identity->removeAccount( this );
+	}
+
+	ident->addAccount( this );
+	d->identity = ident;
+	d->configGroup->writeEntry("Identity", ident->id());
+	return true;
+}
 
 Contact * Account::myself() const
 {
@@ -393,24 +439,26 @@ Contact * Account::myself() const
 
 void Account::setMyself( Contact *myself )
 {
+	//FIXME  does it make sens to change the myself contact to another ?   - Olivier 2005-11-21
+
 	bool wasConnected = isConnected();
 
 	if ( d->myself )
 	{
 		QObject::disconnect( d->myself, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
 			this, SLOT( slotOnlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
-		QObject::disconnect( d->myself, SIGNAL( propertyChanged( Kopete::Contact *, const QString &, const QVariant &, const QVariant & ) ),
-			this, SLOT( slotContactPropertyChanged( Kopete::Contact *, const QString &, const QVariant &, const QVariant & ) ) );
+		QObject::disconnect( d->myself, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ),
+			this, SLOT( slotContactPropertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ) );
 	}
 
 	d->myself = myself;
 
 //	d->contacts.remove( myself->contactId() );
-	
+
 	QObject::connect( d->myself, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
 		this, SLOT( slotOnlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
-	QObject::connect( d->myself, SIGNAL( propertyChanged( Kopete::Contact *, const QString &, const QVariant &, const QVariant & ) ),
-		this, SLOT( slotContactPropertyChanged( Kopete::Contact *, const QString &, const QVariant &, const QVariant & ) ) );
+	QObject::connect( d->myself, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ),
+		this, SLOT( slotContactPropertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ) );
 
 	if ( isConnected() != wasConnected )
 		emit isConnectedChanged();
@@ -431,18 +479,19 @@ void Account::slotOnlineStatusChanged( Contact * /* contact */,
 		// contact list's size, the protocol you are using, your internet
 		// connection's speed and your computer's speed you *will* need it.
 		d->suppressStatusNotification = true;
-		d->suppressStatusTimer.start( 5000, true );
+		d->suppressStatusTimer.setSingleShot( true );
+		d->suppressStatusTimer.start( 5000 );
 		//the timer is also used to reset the d->connectionTry
 	}
 
 	if ( !isOffline )
 	{
 		d->restoreStatus = newStatus;
-		d->restoreMessage = myself()->property( Kopete::Global::Properties::self()->awayMessage() ).value().toString();
-//		kdDebug( 14010 ) << k_funcinfo << "account " << d->id << " restoreStatus " << d->restoreStatus.status() << " restoreMessage " << d->restoreMessage << endl;
+		d->restoreMessage = identity()->property( Kopete::Global::Properties::self()->statusMessage() ).value().toString();
+//		kDebug( 14010 ) << "account " << d->id << " restoreStatus " << d->restoreStatus.status() << " restoreMessage " << d->restoreMessage;
 	}
 
-/*	kdDebug(14010) << k_funcinfo << "account " << d->id << " changed status. was "
+/*	kDebug(14010) << "account " << d->id << " changed status. was "
 	               << Kopete::OnlineStatus::statusTypeToString(oldStatus.status()) << ", is "
 	               << Kopete::OnlineStatus::statusTypeToString(newStatus.status()) << endl;*/
 	if ( wasOffline != isOffline )
@@ -452,20 +501,24 @@ void Account::slotOnlineStatusChanged( Contact * /* contact */,
 void Account::setAllContactsStatus( const Kopete::OnlineStatus &status )
 {
 	d->suppressStatusNotification = true;
-	d->suppressStatusTimer.start( 5000, true );
+	d->suppressStatusTimer.setSingleShot( true );
+	d->suppressStatusTimer.start( 5000 );
 
-	for ( QDictIterator<Contact> it( d->contacts ); it.current(); ++it )
-		if ( it.current() != d->myself )
-			it.current()->setOnlineStatus( status );
+	QHashIterator<QString, Contact*> it(d->contacts);
+	for (  ; it.hasNext(); ) {
+		it.next();
+		if ( it.value() != d->myself )
+			it.value()->setOnlineStatus( status );
+	}
 }
 
-void Account::slotContactPropertyChanged( Contact * /* contact */,
+void Account::slotContactPropertyChanged( PropertyContainer * /* contact */,
 	const QString &key, const QVariant &old, const QVariant &newVal )
 {
-	if ( key == QString::fromLatin1("awayMessage") && old != newVal && isConnected() )
+	if ( key == Kopete::Global::Properties::self()->statusMessage().key() && old != newVal && isConnected() )
 	{
 		d->restoreMessage = newVal.toString();
-//		kdDebug( 14010 ) << k_funcinfo << "account " << d->id << " restoreMessage " << d->restoreMessage << endl;
+//		kDebug( 14010 ) << "account " << d->id << " restoreMessage " << d->restoreMessage;
 	}
 }
 
@@ -510,9 +563,9 @@ bool Account::isBlocked( const QString &contactId )
 
 void Account::editAccount(QWidget *parent)
 {
-	KDialogBase *editDialog = new KDialogBase( parent, "KopeteAccountConfig::editDialog", true,
-						   i18n( "Edit Account" ), KDialogBase::Ok | KDialogBase::Cancel,
-						   KDialogBase::Ok, true );
+	KDialog *editDialog = new KDialog( parent );
+	editDialog->setCaption( i18n( "Edit Account" ) );
+	editDialog->setButtons( KDialog::Ok | KDialog::Apply | KDialog::Cancel );
 
 	KopeteEditAccountWidget *m_accountWidget = protocol()->createEditAccountWidget( this, editDialog );
 	if ( !m_accountWidget )
@@ -538,21 +591,6 @@ void Account::editAccount(QWidget *parent)
 	editDialog->deleteLater();
 }
 
-void Account::setPluginData( Plugin* /*plugin*/, const QString &key, const QString &value )
-{
-	configGroup()->writeEntry(key,value);
-}
-
-QString Account::pluginData( Plugin* /*plugin*/, const QString &key ) const
-{
-	return configGroup()->readEntry(key);
-}
-
-void Account::setAway(bool away, const QString& reason)
-{
-	setOnlineStatus( OnlineStatusManager::self()->onlineStatus(protocol() , away ? OnlineStatusManager::Away : OnlineStatusManager::Online)  , reason );
-}
-
 void Account::setCustomIcon( const QString & i)
 {
 	d->customIcon = i;
@@ -568,14 +606,7 @@ QString Account::customIcon()  const
 	return d->customIcon;
 }
 
-void Account::virtual_hook( uint /*id*/, void* /*data*/)
-{
-}
-
-
-
-}
-
- //END namespace Kopete
+} // END namespace Kopete
 
 #include "kopeteaccount.moc"
+
