@@ -1,10 +1,12 @@
 /*
     kopeteaccount.h - Kopete Account
 
-    Copyright (c) 2003-2004 by Olivier Goffart       <ogoffart@ tiscalinet.be>
+    Copyright (c) 2007      by Gustavo Pichorim Boiko <gustavo.boiko@kdemail.net>
+    Copyright (c) 2003-2005 by Olivier Goffart       <ogoffart@kde.org>
     Copyright (c) 2003-2004 by Martijn Klingens      <klingens@kde.org>
     Copyright (c) 2004      by Richard Smith         <kde@metafoo.co.uk>
-    Kopete    (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
+
+    Kopete    (c) 2002-2007 by the Kopete developers <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -20,25 +22,29 @@
 #define KOPETEACCOUNT_H
 
 #include "kopeteonlinestatus.h"
-
+#include "kopetestatusmessage.h"
 #include "kopete_export.h"
 
-#include <qobject.h>
-#include <qdict.h>
+#include <QtCore/QObject>
+#include <QtGui/QPixmap>
+#include <QtCore/QHash>
+
+#include <kconfiggroup.h>
 
-class QDomNode;
 class KActionMenu;
 class KConfigGroup;
 
 namespace Kopete
 {
 class Contact;
-class Plugin;
 class Protocol;
 class MetaContact;
 class Group;
 class OnlineStatus;
 class BlackLister;
+class StatusMessage;
+class Identity;
+class PropertyContainer;
 
 /**
  * The Kopete::Account class handles one account.
@@ -61,7 +67,7 @@ class BlackLister;
  * When you create a new account, you have to register it with the account manager by calling
  * @ref AccountManager::registerAccount.
  *
- * @author Olivier Goffart  <ogoffart@tiscalinet.be>
+ * @author Olivier Goffart  <ogoffart\@kde.org>
  */
 class KOPETE_EXPORT Account : public QObject
 {
@@ -96,13 +102,23 @@ public:
 		Unknown = 99         ///< the reason for disconnection is unknown
 	};
 
+	/**
+	 * \brief Describes what should be done when the contact is added to a metacontact
+	 * @sa @ref addContact()
+	 */
+	enum AddMode {
+		ChangeKABC = 0,     ///< The KDE Address book may be updated
+		DontChangeKABC = 1, ///< The KDE Address book will not be changed
+		Temporary = 2       ///< The contact will not be added on the contact list
+	};
+
 	/**
 	 * @param parent the protocol for this account. The account is a child object of the
 	 * protocol, so it will be automatically deleted when the protocol is.
 	 * @param accountID the unique ID of this account.
 	 * @param name the name of this QObject.
 	 */
-	Account(Protocol *parent, const QString &accountID, const char *name=0L);
+	Account(Protocol *parent, const QString &accountID);
 	~Account();
 
 	/**
@@ -177,6 +193,44 @@ public:
 	 * @return the icon for this account, colored if needed
 	 */
 	QPixmap accountIcon( const int size = 0 ) const;
+	
+	/**
+	 * \brief change the account icon.
+	 * by default the icon of an account is the protocol one, but it may be overide it.
+	 * Set QString() to go back to the default  (the protocol icon)
+	 * 
+	 * this call will emit colorChanged()
+	 */
+	void setCustomIcon( const QString& );
+	
+	/**
+	 * \brief return the icon base
+	 * This is the custom account icon set with setIcon.   if this icon is null, then the protocol icon is used
+	 * don't use this function to get the icon that need to be displayed, use accountIcon
+	 */
+	QString customIcon() const;
+	
+	/**
+	 * \brief Retrieve the identity this account belongs to
+	 *
+	 * \return a pointer to the Identity object this account belongs to.
+	 *
+	 * \see setIdentity().
+	 */
+	Identity * identity() const;
+
+	/**
+	 * \brief Sets the identity this account belongs to
+	 *
+	 * Setting the account to a new identity implies it to be removed from the 
+	 * identity it was previously associated.
+	 *
+	 * @param ident The identity this account should be associated to
+	 * \return @c true if the identity was changed, @c false otherwise
+	 *
+	 * @note You should call the default implementation from your reimplementation
+	 */
+	virtual bool setIdentity( Kopete::Identity *ident );
 
 	/**
 	 * \brief Retrieve the 'myself' contact.
@@ -188,9 +242,9 @@ public:
 	Contact * myself() const;
 
 	/**
-	 * @brief Return the menu for this account
+	 * @brief Fill the menu with actions for this account
 	 *
-	 * You have to reimplement this method to return the custom action menu which will
+	 * You have to reimplement this method to add custom actions to the @p actionMenu which will
 	 * be shown in the statusbar. It is the caller's responsibility to ensure the menu is deleted.
 	 *
 	 * The default implementation provides a generic menu, with actions generated from the protocol's
@@ -201,7 +255,17 @@ public:
 	 *
 	 * @see OnlineStatusManager::registerOnlineStatus
 	 */
-	virtual KActionMenu* actionMenu() ;
+	virtual void fillActionMenu( KActionMenu *actionMenu );
+
+	/**
+	 * @brief Return true if account has custom status menu.
+	 *
+	 * You have to reimplement this method and return true if you don't want to have status menu in menu
+	 * which will be shown in the statusbar
+	 *
+	 * The default implementation returns false.
+	 */
+	virtual bool hasCustomStatusMenu() const;
 
 	/**
 	 * @brief Retrieve the list of contacts for this account
@@ -210,7 +274,7 @@ public:
 	 * so you can safely use static_cast to your own derived contact class
 	 * if needed.
 	 */
-	const QDict<Contact>& contacts();
+	const QHash<QString,Contact*>& contacts();
 
 	/**
 	 * Indicates whether or not we should suppress status notifications
@@ -223,16 +287,6 @@ public:
 	 */
 	bool suppressStatusNotification() const;
 
-	/**
-	 * \brief Describes what should be done when the contact is added to a metacontact
-	 * @sa @ref addContact()
-	 */
-	enum AddMode {
-		ChangeKABC = 0,     ///< The KDE Address book may be updated
-		DontChangeKABC = 1, ///< The KDE Address book will not be changed
-		Temporary = 2       ///< The contact will not be added on the contactlist
-	};
-
 	/**
 	 * \brief Create a contact (creating a new metacontact if necessary)
 	 *
@@ -245,13 +299,13 @@ public:
 	 * If @p mode is @c DontChangeKABC, no additional action is carried out.
 	 *
 	 * @param contactId the @ref Contact::contactId of the contact to create
-	 * @param displayName the displayname (alias) of the new metacontact. Leave as QString::null if
+	 * @param displayName the displayname (alias) of the new metacontact. Leave as QString() if
 	 *                    no alias is known, then by default, the nick will be taken as alias and tracked if changed.
 	 * @param group the group to add the created metacontact to, or 0 for the top-level group.
 	 * @param mode the mode used to add the contact. Use DontChangeKABC when deserializing.
 	 * @return the new created metacontact or 0L if the operation failed
 	 */
-	MetaContact* addContact( const QString &contactId, const QString &displayName = QString::null, Group *group = 0, AddMode mode = DontChangeKABC ) ;
+	MetaContact* addContact( const QString &contactId, const QString &displayName = QString(), Group *group = 0, AddMode mode = DontChangeKABC );
 
 	/**
 	 * @brief Create a new contact, adding it to an existing metacontact
@@ -289,8 +343,10 @@ public:
 	/**
 	 * Return the @ref KConfigGroup used to write and read special properties
 	 *
-	 * "Protocol", "AccountId" , "Color", "AutoConnect", "Priority", "Enabled" are reserved keyword
+	 * "Protocol", "AccountId" , "Color", "AutoConnect", "Priority", "Enabled" , "Icon" are reserved keyword
 	 * already in use in that group.
+	 * 
+	 * for compatibility, try to not use key that start with a uppercase
 	 */
 	KConfigGroup *configGroup() const;
 
@@ -311,11 +367,13 @@ public:
 
 	/**
 	 * \return a pointer to the blacklist of the account
+	 * @todo remove or implement correctly (BlackLister)
 	 */
 	BlackLister* blackLister();
 
 	/**
 	 * \return @c true if the contact with ID @p contactId is in the blacklist, @c false otherwise.
+	 * @todo remove or implement correctly (BlackLister)
 	 */
 	virtual bool isBlocked( const QString &contactId );
 
@@ -392,6 +450,9 @@ protected slots:
 signals:
 	/**
 	 * The color of the account has been changed
+	 * 
+	 * also emitted when the icon change
+	 * @todo  probably rename to accountIconChanged
 	 */
 	void colorChanged( const QColor & );
 
@@ -427,6 +488,7 @@ public slots:
 	 *
 	 * @param initialStatus is the status to connect with. If it is an invalid status for this
 	 * account, the default online for the account should be used.
+	 * @todo probably deprecate in favor of setOnlineStatus
 	 */
 	virtual void connect( const Kopete::OnlineStatus& initialStatus = OnlineStatus() ) = 0;
 
@@ -436,25 +498,24 @@ public slots:
 	 * If the service is connecting, you should abort the connection.
 	 *
 	 * You should call the @ref disconnected function from this function.
+	 * @todo  probably deprecate in favor of setOnlineStatus
 	 */
 	virtual void disconnect( ) = 0 ;
 
 public slots:
-	/**
-	 * If @p away is @c true, set the account away with away message @p reason. Otherwise,
-	 * set the account to not be away.
-	 *
-	 * @todo change ; make use of setOnlineStatus
-	 */
-	virtual void setAway( bool away, const QString &reason = QString::null );
-
 	/**
 	 * Reimplement this function to set the online status
 	 * @param status is the new status
-	 * @param reason is the away message to set.
+	 * @param reason is the status message to set.
 	 * @note If needed, you need to connect.  if the offline status is given, you should disconnect
 	 */
-	virtual void setOnlineStatus( const Kopete::OnlineStatus& status , const QString &reason = QString::null ) = 0;
+	virtual void setOnlineStatus( const Kopete::OnlineStatus& status , const Kopete::StatusMessage &reason = Kopete::StatusMessage() ) = 0;
+	/**
+	 * Reimplement this function to set the status message(with metadata).
+	 * You should use this method to set the status message instead of using setOnlineStatus.
+	 * @param statusMessage is the status message to set. (Use Kopete::StatusMessage).
+	 */
+	virtual void setStatusMessage( const Kopete::StatusMessage &statusMessage ) = 0;
 
 	/**
 	 * Display the edit account widget for the account
@@ -466,6 +527,7 @@ public slots:
 	 * blackList()->addContact( contactId )
 	 *
 	 * @param contactId the contact to be added to the blacklist
+	 * @todo remove or implement correctly (BlackLister)
 	 */
 	virtual void block( const QString &contactId );
 
@@ -474,10 +536,16 @@ public slots:
 	 * blackList()->removeContact( contactId )
 	 *
 	 * @param contactId the contact to be removed from the blacklist
+	 * @todo remove or implement correctly (BlackLister)
 	 */
 	virtual void unblock( const QString &contactId );
 
 private slots:
+	/**
+	 * Restore online status and status message on reconnect.
+	 */
+	virtual void reconnect(); 
+
 	/**
 	 * Track the deletion of a Contact and clean up
 	 */
@@ -488,6 +556,11 @@ private slots:
 	 */
 	void slotOnlineStatusChanged( Kopete::Contact *contact, const Kopete::OnlineStatus &newStatus, const Kopete::OnlineStatus &oldStatus );
 
+	/**
+	 * The @ref myself() contact's property changed.
+	 */
+	void slotContactPropertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & );
+
 	/**
 	 * Stop the suppression of status notification (connected to a timer)
 	 */
@@ -496,22 +569,6 @@ private slots:
 private:
 	class Private;
 	Private *d;
-
-protected:
-	virtual void virtual_hook( uint id, void* data);
-
-public:
-	/**
-	 * @todo remove
-	 * @deprecated  use configGroup
-	 */
-	void setPluginData( Plugin* /*plugin*/, const QString &key, const QString &value ) KDE_DEPRECATED;
-
-	/**
-	 * @todo remove
-	 * @deprecated  use configGroup
-	 */
-	QString pluginData( Plugin* /*plugin*/, const QString &key ) const KDE_DEPRECATED;
 };
 
 } //END namespace Kopete
