@@ -1,7 +1,7 @@
 /*
     kopetefileconfirmdialog.h
 
-    Copyright (c) 2003 by Olivier Goffart <ogoffart @ kde.org>
+    Copyright (c) 2003      by Olivier Goffart <ogoffart@kde.org>
 
     Kopete    (c) 2002-2003 by the Kopete developers  <kopete-devel@kde.org>
 
@@ -18,36 +18,33 @@
 #ifndef KOPETEFILECONFIRMDIALOG_H
 #define KOPETEFILECONFIRMDIALOG_H
 
-#include <qwidget.h>
-#include <kdialogbase.h>
-#include "kopetetransfermanager.h"
+#include <QtGui/QWidget>
 
-class FileConfirmBase;
+#include <kdialog.h>
+#include "kopetetransfermanager.h"
+#include "ui_fileconfirmbase.h"
 
 /**
-  *@author Olivier Goffart
-  */
-
-class KopeteFileConfirmDialog : public KDialogBase
+ * @author Olivier Goffart
+ */
+class KopeteFileConfirmDialog : public KDialog, private Ui::FileConfirmBase
 {
 Q_OBJECT
 
 public:
-	KopeteFileConfirmDialog(const Kopete::FileTransferInfo &info,const QString& description=QString::null, QWidget *parent=0, const char* name=0);
+	explicit KopeteFileConfirmDialog( const Kopete::FileTransferInfo &info,
+	                         const QString& description = QString(),
+	                         QWidget *parent = 0 );
 	~KopeteFileConfirmDialog();
-
+	
 private:
-	FileConfirmBase* m_view;
+	QWidget* m_view;
 	Kopete::FileTransferInfo m_info;
 	bool m_emited;
 
 public slots:
 	void slotBrowsePressed();
-
-protected slots:
-	virtual void slotUser2();
-	virtual void slotUser1();
-	virtual void closeEvent( QCloseEvent *e);
+	virtual void accept();
 
 signals:
 	void accepted(const Kopete::FileTransferInfo &info, const QString &filename);
