@@ -16,9 +16,7 @@
     *************************************************************************
 */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <config-kopete.h>
 
 #include "kopetecontact.h"
 #include "kopetelistviewitem.h"
@@ -32,16 +30,12 @@
 #include <qapplication.h>
 #include <qpixmap.h>
 #include <qpainter.h>
-#include <qptrlist.h>
 #include <qrect.h>
 #include <qtimer.h>
-#include <qheader.h>
+#include <q3header.h>
 #include <qstyle.h>
-
-#ifdef HAVE_XRENDER
-#  include <X11/Xlib.h>
-#  include <X11/extensions/Xrender.h>
-#endif
+#include <qstyleoption.h>
+#include <QList>
 
 #include <limits.h>
 
@@ -54,7 +48,7 @@ namespace ListView {
 class ComponentBase::Private
 {
 public:
-	QPtrList<Component> components;
+	QList<Component*> components;
 };
 
 ComponentBase::ComponentBase()
@@ -64,22 +58,30 @@ ComponentBase::ComponentBase()
 
 ComponentBase::~ComponentBase()
 {
-	d->components.setAutoDelete( true );
+	foreach( Component *c , d->components )
+		delete c;
 	delete d;
 }
 
 uint ComponentBase::components() { return d->components.count(); }
-Component *ComponentBase::component( uint n ) { return d->components.at( n ); }
+
+Component *ComponentBase::component( uint n )
+{
+	if( n < components() )
+		return d->components.at( n );
+	return 0l;
+
+}
 
 Component *ComponentBase::componentAt( const QPoint &pt )
 {
-	for ( uint n = 0; n < components(); ++n )
+	foreach( Component* n , d->components )
 	{
-		if ( component( n )->rect().contains( pt ) )
+		if ( n->rect().contains( pt ) )
 		{
-			if ( Component *comp = component( n )->componentAt( pt ) )
+			if ( Component *comp = n->componentAt( pt ) )
 				return comp;
-			return component( n );
+			return n;
 		}
 	}
 	return 0;
@@ -94,19 +96,14 @@ void ComponentBase::componentRemoved( Component *component )
 {
 	//TODO: make sure the component is in d->components once and only once.
 	// if not, the situation is best referred to as 'very very broken indeed'.
-	d->components.remove( component );
+	d->components.removeAll( component );
 }
 
 void ComponentBase::clear()
 {
-	/* I'm switching setAutoDelete back and forth instead of turning it
-	 * on permenantly, because original author of this class set it to
-	 * auto delete in the dtor, that might have a reason that I can't
-	 * imagine right now */
-	bool tmp = d->components.autoDelete();
-	d->components.setAutoDelete( true );
+	foreach( Component *c , d->components )
+		delete c;
 	d->components.clear();
-	d->components.setAutoDelete( tmp );
 }
 
 void ComponentBase::componentResized( Component * )
@@ -115,18 +112,17 @@ void ComponentBase::componentResized( Component * )
 
 std::pair<QString,QRect> ComponentBase::toolTip( const QPoint &relativePos )
 {
-	for ( uint n = 0; n < components(); ++n )
-		if ( component( n )->rect().contains( relativePos ) )
-			return component( n )->toolTip( relativePos );
+	foreach( Component* n , d->components )
+		if ( n->rect().contains( relativePos ) )
+			return n->toolTip( relativePos );
 
 	return std::make_pair( QString::null, QRect() );
 }
 
 void ComponentBase::updateAnimationPosition( int p, int s )
 {
-	for ( uint n = 0; n < components(); ++n )
+	foreach( Component* comp , d->components )
 	{
-		Component *comp = component( n );
 		QRect start = comp->startRect();
 		QRect target = comp->targetRect();
 		QRect rc( start.left() + ((target.left() - start.left()) * p) / s,
@@ -154,7 +150,7 @@ public:
 	QRect startRect, targetRect;
 	int minWidth, minHeight;
 	bool growHoriz, growVert;
-	bool show; /** @since 23-03-2005 */
+	bool show;
 	ToolTipSource *tipSource;
 };
 
@@ -242,7 +238,7 @@ void Component::layout( const QRect &newRect )
 	else
 		d->startRect = rect();
 	d->targetRect = newRect;
-	//kdDebug(14000) << k_funcinfo << "At " << rect << endl;
+	//kDebug(14000) << "At " << rect;
 }
 
 void Component::setRect( const QRect &rect )
@@ -250,14 +246,14 @@ void Component::setRect( const QRect &rect )
 	d->rect = rect;
 }
 
-void Component::paint( QPainter *painter, const QColorGroup &cg )
+void Component::paint( QPainter *painter, const QPalette &pal )
 {
 	/*painter->setPen( Qt::red );
 	painter->drawRect( rect() );*/
 	for ( uint n = 0; n < components(); ++n )
 	{
 		if( component( n )->isShown() )
-			component( n )->paint( painter, cg );
+			component( n )->paint( painter, pal );
 	}
 }
 
@@ -312,7 +308,7 @@ int BoxComponent::widthForHeight( int height )
 	{
 		int width = 0;
 		for ( uint n = 0; n < components(); ++n )
-			width = QMAX( width, component( n )->widthForHeight( height ) );
+			width = qMax( width, component( n )->widthForHeight( height ) );
 		return width;
 	}
 	else
@@ -330,7 +326,7 @@ int BoxComponent::heightForWidth( int width )
 	{
 		int height = 0;
 		for ( uint n = 0; n < components(); ++n )
-			height = QMAX( height, component( n )->heightForWidth( width ) );
+			height = qMax( height, component( n )->heightForWidth( width ) );
 		return height;
 	}
 	else
@@ -350,12 +346,12 @@ void BoxComponent::calcMinSize()
 		Component *comp = component( n );
 		if ( d->direction == Horizontal )
 		{
-			max = QMAX( max, comp->minHeight() );
+			max = qMax( max, comp->minHeight() );
 			sum += comp->minWidth();
 		}
 		else
 		{
-			max = QMAX( max, comp->minWidth() );
+			max = qMax( max, comp->minWidth() );
 			sum += comp->minHeight();
 		}
 	}
@@ -401,9 +397,9 @@ void BoxComponent::layout( const QRect &rect )
 	// that cases we should pretend that we're wide/high enough.
 	int total;
 	if ( horiz )
-		total = QMAX( rect.width(), minWidth() );
+		total = qMax( rect.width(), minWidth() );
 	else
-		total = QMAX( rect.height(), minHeight() );
+		total = qMax( rect.height(), minHeight() );
 
 	int remaining = total - fixedSize - padding * (components() - 1);
 
@@ -412,7 +408,7 @@ void BoxComponent::layout( const QRect &rect )
 	for ( uint n = 0; n < components(); ++n )
 	{
 		Component *comp = component( n );
-		
+
 		QRect rc;
 		if ( horiz )
 		{
@@ -421,7 +417,7 @@ void BoxComponent::layout( const QRect &rect )
 			rc.setHeight( rect.height() );
 			int minWidth = comp->minWidth();
 			int desiredWidth = comp->widthForHeight( rect.height() );
-			rc.setWidth( QMIN( remaining + minWidth, desiredWidth ) );
+			rc.setWidth( qMin( remaining + minWidth, desiredWidth ) );
 			pos += rc.width();
 			remaining -= rc.width() - minWidth;
 		}
@@ -432,7 +428,7 @@ void BoxComponent::layout( const QRect &rect )
 			rc.setWidth( rect.width() );
 			int minHeight = comp->minHeight();
 			int desiredHeight = comp->heightForWidth( rect.width() );
-			rc.setHeight( QMIN( remaining + minHeight, desiredHeight ) );
+			rc.setHeight( qMin( remaining + minHeight, desiredHeight ) );
 			pos += rc.height();
 			remaining -= rc.height() - minHeight;
 		}
@@ -513,8 +509,9 @@ static QPoint operator+( const QPoint &pt, const QSize &sz )
 	return pt + sz;
 }*/
 
-void ImageComponent::paint( QPainter *painter, const QColorGroup & )
+void ImageComponent::paint( QPainter *painter, const QPalette &pal )
 {
+	Q_UNUSED( pal )
 	QRect ourRc = rect();
 	QRect rc = d->image.rect();
 	// center rc within our rect
@@ -523,10 +520,10 @@ void ImageComponent::paint( QPainter *painter, const QColorGroup & )
 	painter->drawPixmap( rc & ourRc, d->image );
 }
 
-void ImageComponent::scale( int w, int h, QImage::ScaleMode mode )
+void ImageComponent::scale( int w, int h, Qt::AspectRatioMode mode )
 {
-	QImage im = d->image.convertToImage();
-	setPixmap( QPixmap( im.smoothScale( w, h, mode ) ) );
+	QImage im = d->image.toImage();
+	setPixmap( QPixmap::fromImage( im.scaled( w, h, mode, Qt::SmoothTransformation) ) );
 }
 // TextComponent
 
@@ -618,15 +615,17 @@ void TextComponent::setDefaultColor()
 	repaint();
 }
 
-void TextComponent::paint( QPainter *painter, const QColorGroup &cg )
+void TextComponent::paint( QPainter *painter, const QPalette &pal )
 {
 	if ( d->customColor )
 		painter->setPen( d->color );
 	else
-		painter->setPen( cg.text() );
-	QString dispStr = KStringHandler::rPixelSqueeze( d->text, QFontMetrics( font() ), rect().width() );
+		painter->setPen( pal.text().color() );
+
+	QFontMetrics metrics( font() );
+	QString dispStr = metrics.elidedText( d->text, Qt::ElideRight, rect().width() );
 	painter->setFont( font() );
-	painter->drawText( rect(), Qt::SingleLine, dispStr );
+	painter->drawText( rect(), Qt::TextSingleLine, dispStr );
 }
 
 // DisplayNameComponent
@@ -678,7 +677,7 @@ void DisplayNameComponent::layout( const QRect &rect )
 					comp->hide();
 				}
 			}
-			else 
+			else
 			{
 				comp->show();
 				comp->layout( QRect( usedWidth+ rect.left(), rect.top(),
@@ -697,10 +696,10 @@ void DisplayNameComponent::layout( const QRect &rect )
 
 void DisplayNameComponent::setText( const QString& text )
 {
-	if ( d->text == text ) 
+	if ( d->text == text )
 		return;
 	d->text = text;
-	
+
 	redraw();
 }
 
@@ -712,13 +711,13 @@ void DisplayNameComponent::redraw()
 	{
 		((TextComponent*)component(n))->color();
 	}
-	
-	QValueList<Kopete::Emoticons::Token> tokens;
-	QValueList<Kopete::Emoticons::Token>::const_iterator token;
-	
-	clear(); // clear childs
 
-	tokens = Kopete::Emoticons::tokenizeEmoticons( d->text );
+	QList<KEmoticonsTheme::Token> tokens;
+	QList<KEmoticonsTheme::Token>::const_iterator token;
+
+	clear(); // clear childen
+
+	tokens = Kopete::Emoticons::tokenize( d->text );
 	ImageComponent *ic;
 	TextComponent *t;
 
@@ -728,19 +727,19 @@ void DisplayNameComponent::redraw()
 	{
 		switch ( (*token).type )
 		{
-		case Kopete::Emoticons::Text:
+		case KEmoticonsTheme::Text:
 			t = new TextComponent( this,  d->font, (*token).text );
 		break;
-		case Kopete::Emoticons::Image:
+		case KEmoticonsTheme::Image:
 			ic = new ImageComponent( this );
 			ic->setPixmap( QPixmap( (*token).picPath ) );
-			ic->scale( INT_MAX, fontHeight, QImage::ScaleMin );
+			ic->scale( INT_MAX, fontHeight, Qt::KeepAspectRatio );
 		break;
 		default:
-			kdDebug( 14010 ) << k_funcinfo << "This should have not happened!" << endl;
+			kDebug( 14010 ) << "This should have not happened!";
 		}
 	}
-	
+
 	if(color.isValid())
 		setColor( color );
 }
@@ -820,6 +819,11 @@ ContactComponent::ContactComponent( ComponentBase *parent, Kopete::Contact *cont
 	updatePixmap();
 }
 
+ContactComponent::~ContactComponent()
+{
+	delete d;
+}
+
 void ContactComponent::updatePixmap()
 {
 	setPixmap( contact()->onlineStatus().iconFor( contact(), d->iconSize ) );
@@ -860,14 +864,14 @@ public:
 		connect( this, SIGNAL(timeout()), target, slot );
 		if( users++ == 0 )
 			start( period );
-		//kdDebug(14000) << "SharedTimer::attach: users is now " << users << "\n";
+		//kDebug(14000) << "SharedTimer::attach: users is now " << users << "\n";
 	}
 	void detach( QObject *target, const char *slot )
 	{
 		disconnect( this, SIGNAL(timeout()), target, slot );
 		if( --users == 0 )
 			stop();
-		//kdDebug(14000) << "SharedTimer::detach: users is now " << users << "\n";
+		//kDebug(14000) << "SharedTimer::detach: users is now " << users << "\n";
 	}
 };
 
@@ -920,7 +924,7 @@ public:
 		static SharedTimer timer( 10 );
 		return timer;
 	}
-	
+
 	bool animateLayout;
 	int layoutAnimateSteps;
 	static const int layoutAnimateStepsTotal = 10;
@@ -936,17 +940,15 @@ public:
 	}
 
 	int visibilityLevel;
+
 	bool visibilityTarget;
+
 	static const int visibilityFoldSteps = 7;
-#ifdef HAVE_XRENDER
 	static const int visibilityFadeSteps = 7;
-#else
-	static const int visibilityFadeSteps = 0;
-#endif
 	static const int visibilityStepsTotal = visibilityFoldSteps + visibilityFadeSteps;
-	
+
 	bool searchMatch;
-		
+
 	static bool animateChanges;
 	static bool fadeVisibility;
 	static bool foldVisibility;
@@ -956,16 +958,16 @@ bool Item::Private::animateChanges = true;
 bool Item::Private::fadeVisibility = true;
 bool Item::Private::foldVisibility = true;
 
-Item::Item( QListViewItem *parent, QObject *owner, const char *name )
- : QObject( owner, name ), KListViewItem( parent ), d( new Private(this) )
+Item::Item( Q3ListViewItem *parent, QObject *owner )
+ : QObject( owner ), K3ListViewItem( parent ), d( new Private(this) )
 {
-	initLVI();
+	initLVI(parent->listView());
 }
 
-Item::Item( QListView *parent, QObject *owner, const char *name )
- : QObject( owner, name ), KListViewItem( parent ), d( new Private(this) )
+Item::Item( Q3ListView *parent, QObject *owner )
+ : QObject( owner ), K3ListViewItem( parent ), d( new Private(this) )
 {
-	initLVI();
+	initLVI(parent);
 }
 
 Item::~Item()
@@ -980,13 +982,14 @@ void Item::setEffects( bool animation, bool fading, bool folding )
 	Private::foldVisibility = folding;
 }
 
-void Item::initLVI()
+void Item::initLVI(QObject* parent)
 {
 	connect( listView()->header(), SIGNAL( sizeChange( int, int, int ) ), SLOT( slotColumnResized() ) );
 	connect( &d->layoutTimer, SIGNAL( timeout() ), SLOT( slotLayoutItems() ) );
+	connect (this, SIGNAL ( visibilityChanged(bool) ), parent, SIGNAL ( visibleSizeChanged () ) );
 	//connect( &d->layoutAnimateTimer, SIGNAL( timeout() ), SLOT( slotLayoutAnimateItems() ) );
 	//connect( &d->visibilityTimer, SIGNAL( timeout() ), SLOT( slotUpdateVisibility() ) );
-	setVisible( false );
+	mySetVisible( false );
 	setTargetVisibility( true );
 }
 
@@ -1001,7 +1004,10 @@ void Item::scheduleLayout()
 {
 	// perform a delayed layout in order to speed it all up
 	if ( ! d->layoutTimer.isActive() )
-		d->layoutTimer.start( 30, true );
+	{
+		d->layoutTimer.setSingleShot( true );
+		d->layoutTimer.start( 30 );
+	}
 }
 
 void Item::slotLayoutItems()
@@ -1019,7 +1025,7 @@ void Item::slotLayoutItems()
 
 		int height = component( n )->heightForWidth( width );
 		component( n )->layout( QRect( 0, 0, width, height ) );
-		//kdDebug(14000) << k_funcinfo << "Component " << n << " is " << width << " x " << height << endl;
+		//kDebug(14000) << "Component " << n << " is " << width << " x " << height;
 	}
 
 	if ( Private::animateChanges && d->animateLayout && !d->visibilityTimer.isActive() )
@@ -1043,7 +1049,7 @@ void Item::slotLayoutAnimateItems()
 		d->layoutAnimateTimer.stop();
 
 	const int s = Private::layoutAnimateStepsTotal;
-	const int p = QMIN( d->layoutAnimateSteps, s );
+	const int p = qMin( d->layoutAnimateSteps, s );
 
 	updateAnimationPosition( p, s );
 	setHeight(0);
@@ -1065,17 +1071,17 @@ void Item::setOpacity( float opacity )
 void Item::setSearchMatch( bool match )
 {
 	d->searchMatch = match;
-	
+
 	if ( !match )
-		setVisible( false );
+		mySetVisible( false );
 	else
 	{
-		kdDebug(14000) << k_funcinfo << " match: " << match << ", vis timer active: " << d->visibilityTimer.isActive()
+		kDebug(14000) << " match: " << match << ", vis timer active: " << d->visibilityTimer.isActive()
 		               << ", target visibility: " << targetVisibility() << endl;
 		if ( d->visibilityTimer.isActive() )
-			setVisible( true );
+			mySetVisible( true );
 		else
-			setVisible( targetVisibility() );
+			mySetVisible( targetVisibility() );
 	}
 }
 
@@ -1091,14 +1097,14 @@ void Item::setTargetVisibility( bool vis )
 		// in case we're getting called because our parent was shown and
 		// we need to be rehidden
 		if ( !d->visibilityTimer.isActive() )
-			setVisible( vis && d->searchMatch );
+			mySetVisible( vis && d->searchMatch );
 		return;
 	}
 	d->visibilityTarget = vis;
 	d->visibilityTimer.start();
 	//d->visibilityTimer.start( 40 );
 	if ( targetVisibility() )
-		setVisible( d->searchMatch );
+		mySetVisible( d->searchMatch );
 	slotUpdateVisibility();
 }
 
@@ -1125,7 +1131,7 @@ void Item::slotUpdateVisibility()
 	{
 		d->visibilityLevel = 0;
 		d->visibilityTimer.stop();
-		setVisible( false );
+		mySetVisible( false );
 	}
 	setHeight( 0 );
 	repaint();
@@ -1146,7 +1152,7 @@ void Item::relayout()
 
 void Item::setup()
 {
-	KListViewItem::setup();
+	K3ListViewItem::setup();
 	slotLayoutItems();
 }
 
@@ -1154,17 +1160,19 @@ void Item::setHeight( int )
 {
 	int minHeight = 0;
 	for ( uint n = 0; n < components(); ++n )
-		minHeight = QMAX( minHeight, component( n )->rect().height() );
-	//kdDebug(14000) << k_funcinfo << "Height is " << minHeight << endl;
+		minHeight = qMax( minHeight, component( n )->rect().height() );
+	//kDebug(14000) << "Height is " << minHeight;
 	if ( Private::foldVisibility && d->visibilityTimer.isActive() )
 	{
-		int vis = QMIN( d->visibilityLevel, Private::visibilityFoldSteps );
+		int vis = d->visibilityLevel;
+		if ( vis > Private::visibilityFoldSteps )
+		    vis = Private::visibilityFoldSteps;
 		minHeight = (minHeight * vis) / Private::visibilityFoldSteps;
 	}
-	KListViewItem::setHeight( minHeight );
+	K3ListViewItem::setHeight( minHeight );
 }
 
-int Item::width( const QFontMetrics &, const QListView *lv, int c ) const
+int Item::width( const QFontMetrics &, const Q3ListView *lv, int c ) const
 {
 	// Qt computes the itemRect from this. we want the whole item to be
 	// clickable, so we return the widest we could possibly be.
@@ -1173,22 +1181,23 @@ int Item::width( const QFontMetrics &, const QListView *lv, int c ) const
 
 void Item::paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int align )
 {
+	Q_UNUSED(align);
 	QPixmap back( width, height() );
 	QPainter paint( &back );
-	//KListViewItem::paintCell( &paint, cg, column, width, align );
+	//K3ListViewItem::paintCell( &paint, cg, column, width, align );
 	// PASTED FROM KLISTVIEWITEM:
 	// set the alternate cell background colour if necessary
 	QColorGroup _cg = cg;
 	if (isAlternate())
 		if (listView()->viewport()->backgroundMode()==Qt::FixedColor)
-			_cg.setColor(QColorGroup::Background, static_cast< KListView* >(listView())->alternateBackground());
+			_cg.setColor(QPalette::Background, static_cast< K3ListView* >(listView())->alternateBackground());
 		else
-			_cg.setColor(QColorGroup::Base, static_cast< KListView* >(listView())->alternateBackground());
+			_cg.setColor(QPalette::Base, static_cast< K3ListView* >(listView())->alternateBackground());
 	// PASTED FROM QLISTVIEWITEM
 	{
 		QPainter *p = &paint;
 
-		QListView *lv = listView();
+		Q3ListView *lv = listView();
 		if ( !lv )
 			return;
 		QFontMetrics fm( p->fontMetrics() );
@@ -1199,11 +1208,18 @@ void Item::paintCell( QPainter *p, const QColorGroup &cg, int column, int width,
 		// removed text truncating code from Qt - we do that differently, further on
 
 		int marg = lv->itemMargin();
-		int r = marg;
+		QBrush b;
+		if (isSelected())
+			b = _cg.brush(QPalette::Normal, QPalette::Highlight);
+		else
+			b = _cg.background();
+		p->fillRect( 0, 0, width, height(), b );
 	//	const QPixmap * icon = pixmap( column );
-
-		const BackgroundMode bgmode = lv->viewport()->backgroundMode();
-		const QColorGroup::ColorRole crole = QPalette::backgroundRoleFromMode( bgmode );
+#ifdef __GNUC__
+#warning Item::paintCell needs fixing
+#endif
+/*
+        const QPalette::ColorRole crole = backgroundRole();
 
 		if ( _cg.brush( crole ) != lv->colorGroup().brush( crole ) )
 			p->fillRect( 0, 0, width, height(), _cg.brush( crole ) );
@@ -1213,13 +1229,13 @@ void Item::paintCell( QPainter *p, const QColorGroup &cg, int column, int width,
 
 			//lv->paintEmptyArea( p, QRect( 0, 0, width, height() ) );
 			QStyleOption opt( lv->sortColumn(), 0 ); // ### hack; in 3.1, add a property in QListView and QHeader
-			QStyle::SFlags how = QStyle::Style_Default;
+			QStyle::SFlags how = QStyle::State_Default;
 			if ( lv->isEnabled() )
-				how |= QStyle::Style_Enabled;
+				how |= QStyle::State_Enabled;
 
-			lv->style().drawComplexControl( QStyle::CC_ListView,
+			lv->style()->drawComplexControl( QStyle::CC_Q3ListView,
 						p, lv, QRect( 0, 0, width, height() ), lv->colorGroup(),
-						how, QStyle::SC_ListView, QStyle::SC_None,
+						how, QStyle::SC_Q3ListView, QStyle::SC_None,
 						opt );
 		}
 
@@ -1228,7 +1244,7 @@ void Item::paintCell( QPainter *p, const QColorGroup &cg, int column, int width,
 		if ( isSelected() &&
 		(column == 0 || lv->allColumnsShowFocus()) ) {
 			p->fillRect( r - marg, 0, width - r + marg, height(),
-					_cg.brush( QColorGroup::Highlight ) );
+					_cg.brush( QPalette::Highlight ) );
 	// removed text pen setting code from Qt
 		}
 
@@ -1237,47 +1253,49 @@ void Item::paintCell( QPainter *p, const QColorGroup &cg, int column, int width,
 		// draw the tree gubbins
 		if ( multiLinesEnabled() && column == 0 && isOpen() && childCount() ) {
 			int textheight = fm.size( align, t ).height() + 2 * lv->itemMargin();
-			textheight = QMAX( textheight, QApplication::globalStrut().height() );
+			textheight = qMax( textheight, QApplication::globalStrut().height() );
 			if ( textheight % 2 > 0 )
 				textheight++;
 			if ( textheight < height() ) {
 				int w = lv->treeStepSize() / 2;
-				lv->style().drawComplexControl( QStyle::CC_ListView, p, lv,
+				lv->style()->drawComplexControl( QStyle::CC_Q3ListView, p, lv,
 								QRect( 0, textheight, w + 1, height() - textheight + 1 ), _cg,
-								lv->isEnabled() ? QStyle::Style_Enabled : QStyle::Style_Default,
-								QStyle::SC_ListViewExpand,
+								lv->isEnabled() ? QStyle::State_Enabled : QStyle::State_Default,
+								QStyle::SC_Q3ListViewExpand,
 								(uint)QStyle::SC_All, QStyleOption( this ) );
 			}
-		}
+        }
+       */
 	}
 	// END OF PASTE
-	
-	
+
+
 	//do you see a better way to tell the TextComponent we are selected ?  - Olivier 2004-09-02
-	if ( isSelected() ) 
-		_cg.setColor(QColorGroup::Text , _cg.highlightedText() );
-	
+	if ( isSelected() )
+		_cg.setColor(QPalette::Text , _cg.highlightedText() );
+
 	if ( Component *comp = component( column ) )
 		comp->paint( &paint, _cg );
 	paint.end();
 
-#ifdef HAVE_XRENDER
-	QColor rgb = cg.base();//backgroundColor();
+	QColor rgba = cg.base();//backgroundColor();
 	float opac = 1.0;
 	if ( d->visibilityTimer.isActive() && Private::fadeVisibility )
 	{
-		int vis = QMAX( d->visibilityLevel - Private::visibilityFoldSteps, 0 );
+		int vis = d->visibilityLevel - Private::visibilityFoldSteps;
+		if ( vis < 0 )
+		    vis = 0;
+
 		opac = float(vis) / Private::visibilityFadeSteps;
 	}
 	opac *= opacity();
-	const int alpha = 257 - int(opac * 257);
+	const int alpha = 255 - int(opac * 255);
 	if ( alpha != 0 )
 	{
-		XRenderColor clr = { alpha * rgb.red(), alpha * rgb.green(), alpha * rgb.blue(), alpha * 0xff };
-		XRenderFillRectangle( back.x11Display(), PictOpOver, back.x11RenderHandle(),
-		                      &clr, 0, 0, width, height() );
+		rgba.setAlpha(alpha);
+		QPainter p(&back);
+		p.fillRect(back.rect(), rgba);
 	}
-#endif
 
 	p->drawPixmap( 0, 0, back );
 }
@@ -1300,6 +1318,12 @@ void Item::componentResized( Component *component )
 	scheduleLayout();
 }
 
+void Item::mySetVisible ( bool b )
+{
+	setVisible (b);
+	emit visibilityChanged (b);
+}
+
 } // END namespace ListView
 } // END namespace UI
 } // END namespace Kopete
