@@ -19,14 +19,14 @@
 #include <qregexp.h>
 #include <qimage.h>
 #include <qbuffer.h>
-#include <qcstring.h>
-#include <qstylesheet.h>
+#include <QTextDocument>
+
 #include <kgenericfactory.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
 #include <kprocess.h>
-#include <ktempfile.h>
-#include <kmdcodec.h>
+#include <ktemporaryfile.h>
+#include <kcodecs.h>
 #include <kmessagebox.h>
 
 #include "kopetechatsessionmanager.h"
@@ -38,34 +38,35 @@
 
 #define ENCODED_IMAGE_MODE 0
 
-typedef KGenericFactory<LatexPlugin> LatexPluginFactory;
-K_EXPORT_COMPONENT_FACTORY( kopete_latex, LatexPluginFactory( "kopete_latex" )  )
 
-LatexPlugin::LatexPlugin( QObject *parent, const char *name, const QStringList &/*args*/ )
-: Kopete::Plugin( LatexPluginFactory::instance(), parent, name )
+K_PLUGIN_FACTORY(LatexPluginFactory, registerPlugin<LatexPlugin>();)
+K_EXPORT_PLUGIN(LatexPluginFactory( "kopete_latex" ))
+
+
+LatexPlugin::LatexPlugin( QObject *parent, const QVariantList &/*args*/ )
+: Kopete::Plugin( LatexPluginFactory::componentData(), parent )
 {
-//	kdDebug() << k_funcinfo << endl;
+//	kDebug(14317) ;
 	if( !s_pluginStatic )
 		s_pluginStatic = this;
 
 	mMagickNotFoundShown = false;
 	connect( Kopete::ChatSessionManager::self(), SIGNAL( aboutToDisplay( Kopete::Message & ) ), SLOT( slotMessageAboutToShow( Kopete::Message & ) ) );
 	connect( Kopete::ChatSessionManager::self(), SIGNAL( aboutToSend(Kopete::Message& )  ), this,  SLOT(slotMessageAboutToSend(Kopete::Message& )  ) );
-	connect ( this , SIGNAL( settingsChanged() ) , this , SLOT( slotSettingsChanged() ) );
 	connect( Kopete::ChatSessionManager::self(), SIGNAL( chatSessionCreated( Kopete::ChatSession * ) ),
 			 this, SLOT( slotNewChatSession( Kopete::ChatSession * ) ) );
 	
 	m_convScript = KStandardDirs::findExe("kopete_latexconvert.sh");
-	slotSettingsChanged();
 
 		//Add GUI action to all already existing kmm (if the plugin is launched when kopete already rining)
-	QValueList<Kopete::ChatSession*> sessions = Kopete::ChatSessionManager::self()->sessions();
-	for (QValueListIterator<Kopete::ChatSession*> it= sessions.begin(); it!=sessions.end() ; ++it)
-		slotNewChatSession( *it );
+	QList<Kopete::ChatSession*> sessions = Kopete::ChatSessionManager::self()->sessions();
+	foreach( Kopete::ChatSession* cs, sessions )
+		slotNewChatSession( cs );
 }
 
 LatexPlugin::~LatexPlugin()
 {
+	qDeleteAll( m_tempFiles );
 	s_pluginStatic = 0L;
 }
 
@@ -92,11 +93,11 @@ void LatexPlugin::slotMessageAboutToShow( Kopete::Message& msg )
 		{
 			KMessageBox::queuedMessageBox(
 			    Kopete::UI::Global::mainWidget(),
-			    KMessageBox::Error, i18n("I cannot find the Magick convert program.\nconvert is required to render the Latex formulas.\nPlease go to www.imagemagick.org or to your distribution site and get the right package.")
+			    KMessageBox::Error, i18n("Cannot find the Magick 'convert' program.\nconvert is required to render the LaTeX formulae.\nPlease get the software from www.imagemagick.org or from your distribution's package manager.")
 			);
 			mMagickNotFoundShown = true;
 		}
-		// dont try to parse if convert is not installed
+		// don't try to parse if convert is not installed
 		return;
 	}
 	
@@ -104,7 +105,7 @@ void LatexPlugin::slotMessageAboutToShow( Kopete::Message& msg )
 	if( !messageText.contains("$$"))
 		return;
 
-	//kdDebug() << k_funcinfo << " Using converter: " << m_convScript << endl;
+	//kDebug(14317) << " Using converter: " << m_convScript;
 
 	// /\[([^]]).*?\[/$1\]/
 	// \$\$.+?\$\$
@@ -118,10 +119,10 @@ void LatexPlugin::slotMessageAboutToShow( Kopete::Message& msg )
 	int pos = 0;
 	
 	QMap<QString, QString> replaceMap;
-	while (pos >= 0 && (unsigned int)pos < messageText.length())
+	while (pos >= 0 && pos < messageText.length())
 	{
-//		kdDebug() << k_funcinfo  << " searching pos: " << pos << endl;
-		pos = rg.search(messageText, pos);
+//		kDebug(14317) << " searching pos: " << pos;
+		pos = rg.indexIn(messageText, pos);
 		
 		if (pos >= 0 )
 		{
@@ -143,7 +144,7 @@ void LatexPlugin::slotMessageAboutToShow( Kopete::Message& msg )
 			{
 				QByteArray ba;
 				QBuffer buffer( ba );
-				buffer.open( IO_WriteOnly );
+				buffer.open( QIODevice::WriteOnly );
 				renderedImage.save( &buffer, "PNG" );
 				QString imageURL = QString::fromLatin1("data:image/png;base64,%1").arg( KCodecs::base64Encode( ba ) );
 				replaceMap[match] = imageURL;
@@ -154,7 +155,7 @@ void LatexPlugin::slotMessageAboutToShow( Kopete::Message& msg )
 		}
 	}
 
-	if(replaceMap.isEmpty()) //we haven't found any latex strings
+	if(replaceMap.isEmpty()) //we haven't found any LaTeX strings
 		return;
 
 	messageText= msg.escapedBody();
@@ -167,11 +168,11 @@ void LatexPlugin::slotMessageAboutToShow( Kopete::Message& msg )
 			continue;
 		imagePxWidth = theImage.width();
 		imagePxHeight = theImage.height();
-		QString escapedLATEX=QStyleSheet::escape(it.key()).replace("\"","&quot;");  //we need  the escape quotes because that string will be in a title="" argument, but not the \n
-		messageText.replace(Kopete::Message::escape(it.key()), " <img width=\"" + QString::number(imagePxWidth) + "\" height=\"" + QString::number(imagePxHeight) + "\" src=\"" + (*it) + "\"  alt=\"" + escapedLATEX +"\" title=\"" + escapedLATEX +"\"  /> ");
+		QString escapedLATEX=Qt::escape(it.key()).replace("\"","&quot;");  //we need  the escape quotes because that string will be in a title="" argument, but not the \n
+		messageText.replace(Kopete::Message::escape(it.key()), " <img width=\"" + QString::number(imagePxWidth) + "\" height=\"" + QString::number(imagePxHeight) + "\" align=\"middle\" src=\"" + (*it) + "\"  alt=\"" + escapedLATEX +"\" title=\"" + escapedLATEX +"\"  /> ");
 	}
 
-	msg.setBody( messageText, Kopete::Message::RichText );
+	msg.setHtmlBody( messageText );
 }
 
 
@@ -180,10 +181,10 @@ void LatexPlugin::slotMessageAboutToSend( Kopete::Message& msg)
 	Q_UNUSED(msg)
 	//disabled because to work correctly, we need to find what special has the gif we can send over MSN
 #if 0
-	KConfig *config = KGlobal::config();
+	KSharedConfig::Ptr config = KGlobal::config();
 	config->setGroup("Latex Plugin");
 
-	if(!config->readBoolEntry("ParseOutgoing", false))
+	if(!config->readEntry("ParseOutgoing", false))
 		return;
 
 	QString messageText = msg.plainBody();
@@ -206,7 +207,7 @@ void LatexPlugin::slotMessageAboutToSend( Kopete::Message& msg)
 
 		if(!url.isNull())
 		{
-			QString escapedLATEX= QStyleSheet::escape(messageText).replace("\"","&quot;");
+			QString escapedLATEX= Qt::escape(messageText).replace("\"","&quot;");
 			QString messageText="<img src=\"" + url + "\" alt=\"" + escapedLATEX + "\" title=\"" + escapedLATEX +"\"  />";
 			msg.setBody( messageText, Kopete::Message::RichText );
 		}
@@ -216,26 +217,30 @@ void LatexPlugin::slotMessageAboutToSend( Kopete::Message& msg)
 
 QString LatexPlugin::handleLatex(const QString &latexFormula)
 {
-	KTempFile *tempFile=new KTempFile( locateLocal( "tmp", "kopetelatex-" ), ".png" );
-	tempFile->setAutoDelete(true);
+	KTemporaryFile *tempFile=new KTemporaryFile();
+	tempFile->setPrefix("kopetelatex-");
+	tempFile->setSuffix(".png");
+	tempFile->open();
 	m_tempFiles.append(tempFile);
-	m_tempFiles.setAutoDelete(true);
-	QString fileName = tempFile->name();
+	QString fileName = tempFile->fileName();
 
 	KProcess p;
-			
-	QString argumentRes = "-r %1x%2";
-	QString argumentOut = "-o %1";
+	
+	QString argumentRes = QString("-r %1x%2").arg(LatexConfig::horizontalDPI()).arg(LatexConfig::verticalDPI());
+	QString argumentOut = QString("-o %1").arg(fileName);
+	QString argumentInclude ("-x %1");
 	//QString argumentFormat = "-fgif";  //we uses gif format because MSN only handle gif
-	int hDPI, vDPI;
-	hDPI = LatexConfig::self()->horizontalDPI();
-	vDPI = LatexConfig::self()->verticalDPI();
-	p << m_convScript <<  argumentRes.arg(QString::number(hDPI), QString::number(vDPI)) << argumentOut.arg(fileName) /*<< argumentFormat*/ << latexFormula  ;
-			
-	kdDebug() << k_funcinfo  << " Rendering " << m_convScript << " " <<  argumentRes.arg(QString::number(hDPI), QString::number(vDPI)) << " " << argumentOut.arg(fileName) << endl;
-			
+	LatexConfig::self()->readConfig();
+	QString includePath = LatexConfig::latexIncludeFile();
+	if (!includePath.isNull())
+		p << m_convScript <<  argumentRes << argumentOut /*<< argumentFormat*/ << argumentInclude.arg(includePath) << latexFormula;
+	else
+		p << m_convScript <<  argumentRes << argumentOut /*<< argumentFormat*/ << latexFormula;
+	
+	kDebug(14317) << "Rendering" << m_convScript << argumentRes << argumentOut << argumentInclude << latexFormula ;
+	
 	// FIXME our sucky sync filter API limitations :-)
-	p.start(KProcess::Block);
+	p.execute();
 	return fileName;
 }
 
@@ -248,11 +253,6 @@ bool LatexPlugin::securityCheck(const QString &latexFormula)
 
 }
 
-void LatexPlugin::slotSettingsChanged()
-{
-	LatexConfig::self()->readConfig();
-}
-
 #include "latexplugin.moc"
 
 // vim: set noet ts=4 sts=4 sw=4:
