@@ -3,6 +3,7 @@
 
     Copyright (c) 2003-2004 by Marc Cramdal        <marc.cramdal@gmail.com>
 
+    Copyright (c) 2007      by the Kopete Developers <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -19,6 +20,9 @@
 
 #include "kopeteonlinestatus.h"
 #include "kopetemessage.h"
+//Added by qt3to4:
+#include <Q3ValueList>
+#include <QTime>
 
 class StatisticsDB;
 class QDateTime;
@@ -48,12 +52,6 @@ public:
 	 *  \return m_metaContact
 	 */
 	Kopete::MetaContact *metaContact() { return m_metaContact; }
-	
-	/** \brief Access method
-	 *  \return m_statisticsContactId
-	 */
-	QString statisticsContactId() { return m_statisticsContactId; }
-	
 	/** \brief Access method
 	 *  \return m_oldStatus
 	 */
@@ -121,7 +119,7 @@ public:
 	 * Prevision methods
 	 */
 	/**
-// 	 * \brief Give informations on when the next event will occur
+// 	 * \brief Give information on when the next event will occur
 // 	 *
 // 	 * \param status the status to be checked.
 // 	 * \retval nextEventDateTime the next event average prevision datetime.
@@ -142,32 +140,12 @@ public:
 	/**
 	 * \brief computes the main "status" events for the contact
 	 */
-	QValueList<QTime> mainEvents(const Kopete::OnlineStatus::StatusType& status);
+	Q3ValueList<QTime> mainEvents(const Kopete::OnlineStatus::StatusType& status);
 	/// \brief used by mainEvents()
-	QValueList<int> computeCentroids(const QValueList<int>& centroids, const QValueList<int>& values);
-	
-	/**
-	 * \brief adds contact to "contacts" database and generates m_statisticsContactId if needed
-	 */
-	void contactAdded( Kopete::Contact *c );
-	
-	/**
-	 * \brief removes contact from "contacts" database
-	 */
-	void contactRemoved( Kopete::Contact *c );
-	
-	/**
-	 * \brief removes all records from database that are related to this class and clears m_statisticsContactId
-	 */
-	void removeFromDB();
-	
-private:
-	/**
-	 * \brief initializes this object and sets m_statisticsContactId
-	 *
-	 */
-	void initialize(Kopete::Contact *c);
+	Q3ValueList<int> computeCentroids(const Q3ValueList<int>& centroids, const Q3ValueList<int>& values);
+
 	
+private:	
 	/**
 	 * \brief Checks if the value name exists in "commonstats" table, if not, add the row.
 	 *
@@ -248,12 +226,6 @@ private:
 	 */
 	QDateTime m_lastPresent;
 	bool m_lastPresentChanged;
-	
-	/**
-	 * Unique id that identifies StatisticsContact
-	 * It's also identifier for database records
-	 */
-	QString m_statisticsContactId;
 };
 
 
