@@ -3,8 +3,8 @@
 
     Kopete Translator plugin
 
-    Copyright (c) 2001-2002 by Duncan Mac-Vicar Prett       <duncan@kde.org>
-    Copyright (c) 2002-2004 by Olivier Goffart      <ogoffart @ kde.org>
+    Copyright (c) 2001-2002 by Duncan Mac-Vicar Prett <duncan@kde.org>
+    Copyright (c) 2002-2004 by Olivier Goffart <ogoffart@kde.org>
 
     Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>
 
@@ -16,12 +16,17 @@
     * (at your option) any later version.                                   *
     *                                                                       *
     *************************************************************************
+    Patched by Francesco Rossi <redsh@email.it> in order to support new 
+    google translation page layout (13-sept-2007)
 */
 
 #include <qapplication.h>
 #include <qregexp.h>
-#include <qsignal.h>
+#include <q3signal.h>
 #include <qstring.h>
+//Added by qt3to4:
+#include <Q3ValueList>
+#include <QByteArray>
 
 #include <kdebug.h>
 #include <kaction.h>
@@ -30,33 +35,32 @@
 #include <kconfig.h>
 #include <kdeversion.h>
 #include <kaboutdata.h>
+#include <kselectaction.h>
+#include <kicon.h>
 
 #include "kopetemetacontact.h"
 #include "kopetecontactlist.h"
-#include "kopetemessagemanagerfactory.h"
+#include "kopetechatsessionmanager.h"
 #include "kopetecontact.h"
 
 #include "translatorplugin.h"
 #include "translatordialog.h"
 #include "translatorguiclient.h"
 #include "translatorlanguages.h"
+#include <kactioncollection.h>
 
 typedef KGenericFactory<TranslatorPlugin> TranslatorPluginFactory;
-#if KDE_IS_VERSION(3,2,90)
-static const KAboutData aboutdata("kopete_translator", I18N_NOOP("Translator") , "1.0" );
+static const KAboutData aboutdata("kopete_translator", 0, ki18n("Translator") , "1.0" );
 K_EXPORT_COMPONENT_FACTORY( kopete_translator, TranslatorPluginFactory( &aboutdata )  )
-#else
-K_EXPORT_COMPONENT_FACTORY( kopete_translator, TranslatorPluginFactory( "kopete_translator" )  )
-#endif
 
-TranslatorPlugin::TranslatorPlugin( QObject *parent, const char *name, const QStringList & /* args */ )
-: Kopete::Plugin( TranslatorPluginFactory::instance(), parent, name )
+TranslatorPlugin::TranslatorPlugin( QObject *parent, const QStringList & /* args */ )
+: Kopete::Plugin( TranslatorPluginFactory::componentData(), parent )
 {
-	kdDebug( 14308 ) << k_funcinfo << endl;
+	kDebug( 14308 ) ;
 
 
 	if ( pluginStatic_ )
-		kdWarning( 14308 ) << k_funcinfo << "Translator already initialized" << endl;
+		kWarning( 14308 ) << "Translator already initialized";
 	else
 		pluginStatic_ = this;
 
@@ -74,7 +78,8 @@ TranslatorPlugin::TranslatorPlugin( QObject *parent, const char *name, const QSt
 	for ( int k = 0; k <= m_languages->numLanguages(); k++ )
 		keys << m[ m_languages->languageKey( k ) ];
 
-	m_actionLanguage = new KSelectAction( i18n( "Set &Language" ), "locale", 0, actionCollection(), "contactLanguage" );
+	m_actionLanguage = new KSelectAction( KIcon("preferences-desktop-locale"), i18n( "Set &Language" ), this );
+        actionCollection()->addAction( "contactLanguage", m_actionLanguage );
 	m_actionLanguage->setItems( keys );
 	connect( m_actionLanguage, SIGNAL( activated() ), this, SLOT(slotSetLanguage() ) );
 	connect( Kopete::ContactList::self(), SIGNAL( metaContactSelected( bool ) ), this, SLOT( slotSelectionChanged( bool ) ) );
@@ -82,8 +87,8 @@ TranslatorPlugin::TranslatorPlugin( QObject *parent, const char *name, const QSt
 	setXMLFile( "translatorui.rc" );
 
 	//Add GUI action to all already existing kmm (if the plugin is launched when kopete already rining)
-	QValueList<Kopete::ChatSession*> sessions = Kopete::ChatSessionManager::self()->sessions();
-	for (QValueListIterator<Kopete::ChatSession*> it= sessions.begin(); it!=sessions.end() ; ++it)
+	Q3ValueList<Kopete::ChatSession*> sessions = Kopete::ChatSessionManager::self()->sessions();
+	for (Q3ValueListIterator<Kopete::ChatSession*> it= sessions.begin(); it!=sessions.end() ; ++it)
 	  slotNewKMM( *it );
 
 	loadSettings();
@@ -92,7 +97,7 @@ TranslatorPlugin::TranslatorPlugin( QObject *parent, const char *name, const QSt
 
 TranslatorPlugin::~TranslatorPlugin()
 {
-	kdDebug( 14308 ) << k_funcinfo << endl;
+	kDebug( 14308 ) ;
 	pluginStatic_ = 0L;
 }
 
@@ -105,29 +110,28 @@ TranslatorPlugin* TranslatorPlugin::pluginStatic_ = 0L;
 
 void TranslatorPlugin::loadSettings()
 {
-	KConfig *config = KGlobal::config();
 	int mode = 0;
 
-	config->setGroup( "Translator Plugin" );
-	m_myLang = m_languages->languageKey( config->readNumEntry( "myLang" , 0 ) );
-	m_service = m_languages->serviceKey( config->readNumEntry( "Service", 0 ) );
+	KConfigGroup config = KGlobal::config()->group("Translator Plugin");
+	m_myLang = m_languages->languageKey( config.readEntry( "myLang" , 0 ) );
+	m_service = m_languages->serviceKey( config.readEntry( "Service", 0 ) );
 
-	if ( config->readBoolEntry( "IncomingDontTranslate", true ) )
+	if ( config.readEntry( "IncomingDontTranslate", true ) )
 		mode = 0;
-	else if ( config->readBoolEntry( "IncomingShowOriginal", false ) )
+	else if ( config.readEntry( "IncomingShowOriginal", false ) )
 		mode = 1;
-	else if ( config->readBoolEntry( "IncomingTranslate", false ) )
+	else if ( config.readEntry( "IncomingTranslate", false ) )
 		mode = 2;
 
 	m_incomingMode = mode;
 
-	if ( config->readBoolEntry( "OutgoingDontTranslate", true ) )
+	if ( config.readEntry( "OutgoingDontTranslate", true ) )
 		mode = 0;
-	else if ( config->readBoolEntry( "OutgoingShowOriginal", false ) )
+	else if ( config.readEntry( "OutgoingShowOriginal", false ) )
 		mode = 1;
-	else if ( config->readBoolEntry( "OutgoingTranslate", false ) )
+	else if ( config.readEntry( "OutgoingTranslate", false ) )
 		mode = 2;
-	else if ( config->readBoolEntry( "OutgoingAsk", false ) )
+	else if ( config.readEntry( "OutgoingAsk", false ) )
 		mode = 3;
 
 	m_outgoingMode = mode;
@@ -170,13 +174,13 @@ void TranslatorPlugin::slotIncomingMessage( Kopete::Message &msg )
 		Kopete::MetaContact *from = msg.from()->metaContact();
 		if ( !from )
 		{
-//			kdDebug( 14308 ) << k_funcinfo << "No metaContact for source contact" << endl;
+//			kDebug( 14308 ) << "No metaContact for source contact";
 			return;
 		}
 		src_lang = from->pluginData( this, "languageKey" );
 		if( src_lang.isEmpty() || src_lang == "null" )
 		{
-//			kdDebug( 14308 ) << k_funcinfo << "Cannot determine src Metacontact language (" << from->displayName() << ")" << endl;
+//			kDebug( 14308 ) << "Cannot determine src Metacontact language (" << from->displayName() << ")";
 			return;
 		}
 
@@ -202,13 +206,13 @@ void TranslatorPlugin::slotOutgoingMessage( Kopete::Message &msg )
 		Kopete::MetaContact *to = msg.to().first()->metaContact();
 		if ( !to )
 		{
-//			kdDebug( 14308 ) << k_funcinfo << "No metaContact for first contact" << endl;
+//			kDebug( 14308 ) << "No metaContact for first contact";
 			return;
 		}
 		dst_lang = to->pluginData( this, "languageKey" );
 		if ( dst_lang.isEmpty() || dst_lang == "null" )
 		{
-//			kdDebug( 14308 ) << k_funcinfo << "Cannot determine dst Metacontact language (" << to->displayName() << ")" << endl;
+//			kDebug( 14308 ) << "Cannot determine dst Metacontact language (" << to->displayName() << ")";
 			return;
 		}
 
@@ -218,7 +222,7 @@ void TranslatorPlugin::slotOutgoingMessage( Kopete::Message &msg )
 
 void TranslatorPlugin::translateMessage( const QString &msg, const QString &from, const QString &to, QObject *obj, const char* slot )
 {
-	QSignal completeSignal;
+	Q3Signal completeSignal;
 	completeSignal.connect( obj, slot );
 
 	QString result = translateMessage( msg, from, to );
@@ -234,47 +238,47 @@ QString TranslatorPlugin::translateMessage( const QString &msg, const QString &f
 {
 	if ( from == to )
 	{
-		kdDebug( 14308 ) << k_funcinfo << "Src and Dst languages are the same" << endl;
-		return QString::null;
+		kDebug( 14308 ) << "Src and Dst languages are the same";
+		return QString();
 	}
 
 	// We search for src_dst
-	if(! m_languages->supported( m_service ).contains( from + "_" + to ) )
+	if(! m_languages->supported( m_service ).contains( from + '_' + to ) )
 	{
-		kdDebug( 14308 ) << k_funcinfo << from << "_" << to << " is not supported by service " << m_service << endl;
-		return QString::null;
+		kDebug( 14308 ) << from << '_' << to << " is not supported by service " << m_service;
+		return QString();
 	}
-		
+
 
 	if ( m_service == "babelfish" )
 		return babelTranslateMessage( msg ,from, to );
 	else if ( m_service == "google" )
 		return googleTranslateMessage( msg ,from, to );
 	else
-		return QString::null;
+		return QString();
 }
 
 QString TranslatorPlugin::googleTranslateMessage( const QString &msg, const QString &from, const QString &to )
 {
-	KURL translatorURL ( "http://translate.google.com/translate_t");
+	KUrl translatorURL ( "http://translate.google.com/translate_t");
 
-	QString body = KURL::encode_string( msg );
-	QString lp = from + "|" + to;
+	QString body = QString(QUrl::toPercentEncoding( msg ));
+	QString lp = from + '|' + to;
 
-	QCString postData = QString( "text=" + body + "&langpair=" + lp ).utf8();
+	QByteArray postData = QString( "text=" + body + "&langpair=" + lp ).toUtf8();
 
 	QString gurl = "http://translate.google.com/translate_t?text=" + body +"&langpair=" + lp;
-	kdDebug(14308) << k_funcinfo << " URL: " << gurl << endl;
-	KURL geturl ( gurl );
+	kDebug(14308) << " URL: " << gurl;
+	KUrl geturl ( gurl );
 
-	KIO::TransferJob *job = KIO::get( geturl, false, true );
-	//job = KIO::http_post( translatorURL, postData, true );
+	KIO::TransferJob *job = KIO::get( geturl );
+	//job = KIO::http_post( translatorURL, postData );
 
 	//job->addMetaData( "content-type", "application/x-www-form-urlencoded" );
 	//job->addMetaData( "referrer", "http://www.google.com" );
 
 	QObject::connect( job, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( slotDataReceived( KIO::Job *, const QByteArray & ) ) );
-	QObject::connect( job, SIGNAL( result( KIO::Job * ) ), this, SLOT( slotJobDone( KIO::Job * ) ) );
+	QObject::connect( job, SIGNAL( result( KJob * ) ), this, SLOT( slotJobDone( KJob * ) ) );
 
 	// KIO is async and we use a sync API, so use the processEvents hack to work around that
 	// FIXME: We need to make the libkopete API async to get rid of this processEvents.
@@ -288,28 +292,30 @@ QString TranslatorPlugin::googleTranslateMessage( const QString &msg, const QStr
 	m_data.remove( job );
 	m_completed.remove( job );
 
-//	kdDebug( 14308 ) << k_funcinfo << "Google response:"<< endl << data << endl;
+//	kDebug( 14308 ) << "Google response:"<< endl << data;
 
-	QRegExp re( "<textarea name=q rows=5 cols=45 wrap=PHYSICAL>(.*)</textarea>" );
+//	QRegExp re( "<textarea name=q rows=5 cols=45 wrap=PHYSICAL>(.*)</textarea>" );
+	QRegExp re( "<textarea name=utrans wrap=PHYSICAL dilr=ltr rows=5 id=suggestion>(.*)</textarea>");
+  
 	re.setMinimal( true );
-	re.search( data );
+	re.indexIn( data );
 
 	return re.cap( 1 );
 }
 
 QString TranslatorPlugin::babelTranslateMessage( const QString &msg, const QString &from, const QString &to )
 {
-	QString body = KURL::encode_string( msg);
-	QString lp = from + "_" + to;
+	QString body = QString(QUrl::toPercentEncoding( msg));
+	QString lp = from + '_' + to;
 	QString gurl = "http://babelfish.altavista.com/babelfish/tr?enc=utf8&doit=done&tt=urltext&urltext=" + body + "&lp=" + lp;
-	KURL geturl ( gurl );
+	KUrl geturl ( gurl );
 
-	kdDebug( 14308 ) << k_funcinfo << "URL: " << gurl << endl;
+	kDebug( 14308 ) << "URL: " << gurl;
 
-	KIO::TransferJob *job = KIO::get( geturl, false, true );
+	KIO::TransferJob *job = KIO::get( geturl );
 
 	QObject::connect( job, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( slotDataReceived( KIO::Job *, const QByteArray & ) ) );
-	QObject::connect( job, SIGNAL( result( KIO::Job * ) ), this, SLOT( slotJobDone( KIO::Job * ) ) );
+	QObject::connect( job, SIGNAL( result( KJob * ) ), this, SLOT( slotJobDone( KJob * ) ) );
 
 	// KIO is async and we use a sync API, so use the processEvents hack to work around that
 	// FIXME: We need to make the libkopete API async to get rid of this processEvents.
@@ -323,11 +329,11 @@ QString TranslatorPlugin::babelTranslateMessage( const QString &msg, const QStri
 	m_data.remove( job );
 	m_completed.remove( job );
 
-	//kdDebug( 14308 ) << k_funcinfo << "Babelfish response: " << endl << data << endl;
+	//kDebug( 14308 ) << "Babelfish response: " << endl << data;
 
-	QRegExp re( "<Div style=padding:10px; lang=..>(.*)</div" );
+	QRegExp re( "<div style=padding:10px;>(.*)</div>" );
 	re.setMinimal( true );
-	re.search( data );
+	re.indexIn( data );
 
 	return re.cap( 1 );
 }
@@ -336,7 +342,7 @@ void TranslatorPlugin::sendTranslation( Kopete::Message &msg, const QString &tra
 {
 	if ( translated.isEmpty() )
 	{
-		kdWarning( 14308 ) << k_funcinfo << "Translated text is empty" << endl;
+		kWarning( 14308 ) << "Translated text is empty";
 		return;
 	}
 
@@ -351,22 +357,31 @@ void TranslatorPlugin::sendTranslation( Kopete::Message &msg, const QString &tra
 		mode = TranslateMode( m_incomingMode );
 		break;
 	default:
-		kdWarning( 14308 ) << k_funcinfo << "Can't determine if it is an incoming or outgoing message" << endl;
+		kWarning( 14308 ) << "Can't determine if it is an incoming or outgoing message";
 	};
 
 	switch ( mode )
 	{
 	case JustTranslate:
-		msg.setBody( translated, msg.format() );
+		if ( msg.format() & Qt::PlainText )
+			msg.setPlainBody( translated );
+		else
+			msg.setHtmlBody ( translated );
 		break;
 	case ShowOriginal:
-		msg.setBody( i18n( "%2\nAuto Translated: %1" ).arg( translated, msg.plainBody() ), msg.format() );
+		if ( msg.format() & Qt::PlainText )
+			msg.setPlainBody( i18n( "%2 \nAuto Translated: \n%1", translated, msg.plainBody() ) );
+		else 
+			msg.setHtmlBody( i18n( "%2 \nAuto Translated: \n%1", translated, msg.plainBody() ) );
 		break;
 	case ShowDialog:
 	{
 		TranslatorDialog *d = new TranslatorDialog( translated );
 		d->exec();
-		msg.setBody( d->translatedText(), msg.format() );
+		if ( msg.format() & Qt::PlainText )
+			msg.setPlainBody (d->translatedText() );
+		else	
+			msg.setHtmlBody( d->translatedText() );
 		delete d;
 		break;
 	}
@@ -379,14 +394,15 @@ void TranslatorPlugin::sendTranslation( Kopete::Message &msg, const QString &tra
 
 void TranslatorPlugin::slotDataReceived ( KIO::Job *job, const QByteArray &data )
 {
-	m_data[ job ] += QCString( data, data.size() + 1 );
+	m_data[ job ] += QByteArray( data, data.size() + 1 );
 }
 
-void TranslatorPlugin::slotJobDone ( KIO::Job *job )
+void TranslatorPlugin::slotJobDone ( KJob *job )
 {
-	m_completed[ job ] = true;
-	QObject::disconnect( job, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( slotDataReceived( KIO::Job *, const QByteArray & ) ) );
-	QObject::disconnect( job, SIGNAL( result( KIO::Job * ) ), this, SLOT( slotJobDone( KIO::Job * ) ) );
+	KIO::Job *kioJob = static_cast<KIO::Job*>(job);
+	m_completed[ kioJob ] = true;
+	QObject::disconnect( kioJob, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( slotDataReceived( KIO::Job *, const QByteArray & ) ) );
+	QObject::disconnect( kioJob, SIGNAL( result( KJob * ) ), this, SLOT( slotJobDone( KJob * ) ) );
 }
 
 void TranslatorPlugin::slotSetLanguage()
