@@ -19,22 +19,20 @@
 
 #include "msnwebcamdialog.h"
 
-#include <qframe.h>
-#include <qobject.h>
-#include <qwidget.h>
 #include <kdebug.h>
 #include <klocale.h>
 
-
-
-MSNWebcamDialog::MSNWebcamDialog( const QString& contact, QWidget * parent, const char * name )
-	: KDialogBase( KDialogBase::Plain, i18n( "Webcam for %1" ).arg( contact ),
-                   KDialogBase::Close, KDialogBase::Close, parent, name, false, true /*seperator*/ ),
+MSNWebcamDialog::MSNWebcamDialog( const QString& contact, QWidget * parent )
+	: KDialog( parent),
 	m_imageContainer( this )
 {
-	setInitialSize( QSize(320,290), true );
-	
-	setEscapeButton( KDialogBase::Close );
+	setInitialSize( QSize(320,290) );
+    setCaption(i18n( "Webcam for %1", contact ));
+	setButtons(KDialog::Close);
+	setDefaultButton(KDialog::Close);
+	setEscapeButton( KDialog::Close );
+	showButtonSeparator(true);
+	setModal(false);
 	/*
 	QObject::connect( contact, SIGNAL( signalReceivedWebcamImage( const QPixmap&  ) ),
 	                  this, SLOT( newImage( const QPixmap& ) ) );
@@ -43,10 +41,11 @@ MSNWebcamDialog::MSNWebcamDialog( const QString& contact, QWidget * parent, cons
 	/*
 	QObject::connect( contact, SIGNAL( webcamClosed( int ) ), this, SLOT( webcamClosed( int ) ) );
 	*/
-	QFrame* page = plainPage();
+	QFrame* page = new Frame(this);
+	setMainWidget(page);
 	if ( page )
 	{
-		kdDebug(14180) << k_funcinfo << "Adding webcam image container" << endl;
+		kDebug(14180) << "Adding webcam image container";
 		//m_imageContainer.setText( i18n( "No webcam image received" ) );
 		//m_imageContainer.setAlignment( Qt::AlignCenter );
 		m_imageContainer.setMinimumSize(320,240);
@@ -61,8 +60,8 @@ MSNWebcamDialog::~ MSNWebcamDialog( )
 
 void MSNWebcamDialog::newImage( const QPixmap & image )
 {
-	kdDebug(14180) << k_funcinfo << "New image received" << endl;
-	//	kdDebug(14180) << image << endl;
+	kDebug(14180) << "New image received";
+	//	kDebug(14180) << image;
 	//m_imageContainer.clear();
 	m_imageContainer.updatePixmap( image );
 	//show();
@@ -70,11 +69,11 @@ void MSNWebcamDialog::newImage( const QPixmap & image )
 
 void MSNWebcamDialog::webcamClosed( int reason  )
 {
-	kdDebug(14180) << k_funcinfo << "webcam closed with reason?? " <<  reason <<endl;
-	//m_imageContainer.clear();
-	//m_imageContainer.setText( i18n( "Webcam closed with reason %1" ).arg( QString::number( reason ) ) );
-	//m_imageContainer.setAlignment( Qt::AlignCenter );
-	//show();
+	kDebug(14180) << "webcam closed with reason?? " <<  reason;
+// 	m_imageContainer.clear();
+// 	m_imageContainer.setText( i18n( "Webcam closed with reason %1", reason ) );
+// 	m_imageContainer.setAlignment( Qt::AlignCenter );
+// 	show();
 }
 
 // kate: indent-mode csands; tab-width 4;
