@@ -1,10 +1,11 @@
 /*
   icqcontact.h  -  ICQ Contact
 
-  Copyright (c) 2003 by Stefan Gehn  <metz AT gehn.net>
-  Copyright (c) 2003 by Olivier Goffart
-  Copyright (c) 2004 by Richard Smith               <kde@metafoo.co.uk>
-  Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>
+  Copyright (c) 2003 by Stefan Gehn  <metz@gehn.net>
+  Copyright (c) 2003 by Olivier Goffart <oggoffart@kde.org>
+  Copyright (c) 2004 by Richard Smith <kde@metafoo.co.uk>
+  Copyright (c) 2006 by Roman Jarosz <kedgedev@centrum.cz>
+  Kopete    (c) 2002-2006 by the Kopete developers  <kopete-devel@kde.org>
 
   *************************************************************************
   *                                                                       *
@@ -19,24 +20,11 @@
 #ifndef ICQCONTACT_H
 #define ICQCONTACT_H
 
-#include "oscarcontact.h"
-#include "userdetails.h"
+#include "icqcontactbase.h"
 
-class OscarEncodingSelectionDialog;
-class KAction;
-class KToggleAction;
-namespace Kopete { class ChatSession; }
-namespace Kopete { class OnlineStatus; }
 class ICQProtocol;
-class ICQAccount;
-class OscarAccount;
-class ICQUserInfo; // user info dialog
-class ICQReadAway;
-
-class ICQGeneralUserInfo;
-class ICQWorkUserInfo;
 class ICQUserInfoWidget;
-class ICQInterestInfoWidget;
+class KToggleAction;
 
 /**
  * Contact for ICQ over Oscar protocol
@@ -44,59 +32,52 @@ class ICQInterestInfoWidget;
  * @author Richard Smith
  * @author Matt Rogers
  */
-class ICQContact : public OscarContact
+class ICQContact : public ICQContactBase
 {
 Q_OBJECT
 
 public:
 
 	/** Normal ICQ constructor */
-	ICQContact( ICQAccount *account, const QString &name, Kopete::MetaContact *parent,
-	            const QString& icon = QString::null, const Oscar::SSI& ssiItem = Oscar::SSI()  );
+	ICQContact( Kopete::Account* account, const QString &name, Kopete::MetaContact *parent,
+	            const QString& icon = QString() );
 	virtual ~ICQContact();
 
 	/**
 	 * Returns a set of custom menu items for
 	 * the context menu
 	 */
-	virtual QPtrList<KAction> *customContextMenuActions();
+	virtual QList<KAction*> *customContextMenuActions();
 
 	/** Return whether or not this contact is reachable. */
 	virtual bool isReachable();
 
+	virtual void setSSIItem( const OContact& ssiItem );
 
-	//virtual const QString awayMessage();
-	//virtual void setAwayMessage(const QString &message);
+	/**  Set encoding for this contact */
+	virtual void setEncoding( int mib );
 
 public slots:
 	virtual void slotUserInfo();
-	virtual void updateSSIItem();
 	void userInfoUpdated( const QString& contact, const UserDetails& details );
 
 	void userOnline( const QString& userId );
 	void userOffline( const QString& userID );
 	void loggedIn();
 
-	void requestShortInfo();
-
 signals:
 	void haveBasicInfo( const ICQGeneralUserInfo& );
 	void haveWorkInfo( const ICQWorkUserInfo& );
 	void haveEmailInfo( const ICQEmailInfo& );
+	void haveNotesInfo( const ICQNotesInfo& );
 	void haveMoreInfo( const ICQMoreUserInfo& );
 	void haveInterestInfo( const ICQInterestInfo& );
+	void haveOrgAffInfo( const ICQOrgAffInfo& );
 
-private:
-	bool cachedBuddyIcon( QByteArray hash );
-	bool m_buddyIconDirty;
-	
-	bool m_requestingNickname;
+private:	
 	ICQProtocol *mProtocol;
 	ICQUserInfoWidget* m_infoWidget;
-	/*
-	ICQReadAway *awayMessageDialog;
-	KAction *actionReadAwayMessage;
-	*/
+
 	KAction *actionRequestAuth;
 	KAction *actionSendAuth;
     KAction *m_selectEncoding;
@@ -105,46 +86,35 @@ private:
 	KToggleAction *m_actionVisibleTo;
 	KToggleAction *m_actionInvisibleTo;
 
-	/*
-	bool mInvisible;
-	*/
-
-    OscarEncodingSelectionDialog* m_oesd;
-
-protected slots:
-	virtual void slotSendMsg(Kopete::Message& message, Kopete::ChatSession *);
-	virtual void updateFeatures();
+	QString m_statusDescription;
+	enum { InfoNone = 0, InfoShort, InfoMediumTlv } m_requestingInfo;
 
 private slots:
+	/** Refresh status from this contact */
+	void refreshStatus( const UserDetails& details, Oscar::Presence presence );
+
 	/** Request authorization from this contact */
 	void slotRequestAuth();
 
 	/** Authorize this contact */
 	void slotSendAuth();
 
-	void slotAuthReplyDialogOkClicked();
-
-	/** We have received an auth request */
-	void slotGotAuthRequest( const QString& contact, const QString& reason );
-
 	/** We have received an auth reply */
 	void slotGotAuthReply( const QString& contact, const QString& reason, bool granted );
 
+	void storeUserInfoDialog();
 	void closeUserInfoDialog();
 
-	void receivedLongInfo( const QString& contact );
+	void requestShortInfo();
 	void receivedShortInfo( const QString& contact );
+	void receivedLongInfo( const QString& contact );
 
-    void changeContactEncoding();
-    void changeEncodingDialogClosed( int );
+	void requestMediumTlvInfo();
+	void receivedTlvInfo( const QString& contact );
 
-	void requestBuddyIcon();
-	void haveIcon( const QString&, QByteArray );
-	void receivedStatusMessage( const QString &contact, const QString &message );
-	void receivedStatusMessage( const Oscar::Message &message );
-
-//void slotCloseAwayMessageDialog();
-	//void slotReadAwayMessage();
+	void requestShortInfoDelayed( int minDelay = 1000 );
+	void requestMediumTlvInfoDelayed( int minDelay = 1000 );
+	void infoDelayTimeout();
 
 	void slotIgnore();
 	void slotVisibleTo();
