@@ -1,7 +1,8 @@
 /*
   oscarprotocol.h  -  Oscar Protocol Plugin
 
-  Copyright (c) 2003 by Olivier Goffart <ogoffart @ kde.org>
+  Copyright (c) 2003 by Olivier Goffart <ogoffart@kde.org>
+
   Kopete    (c) 2003 by the Kopete developers  <kopete-devel@kde.org>
 
   *************************************************************************
@@ -17,30 +18,26 @@
 #ifndef ICQPROTOCOL_H
 #define ICQPROTOCOL_H
 
-#include "kopeteprotocol.h"
+#include "oscarprotocol.h"
 #include "kopetemimetypehandler.h"
-#include "kopeteonlinestatus.h"
 
 class QComboBox;
-/*class ICQUserInfoWidget;
-class ICQContact;*/
-
-namespace ICQ { class OnlineStatusManager; }
+class ICQStatusManager;
 
 class ICQProtocolHandler : public Kopete::MimeTypeHandler
 {
 public:
 	ICQProtocolHandler();
-	void handleURL(const QString &mimeType, const KURL & url) const;
+	void handleURL(const QString &mimeType, const KUrl & url) const;
 };
 
 
-class ICQProtocol : public Kopete::Protocol
+class ICQProtocol : public OscarProtocol
 {
 Q_OBJECT
 
 public:
-	ICQProtocol(QObject *parent, const char *name, const QStringList &args);
+	ICQProtocol(QObject *parent, const QVariantList &args);
 	virtual ~ICQProtocol();
 
 	/**
@@ -50,24 +47,17 @@ public:
 
 	virtual bool canSendOffline() const;
 
-	virtual Kopete::Contact *deserializeContact( Kopete::MetaContact *metaContact,
-	                                             const QMap<QString, QString> &serializedData,
-	                                             const QMap<QString, QString> &addressBookData );
 	AddContactPage *createAddContactWidget(QWidget *parent, Kopete::Account *account);
 	KopeteEditAccountWidget *createEditAccountWidget(Kopete::Account *account, QWidget *parent);
 	Kopete::Account *createNewAccount(const QString &accountId);
 
-	ICQ::OnlineStatusManager *statusManager();
+	OscarStatusManager *statusManager() const;
 
 
-	const Kopete::ContactPropertyTmpl firstName;
-	const Kopete::ContactPropertyTmpl lastName;
-	const Kopete::ContactPropertyTmpl awayMessage;
-	const Kopete::ContactPropertyTmpl emailAddress;
-	const Kopete::ContactPropertyTmpl ipAddress;
-	const Kopete::ContactPropertyTmpl clientFeatures;
-	const Kopete::ContactPropertyTmpl buddyIconHash;
-    const Kopete::ContactPropertyTmpl contactEncoding;
+	const Kopete::PropertyTmpl firstName;
+	const Kopete::PropertyTmpl lastName;
+	const Kopete::PropertyTmpl emailAddress;
+	const Kopete::PropertyTmpl ipAddress;
 
 	const QMap<int, QString> &genders() { return mGenders; }
 	const QMap<int, QString> &countries() { return mCountries; }
@@ -75,6 +65,9 @@ public:
 	const QMap<int, QString> &encodings() { return mEncodings; }
 	const QMap<int, QString> &maritals() { return mMarital; }
 	const QMap<int, QString> &interests() { return mInterests; }
+	const QMap<int, QString> &occupations() { return mOccupations; }
+	const QMap<int, QString> &organizations() { return mOrganizations; }
+	const QMap<int, QString> &affiliations() { return mAffiliations; }
 
 	void fillComboFromTable( QComboBox*, const QMap<int, QString>& );
 	void setComboFromTable( QComboBox*, const QMap<int, QString>&, int );
@@ -90,16 +83,22 @@ private:
 	void initEncodings();
 	void initMaritals();
 	void initInterests();
+	void initOccupations();
+	void initOrganizations();
+	void initAffiliations();
 
 private:
 	static ICQProtocol* protocolStatic_;
-	ICQ::OnlineStatusManager* statusManager_;
+	ICQStatusManager* statusManager_;
 	QMap<int, QString> mGenders;
 	QMap<int, QString> mCountries;
 	QMap<int, QString> mLanguages;
 	QMap<int, QString> mEncodings;
 	QMap<int, QString> mMarital;
 	QMap<int, QString> mInterests;
+	QMap<int, QString> mOccupations;
+	QMap<int, QString> mOrganizations;
+	QMap<int, QString> mAffiliations;
 	ICQProtocolHandler protohandler;
 };
 #endif
