@@ -25,6 +25,8 @@
 
 #include <qobject.h>
 #include <qstring.h>
+#include <QList>
+#include <QByteArray>
 #include "kopete_export.h"
 #include "rtf2html.h"
 #include "transfer.h"
@@ -32,26 +34,40 @@
 #include "userdetails.h"
 #include "oscartypeclasses.h"
 #include "oscarmessage.h"
+#include "contact.h"
 
 class Connection;
 class StageOneLoginTask;
 class StageTwoLoginTask;
-class SSIManager;
+class ContactManager;
 class UserDetails;
 class QString;
 class Task;
+class QTextCodec;
+namespace Kopete
+{
+	class Transfer;
+	class TransferManager;
+}
 
 namespace Oscar
 {
 class Settings;
 }
 
-class KOPETE_EXPORT Client : public QObject
+class LIBOSCAR_EXPORT Client : public QObject
 {
 Q_OBJECT
 
 public:
 
+	class CodecProvider {
+	public:
+		virtual ~CodecProvider() {}
+		virtual QTextCodec* codecForContact( const QString& contactName ) const = 0;
+		virtual QTextCodec* codecForAccount() const = 0;
+	};
+
 	enum ErrorCodes {
 		NoError = 0,
 		NotConnectedError = 1,
@@ -59,8 +75,20 @@ public:
 		FatalProtocolError = 3
 	};
 
-	enum AIMStatus { Online = 0, Away };
-	enum ICQStatus { ICQOnline = 0, ICQAway, ICQNotAvailable, ICQOccupied, ICQDoNotDisturb, ICQFreeForChat };
+	enum ICQStatusFlags {
+		ICQOnline       = 0x00,
+		ICQAway         = 0x01,
+		ICQNotAvailable = 0x02,
+		ICQOccupied     = 0x03,
+		ICQDoNotDisturb = 0x04,
+		ICQFreeForChat  = 0x05,
+
+		ICQXStatus      = 0x10,
+		ICQPluginStatus = 0x20,
+
+		ICQStatusMask   = 0x0F
+	};
+	Q_DECLARE_FLAGS(ICQStatus, ICQStatusFlags)
 
 	/*************
 	  EXTERNAL API
@@ -78,26 +106,34 @@ public:
 	 * Start a connection to the server using the supplied @ref ClientStream.
 	 * This is only a transport layer connection.
 	 * @param s initialised connection object to use for the connection.
-	 * @param server the server to connect to - but this is also set on the connector used to construct the clientstream??
+	 * @param host the host name of server to connect to
+	 * @param port the port of server to connect to
 	 * @param auth indicate whether we're connecting to the authorizer or the bos server
 	 */
-	void connectToServer( Connection *c, const QString& server, bool auth = true );
+	void connectToServer( Connection *c, const QString& host, quint16 port, bool auth = true );
 
 	/**
 	 * Start the login process for Oscar
-	 * @param host - probably could obtain this back from the connector - used for outgoing tasks to determine destination
+	 * @param host Used for outgoing tasks to determine destination
 	 * @param user The user name to log in as.
+	 * @param port The port of server to connect to
 	 * @param pass The password to use when logging in
 	 */
 	void start( const QString &host, const uint port, const QString &userId, const QString &pass );
 
 	/** Logout and disconnect */
 	void close();
-	
-	/** Set our status for AIM */
-	void setStatus( AIMStatus status, const QString &message = QString::null );
-	/** Set our status for ICQ */
- 	void setStatus( DWORD status, const QString &message = QString::null );
+
+	/** Set our status
+	 * \param status the oscar status
+	 * \param message the status message or Xtraz status message
+	 * \param xtraz the Xtraz status
+	 * \param description the Xtraz status description
+	 * @note If you want XStatus you have to set status, message, xtraz and description,
+	 * for ExtStatus (ICQ6 status) you have to set status, message and description, xtraz have to be -1.
+	 * If you want normal status than you should set only status and message.
+	 */
+	void setStatus( Oscar::DWORD status, const QString &message = QString(), int xtraz = -1, const QString &description = QString() );
 
 	/** Retrieve our user info */
 	UserDetails ourInfo() const;
@@ -138,10 +174,10 @@ public:
 	void renameGroup( const QString& oldGroupName, const QString& newGroupName );
 
 	/**
-	 * Modify an SSI item on the SSI list
+	 * Modify an Contact item on the Contact list
 	 * \param item the item to send to the server
 	 */
-	void modifySSIItem( const Oscar::SSI& oldItem, const Oscar::SSI& newItem );
+	void modifyContactItem( const OContact& oldItem, const OContact& newItem );
 
 	/**
 	 * Change a contact's group on the server
@@ -150,6 +186,20 @@ public:
 	 */
 	void changeContactGroup( const QString& contact, const QString& newGroupName );
 
+	/**
+	 * Change a contact's alias on the server
+	 * \param contact the contact to change
+	 * \param alias the new alias
+	 */
+	void changeContactAlias( const QString& contact, const QString& alias );
+
+	/**
+	 * Set privacy settings
+	 * \param privacy the privacy settings
+	 * \param userClasses the bit mask which tells which class of users you want to be visible to
+	 */
+	void setPrivacyTLVs( Oscar::BYTE privacy, Oscar::DWORD userClasses = 0xFFFFFFFF );
+
 	/**
 	 * Send a message to a contact
 	 * \param msg the message to be sent
@@ -172,6 +222,15 @@ public:
 	 */
 	void sendAuth( const QString& contactid, const QString& reason, bool auth=true );
 
+	/**
+	 * Request Short/Medium/Long user info from an ICQ contact (new TLV based format)
+	 * \param contactId the UIN of the contact to get info for
+	 * \param metaInfoId the id of the info (TLV 0x015C in SSI)
+	 */
+	void requestShortTlvInfo( const QString& contactId, const QByteArray &metaInfoId );
+	void requestMediumTlvInfo( const QString& contactId, const QByteArray &metaInfoId );
+	void requestLongTlvInfo( const QString& contactId, const QByteArray &metaInfoId );
+
 	/**
 	 * Request full user info from an ICQ contact
 	 * \param contactId the UIN of the contact to get info for
@@ -191,6 +250,18 @@ public:
 	 */
 	void sendWarning( const QString& contact, bool anonymous );
 
+	/**
+	 * Change ICQ password
+	 * \param password your new password
+	 */
+	bool changeICQPassword( const QString& password );
+
+	/**
+	 * Get the full ICQ info for a client
+	 * \param contact the contact to get info for
+	 */
+	ICQFullInfo getFullInfo( const QString& contact );
+	
 	/**
 	 * Get the general ICQ info for a client
 	 * \param contact the contact to get info for
@@ -209,6 +280,12 @@ public:
 	 */
 	ICQEmailInfo getEmailInfo( const QString& contact );
 
+	/**
+	 * Get the notes info for a contact
+	 * \param contact the contact to get info for
+	 */
+	ICQNotesInfo getNotesInfo( const QString& contact );
+	
 	/**
 	 * Get the additional info available for a contact
 	 * \param contact the contact to get info for
@@ -221,12 +298,23 @@ public:
 	 */
 	ICQInterestInfo getInterestInfo( const QString& contact );
 
+	/**
+	 * Get the organization and affiliation interest info available for a contact
+	 * \param contact the contact to get info for
+	 */
+	ICQOrgAffInfo getOrgAffInfo( const QString& contact );
+
 	/**
 	 * Get the short info available for an icq contact
 	 * \param contact the contact to get info for
 	 */
 	ICQShortInfo getShortInfo( const QString& contact );
 
+    /**
+     * Get the list of chat room exchanges we have
+     */
+    QList<int> chatExchangeList() const;
+
 	/**
 	 * Request the aim profile
 	 * \param contact the contact to get info for
@@ -263,15 +351,27 @@ public:
 	//! Update the user's AIM profile
 	void updateProfile( const QString& profile );
 
+	//! Update the user's ICQ profile
+	bool updateProfile( const QList<ICQInfoBase*>& infoList );
+
 	//! Get buddy icon information for a person
-	void requestBuddyIcon( const QString& user, const QByteArray& hash, BYTE hashType );
+	void requestBuddyIcon( const QString& user, const QByteArray& hash, Oscar::WORD iconType, Oscar::BYTE hashType );
 
 	//! Start a server redirect for a different service
-	void requestServerRedirect( WORD family );
+	void requestServerRedirect( Oscar::WORD family, Oscar::WORD e = 0, QByteArray c = QByteArray(),
+                                Oscar::WORD instance = 0, const QString& room = QString() );
 
 	//! Start uploading a buddy icon
 	void sendBuddyIcon( const QByteArray& imageData );
 
+    void joinChatRoom( const QString& roomName, int exchange );
+
+	void setIgnore( const QString& user, bool ignore );
+	
+	void setVisibleTo( const QString& user, bool visible );
+	
+	void setInvisibleTo( const QString& user, bool invisible );
+	
 	/** Accessors needed for login */
 	QString host();
 	int port();
@@ -284,6 +384,20 @@ public:
 
 	bool hasIconConnection() const;
 
+    /** We've finished chatting in a chat room, disconnect from it */
+    void disconnectChatRoom( Oscar::WORD exchange, const QString& room );
+
+	/** Set codec provider */
+	void setCodecProvider( CodecProvider* codecProvider );
+
+	/** Set pointer to version info */
+	void setVersion( const Oscar::ClientVersion* version );
+
+	/**	Set version capability */
+	void setVersionCap( const QByteArray &cap );
+
+	/** start a filetransfer task */
+	void sendFiles( const QString& contact, const QStringList& files, Kopete::Transfer *t );
 
 	/*************
 	  INTERNAL (FOR USE BY TASKS OR CONNECTIONS) METHODS
@@ -296,8 +410,14 @@ public:
 	/** Have we logged in yet? */
 	bool isActive() const;
 
-	/** Accessor for the SSI Manager */
-	SSIManager* ssiManager() const;
+	/** Accessor for the Contact Manager */
+	ContactManager* ssiManager() const;
+
+	/** Return version info */
+	const Oscar::ClientVersion* version() const;
+
+	/** Return version capability */
+	Guid versionCap() const;
 
 	/** The current user's user ID */
 	QString userId() const;
@@ -305,7 +425,13 @@ public:
 	/** The current user's password */
 	QString password() const;
 
-	/** The current status message (a.k.a. away message) */
+	/** The current Xtraz status */
+	int statusXtraz() const;
+	
+	/** The current Xtraz status description */
+	QString statusDescription() const;
+	
+	/** The current status message (a.k.a. away message or Xtraz message) */
 	QString statusMessage() const;
 
 	/** Change the current status message w/o changing status */
@@ -316,12 +442,12 @@ public:
 	void setIsIcq( bool isIcq );
 
 	/** Host's IP address */
-	QCString ipAddress() const;
+	QByteArray ipAddress() const;
 
 	/** Notify that a task error was received */
 	void notifyTaskError( const Oscar::SNAC& s, int errCode, bool fatal );
 
-	/** Notify that a socket error has occured */
+	/** Notify that a socket error has occurred */
 	void notifySocketError( int errCode, const QString& msg );
 
 signals:
@@ -342,8 +468,8 @@ signals:
 	/** We have our own user info */
 	void haveOwnInfo();
 
-	/** We have our SSI list */
-	void haveSSIList();
+	/** We have our Contact list */
+	void haveContactList();
 
 	/** a user is online. */
 	void userIsOnline( const QString& );
@@ -360,6 +486,9 @@ signals:
 	/** we've received an authorization reply */
 	void authReplyReceived( const QString& contact, const QString& reason, bool auth );
 
+	/** we've received a ICQ password change reply */
+	void icqPasswordChanged( bool error );
+
 	/**
 	 * we've received an error from a task and need to notify somebody
 	 */
@@ -372,14 +501,16 @@ signals:
 
 	void receivedIcqShortInfo( const QString& contact );
 	void receivedIcqLongInfo( const QString& contact );
+	void receivedIcqTlvInfo( const QString& contact );
 
 	void receivedProfile( const QString& contact, const QString& profile );
 	void receivedAwayMessage( const QString& contact, const QString& message );
-	void receivedAwayMessage( const Oscar::Message& message );
+	void receivedXStatusMessage( const QString& contact, int icon, const QString& description, const QString& message );
 	void receivedUserInfo( const QString& contact, const UserDetails& details );
+	void userReadsStatusMessage( const QString& contact );
 
 	/** We warned a user */
-	void userWarned( const QString& contact, Q_UINT16 increase, Q_UINT16 newLevel );
+	void userWarned( const QString& contact, quint16 increase, quint16 newLevel );
 
 	/** Search signals */
 	void gotSearchResults( const ICQSearchResult& );
@@ -396,10 +527,17 @@ signals:
 
 	/* Chat rooms */
 	void chatNavigationConnected();
+    void chatRoomConnected( Oscar::WORD, const QString& );
+    void userJoinedChat( Oscar::WORD, const QString& room, const QString& contact );
+    void userLeftChat( Oscar::WORD, const QString& room, const QString& contact );
 
 	/* service redirection */
-	void redirectionFinished( WORD );
+	void redirectionFinished( Oscar::WORD );
 
+	/** incoming filetransfer */
+	void askIncoming( QString c, QString f, Oscar::DWORD s, QString d, QString i );
+
+	void getTransferManager( Kopete::TransferManager ** );
 
 protected slots:
 	// INTERNAL, FOR USE BY TASKS' finished() SIGNALS //
@@ -427,23 +565,41 @@ protected slots:
 	void receivedIcqInfo( const QString& contact, unsigned int type );
 
 	/** we have normal user info for a contact */
-	void receivedInfo( Q_UINT16 sequence );
+	void receivedInfo( quint16 sequence );
 
 	/** received a message of some kind */
 	void receivedMessage( const Oscar::Message& msg );
 
+	/** filetransfer message needs sending */
+	void fileMessage( const Oscar::Message& msg );
+
+	/** rendezvous message for a filetransfer task */
+	void gotFileMessage( int, const QString, const QByteArray, Buffer );
+
 	void offlineUser( const QString&, const UserDetails& );
 
-	void haveServerForRedirect( const QString& host, const QByteArray& cookie, WORD family );
+	void haveServerForRedirect( const QString& host, const QByteArray& cookie, Oscar::WORD family );
 	void serverRedirectFinished();
-	void checkRedirectionQueue( WORD );
+	void checkRedirectionQueue( Oscar::WORD );
 
 	void requestChatNavLimits();
-
+    /**
+     * Set the list of chat room exchanges we have
+     */
+    void setChatExchangeList( const QList<int>& exchanges );
+    
+    /**
+     * set up the connection to a chat room
+     */
+    void setupChatConnection( Oscar::WORD, QByteArray, Oscar::WORD, const QString& );
+    
     void determineDisconnection( int, const QString& );
 
 	void nextICQAwayMessageRequest();
 
+	/** Change ICQ password finished */
+	void changeICQPasswordFinished();
+
 private:
 
 	/** Initialize some static tasks */
@@ -452,7 +608,7 @@ private:
 	/** Delete the static tasks */
 	void deleteStaticTasks();
 
-	Connection* createConnection( const QString& host, const QString& port );
+	Connection* createConnection();
 
 	/**
 	 * Request the icq away message
@@ -468,6 +624,7 @@ private:
 	StageOneLoginTask* m_loginTask;
 	StageTwoLoginTask* m_loginTaskTwo;
 };
+Q_DECLARE_OPERATORS_FOR_FLAGS(Client::ICQStatus)
 
 #endif
 
