@@ -2,11 +2,12 @@
 	oscarclientstream.cpp - Kopete Oscar Protocol
 	
 	Copyright (c) 2004 Matt Rogers <mattr@kde.org>
+	Copyright (c) 2007 Roman Jarosz <kedgedev@centrum.cz>
 	
 	Based on code Copyright (c) 2004 SuSE Linux AG <http://www.suse.com>
 	Based on Iris, Copyright (C) 2003  Justin Karneges
 	
-	Kopete (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
+	Kopete (c) 2002-2007 by the Kopete developers <kopete-devel@kde.org>
 	
 	*************************************************************************
 	*                                                                       *
@@ -20,102 +21,63 @@
 
 #include "oscarclientstream.h"
 
-#include <qguardedptr.h> 
-#include <qobject.h>
-#include <qptrqueue.h>
-#include <qtimer.h>
+#include <QtCore/QQueue>
+#include <QtCore/QTimer>
+#include <QtNetwork/QHostAddress>
 
 #include <kdebug.h>
 
-#include "bytestream.h"
 #include "connection.h"
-#include "connector.h"
 #include "coreprotocol.h"
-#include "rateclassmanager.h"
 #include "transfer.h"
 
 #define LIBOSCAR_DEBUG 0
 
 void cs_dump( const QByteArray &bytes );
 
-enum {
-	Idle,
-	Connecting,
-	Active,
-	Closing
-};
-
-enum {
-	ClientMode,
-	ServerMode
-};
-
 class ClientStream::Private
 {
 public:
 	Private()
 	{
-		conn = 0;
-		bs = 0;
+		socket = 0;
 		connection = 0;
-		
-		username = QString::null;
-		password = QString::null;
-		server = QString::null;
-		haveLocalAddr = false;
-		doBinding = true;
-
-		reset();
-	}
-	void reset()
-	{
-		state = Idle;
-		notify = 0;
 		newTransfers = false;
 	}
-	
-	QString username;
-	QString password;
-	QString server;
-	bool doAuth; //send the initial login sequences to get the cookie
-	bool haveLocalAddr;
-	QHostAddress localAddr;
-	Q_UINT16 localPort;
-	bool doBinding;
 
-	Connector *conn;
-	ByteStream *bs;
+	QString host;
+	quint16 port;
+
+	QAbstractSocket *socket;
 	CoreProtocol client;
 	Connection* connection;
 
-	QString defRealm;
-
-	int mode;
-	int state;
-	int notify;
 	bool newTransfers;
-	
-	int errCond;
-	QString errText;
 
-	QPtrQueue<Transfer> in;
+	QQueue<Transfer*> in;
 
 	QTimer noopTimer; // used to send icq keepalive
 	int noop_time;
 };
 
-ClientStream::ClientStream(Connector *conn, QObject *parent)
-:Stream(parent)
+ClientStream::ClientStream( QAbstractSocket *socket, QObject *parent )
+: Stream( parent )
 {
-	//qDebug("CLIENTSTREAM::ClientStream");
-
 	d = new Private;
-	d->mode = ClientMode;
-	d->conn = conn;
-	connect( d->conn, SIGNAL(connected()), SLOT(cr_connected()) );
-	connect( d->conn, SIGNAL(error()), SLOT(cr_error()) );
-	connect( &d->client, SIGNAL( outgoingData( const QByteArray& ) ), SLOT ( cp_outgoingData( const QByteArray & ) ) );
-	connect( &d->client, SIGNAL( incomingData() ), SLOT ( cp_incomingData() ) );
+	d->socket = socket;
+
+	connect( d->socket, SIGNAL(connected()), SLOT(socketConnected()) );
+	connect( d->socket, SIGNAL(error(QAbstractSocket::SocketError)), SLOT(socketError(QAbstractSocket::SocketError)) );
+
+	connect(d->socket, SIGNAL(disconnected()), SLOT(socketDisconnected()));
+	connect(d->socket, SIGNAL(readyRead()), SLOT(socketReadyRead()));
+	connect(d->socket, SIGNAL(bytesWritten(qint64)), SLOT(socketBytesWritten(qint64)));
+	
+	
+	connect( &d->client, SIGNAL(outgoingData(const QByteArray&)),
+	         SLOT (cp_outgoingData(const QByteArray & )) );
+	connect( &d->client, SIGNAL(incomingData()),
+	         SLOT (cp_incomingData()) );
 
 	d->noop_time = 0;
 	connect(&d->noopTimer, SIGNAL(timeout()), SLOT(doNoop()));
@@ -123,114 +85,90 @@ ClientStream::ClientStream(Connector *conn, QObject *parent)
 
 ClientStream::~ClientStream()
 {
-	reset();
+	d->noopTimer.stop();
+
+	if ( d->socket->isOpen() )
+	{
+		kDebug(OSCAR_RAW_DEBUG) << "Socket open, disconnecting...";
+		d->socket->disconnectFromHost();
+	
+		if ( !d->socket->waitForDisconnected( 10000 ) )
+		{
+			kDebug(OSCAR_RAW_DEBUG) << "Disconnection error!";
+			d->socket->close();
+		}
+	}
+
+	delete d->socket;
 	delete d;
 }
 
-void ClientStream::reset(bool all)
+void ClientStream::connectToServer( const QString& host, quint16 port )
 {
-	d->reset();
 	d->noopTimer.stop();
-
-	// client
-	if(d->mode == ClientMode)
+	if ( d->socket->isOpen() )
 	{
-		// reset connector
-		if ( d->bs )
+		kDebug(OSCAR_RAW_DEBUG) << "Socket open, disconnecting...";
+		d->socket->disconnectFromHost();
+		
+		if ( !d->socket->waitForDisconnected( 10000 ) )
 		{
-			d->bs->close();
-			d->bs = 0;
+			kDebug(OSCAR_RAW_DEBUG) << "Disconnection error!";
+			d->socket->close();
 		}
-		if ( d->conn )
-			d->conn->done();
-
-		// reset state machine
-		d->client.reset();
 	}
-	if(all)
-		d->in.clear();
+	d->client.reset();
+	d->in.clear();
+	d->newTransfers = false;
+	
+	d->host = host;
+	d->port = port;
+
+	d->socket->connectToHost( d->host, d->port );
 }
 
-void ClientStream::connectToServer(const QString& server, bool auth)
+bool ClientStream::isOpen() const
 {
-	reset(true);
-	d->state = Connecting;
-	d->doAuth = auth;
-	d->server = server;
-
-	d->conn->connectToServer( d->server );
+	return d->socket->isOpen();
 }
 
-void ClientStream::continueAfterWarning()
-{
-/* unneeded?
-	if(d->state == WaitVersion) {
-		d->state = Connecting;
-		processNext();
-	}
-	else if(d->state == WaitTLS) {
-		d->state = Connecting;
-		processNext();
-	}
-*/
-}
-
-void ClientStream::accept()
-{
-
-}
-
-bool ClientStream::isActive() const
-{
-	return (d->state != Idle);
-}
-
-bool ClientStream::isAuthenticated() const
-{
-	return (d->state == Active);
-}
-
-void ClientStream::setNoopTime(int mills)
+void ClientStream::setNoopTime( int mills )
 {
 	d->noop_time = mills;
 
-	if(d->noop_time == 0) {
+	if( d->noop_time == 0 )
+	{
 		d->noopTimer.stop();
 		return;
 	}
 	
-	if( d->state != Active )
+	if( !d->socket->isOpen() )
 		return;
 	
 	d->noopTimer.start( d->noop_time );
 }
 
-void ClientStream::setLocalAddr(const QHostAddress &addr, Q_UINT16 port)
+QHostAddress ClientStream::localAddress() const
 {
-	d->haveLocalAddr = true;
-	d->localAddr = addr;
-	d->localPort = port;
+	return d->socket->localAddress();
 }
 
-int ClientStream::errorCondition() const
+int ClientStream::error() const
 {
-	return d->errCond;
+	return d->socket->error();
 }
 
-QString ClientStream::errorText() const
+QString ClientStream::errorString() const
 {
-	return d->errText;
+	return d->socket->errorString();
 }
 
 void ClientStream::close()
 {
-	if(d->state == Active) {
-		d->state = Closing;
-//		d->client.shutdown();
+	if( d->socket->isOpen() )
+	{
 		processNext();
-	}
-	else if(d->state != Idle && d->state != Closing) {
-		reset();
+		d->socket->disconnectFromHost();
 	}
 }
 
@@ -244,7 +182,6 @@ Connection* ClientStream::connection() const
 	return d->connection;
 }
 
-
 bool ClientStream::transfersAvailable() const
 {
 	return ( !d->in.isEmpty() );
@@ -252,7 +189,7 @@ bool ClientStream::transfersAvailable() const
 
 Transfer* ClientStream::read()
 {
-	if(d->in.isEmpty())
+	if( d->in.isEmpty() )
 		return 0; //first from queue...
 	else 
 		return d->in.dequeue();
@@ -308,7 +245,7 @@ void cs_dump( const QByteArray &bytes )
 void ClientStream::cp_outgoingData( const QByteArray& outgoingBytes )
 {
 	// take formatted bytes from CoreProtocol and put them on the wire
-	d->bs->write( outgoingBytes );
+	d->socket->write( outgoingBytes );
 }
 
 void ClientStream::cp_incomingData()
@@ -321,84 +258,70 @@ void ClientStream::cp_incomingData()
 		doReadyRead();
 	}
 	else
-		kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << 
+		kDebug(OSCAR_RAW_DEBUG) << 
 			"client signalled incomingData but none was available, state is: " <<
 			d->client.state() << endl;
 }
 
-void ClientStream::cr_connected()
-{
-	d->bs = d->conn->stream();
-	connect(d->bs, SIGNAL(connectionClosed()), SLOT(bs_connectionClosed()));
-	connect(d->bs, SIGNAL(delayedCloseFinished()), SLOT(bs_delayedCloseFinished()));
-	connect(d->bs, SIGNAL(readyRead()), SLOT(bs_readyRead()));
-	connect(d->bs, SIGNAL(bytesWritten(int)), SLOT(bs_bytesWritten(int)));
-	connect(d->bs, SIGNAL(error(int)), SLOT(bs_error(int)));
 
-	d->state = Active;
+void ClientStream::socketConnected()
+{
+	kDebug(OSCAR_RAW_DEBUG) ;
+
 	if ( d->noop_time )
 		d->noopTimer.start( d->noop_time );
 
-	QByteArray spare = d->bs->read();
-
-	QGuardedPtr<QObject> self = this;
 	emit connected();
-	if(!self)
-		return;
 }
 
-void ClientStream::cr_error()
+void ClientStream::socketDisconnected()
 {
-	kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << endl;
-	reset();
-	emit error(ErrConnection);
+	kDebug(OSCAR_RAW_DEBUG) ;
+
+	d->noopTimer.stop();
+	d->client.reset();
+	emit disconnected();
 }
 
-void ClientStream::bs_connectionClosed()	
+void ClientStream::socketError( QAbstractSocket::SocketError socketError )
 {
-	reset();
-	emit connectionClosed();
+	kDebug(OSCAR_RAW_DEBUG) << " error: " << int(socketError);
+
+	d->noopTimer.stop();
+
+	if ( socketError == QAbstractSocket::RemoteHostClosedError )
+		d->socket->abort();
+	else
+		d->socket->close();
+
+	d->client.reset();
+
+	emit Stream::error( socketError );
 }
 
-void ClientStream::bs_delayedCloseFinished()
+void ClientStream::socketReadyRead()
 {
-	// we don't care about this (we track all important data ourself)
-}
-
-void ClientStream::bs_error(int)
-{
-	// TODO
-}
-
-void ClientStream::bs_readyRead()
-{
-	QByteArray a;
-	//qDebug( "size of storage for incoming data is %i bytes.", a.size() );
-	a = d->bs->read();
+	QByteArray buffer = d->socket->readAll();
 
 #if LIBOSCAR_DEBUG
-	QCString cs(a.data(), a.size()+1);
-	kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "recv: " << a.size() << "bytes" << endl;
-	cs_dump( a );
+	QByteArray cs(buffer.data(), buffer.size()+1);
+	kDebug(OSCAR_RAW_DEBUG) << "recv: " << buffer.size() << "bytes";
+	cs_dump( buffer );
 #endif
 
-	d->client.addIncomingData(a);
+	d->client.addIncomingData( buffer );
 }
 
-void ClientStream::bs_bytesWritten(int bytes)
+void ClientStream::socketBytesWritten( qint64 bytes )
 {
 #if LIBOSCAR_DEBUG
- 	kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << bytes << " bytes written" << endl;
+ 	kDebug(OSCAR_RAW_DEBUG) << bytes << " bytes written";
 	Q_UNUSED( bytes );
 #else
 	Q_UNUSED( bytes );
 #endif
 }
 
-void ClientStream::srvProcessNext()
-{
-}
-
 void ClientStream::doReadyRead()
 {
 	emit readyRead();
@@ -412,14 +335,9 @@ void ClientStream::processNext()
 	}
 }
 
-bool ClientStream::handleNeed()
-{
-	return false;
-}
-
 void ClientStream::doNoop()
 {
-	if ( d->state != Active )
+	if ( !d->socket->isOpen() )
 		return;
 	
 	FLAP f = { 0x05, d->connection->flapSequence(), 0 };
@@ -428,10 +346,6 @@ void ClientStream::doNoop()
 	write( t );
 }
 
-void ClientStream::handleError()
-{
-}
-
 #include "oscarclientstream.moc"
 
 //kate: tab-width 4; indent-mode csands;
