@@ -1,5 +1,5 @@
 /*  *************************************************************************
-    *   copyright: (C) 2003 Richard Lrkng <nouseforaname@home.se>         *
+    *   copyright: (C) 2003 Richard Lärkäng <nouseforaname@home.se>         *
     *   copyright: (C) 2003 Gav Wood <gav@kde.org>                          *
     *************************************************************************
 */
@@ -20,13 +20,12 @@
 #include "smsservice.h"
 #include "kopetemessage.h"
 
-#include <qobject.h>
-#include <qstringlist.h>
+#include <QStringList>
+
 
 class SMSClientPrefsUI;
-class SMSContact;
-class QListViewItem;
-class KProcess;
+class QGridLayout;
+class K3Process;
 
 class SMSClient : public SMSService
 {
@@ -45,8 +44,8 @@ public slots:
 	void savePreferences();
 
 private slots:
-	void slotReceivedOutput(KProcess*, char  *buffer, int  buflen);
-	void slotSendFinished(KProcess* p);
+	void slotReceivedOutput(K3Process*, char  *buffer, int  buflen);
+	void slotSendFinished(K3Process* p);
 signals:
 	void messageSent(const Kopete::Message &);
 
