@@ -1,5 +1,5 @@
 /*  *************************************************************************
-    *   copyright: (C) 2003 Richard Lrkng <nouseforaname@home.se>         *
+    *   copyright: (C) 2003 Richard Lärkäng <nouseforaname@home.se>         *
     *************************************************************************
 */
 
@@ -21,13 +21,12 @@
 #include <qlabel.h>
 
 class smsAddUI;
-class SMSProtocol;
 
 class SMSAddContactPage : public AddContactPage
 {
    Q_OBJECT
 public:
-	SMSAddContactPage(QWidget *parent=0, const char *name=0);
+	SMSAddContactPage(QWidget *parent=0);
 	~SMSAddContactPage();
 	smsAddUI *smsdata;
 	virtual bool validateData();
