@@ -1,5 +1,5 @@
 /*  *************************************************************************
-    *   copyright: (C) 2003 Richard Lrkng <nouseforaname@home.se>         *
+    *   copyright: (C) 2003 Richard Lärkäng <nouseforaname@home.se>         *
     *   copyright: (C) 2003 Gav Wood <gav@kde.org>                          *
     *************************************************************************
 */
@@ -20,6 +20,7 @@
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <kactioncollection.h>
 
 #include "kopetechatsessionmanager.h"
 #include "kopeteaccount.h"
@@ -35,7 +36,7 @@ SMSContact::SMSContact( Kopete::Account* _account, const QString &phoneNumber,
 	const QString &displayName, Kopete::MetaContact *parent )
 : Kopete::Contact( _account, phoneNumber, parent ), m_phoneNumber( phoneNumber )
 {
-//	kdWarning( 14160 ) << k_funcinfo << " this = " << this << ", phone = " << phoneNumber << endl;
+//	kWarning( 14160 ) << " this = " << this << ", phone = " << phoneNumber;
 	setNickName( displayName );
 
 	m_msgManager = 0L;
@@ -53,7 +54,7 @@ void SMSContact::slotSendingSuccess(const Kopete::Message &msg)
 
 void SMSContact::slotSendingFailure(const Kopete::Message &/*msg*/, const QString &error)
 {
-	KMessageBox::detailedError(Kopete::UI::Global::mainWidget(), i18n("Something went wrong when sending message."), error,
+	KMessageBox::detailedError(Kopete::UI::Global::mainWidget(), i18n("Something went wrong while sending the message."), error,
 			i18n("Could Not Send Message"));
 //	manager()->messageFailed();
 	// TODO: swap for failed as above. show it anyway for now to allow closing of window.
@@ -76,7 +77,7 @@ Kopete::ChatSession* SMSContact::manager( Kopete::Contact::CanCreateFlags canCre
 	}
 	else
 	{
-		QPtrList<Kopete::Contact> contacts;
+		QList<Kopete::Contact*> contacts;
 		contacts.append(this);
 		m_msgManager = Kopete::ChatSessionManager::self()->create(account()->myself(), contacts, protocol());
 		connect(m_msgManager, SIGNAL(messageSent(Kopete::Message&, Kopete::ChatSession*)),
@@ -119,13 +120,26 @@ void SMSContact::setPhoneNumber( const QString phoneNumber )
 	new SMSContact(account(), phoneNumber, nickName(), metaContact());
 }
 
-QPtrList<KAction>* SMSContact::customContextMenuActions()
+KActionCollection* SMSContact::customContextMenuActions(QWidget *parent)
 {
-	QPtrList<KAction> *m_actionCollection = new QPtrList<KAction>();
-	if( !m_actionPrefs )
-		m_actionPrefs = new KAction(i18n("&Contact Settings"), 0, this, SLOT(userPrefs()), this, "userPrefs");
+	KActionCollection *m_actionCollection = new KActionCollection(parent);
 
-	m_actionCollection->append( m_actionPrefs );
+	if( !m_actionPrefs )
+	{
+		m_actionPrefs = new KAction(i18n("&Contact Settings"),
+					    m_actionCollection );
+
+//       dynamic_cast<QObject*>(this),
+//          SLOT(userPrefs()),
+//          dynamic_cast<QObject*>(this),
+//          "userPrefs");
+		QObject::connect(m_actionPrefs,
+				 SIGNAL(triggered(bool)),
+				 dynamic_cast<QObject*>(this),
+				 SLOT(userPrefs()));
+	}
+
+	m_actionCollection->addAction("userPrefs", m_actionPrefs);
 
 	return m_actionCollection;
 }
