@@ -1,5 +1,5 @@
 /*  *************************************************************************
-    *   copyright: (C) 2003 Richard Lrkng <nouseforaname@home.se>         *
+    *   copyright: (C) 2003 Richard Lärkäng <nouseforaname@home.se>         *
     *   copyright: (C) 2003 Gav Wood <gav@kde.org>                          *
     *************************************************************************
 */
@@ -27,19 +27,20 @@
 #include "smsaddcontactpage.h"
 #include "smsaccount.h"
 
-typedef KGenericFactory<SMSProtocol> SMSProtocolFactory;
-K_EXPORT_COMPONENT_FACTORY( kopete_sms, SMSProtocolFactory( "kopete_sms" )  )
+K_PLUGIN_FACTORY( SMSProtocolFactory, registerPlugin<SMSProtocol>(); )
+K_EXPORT_PLUGIN( SMSProtocolFactory( "kopete_sms" ) )
 
 SMSProtocol* SMSProtocol::s_protocol = 0L;
 
-SMSProtocol::SMSProtocol(QObject *parent, const char *name, const QStringList &/*args*/)
-: Kopete::Protocol( SMSProtocolFactory::instance(), parent, name ),
-	SMSOnline(  Kopete::OnlineStatus::Online,  25, this, 0,  QString::null,   i18n( "Online" ), i18n( "Online" ), Kopete::OnlineStatusManager::Online ),
-	SMSConnecting( Kopete::OnlineStatus::Connecting,2, this, 3, QString::null,    i18n( "Connecting" ) ),
-	SMSOffline( Kopete::OnlineStatus::Offline, 0, this, 2,  QString::null,   i18n( "Offline" ), i18n( "Offline" ), Kopete::OnlineStatusManager::Offline )
+SMSProtocol::SMSProtocol(QObject *parent, const QVariantList &)
+: Kopete::Protocol( SMSProtocolFactory::componentData(), parent ),
+	SMSOnline(  Kopete::OnlineStatus::Online,  25, this, 0,  QStringList(),   i18n( "Online" ), i18n( "Online" ), Kopete::OnlineStatusManager::Online ),
+	SMSOffline( Kopete::OnlineStatus::Offline, 0, this, 2,  QStringList(),   i18n( "Offline" ), i18n( "Offline" ), Kopete::OnlineStatusManager::Offline ),
+	SMSConnecting( Kopete::OnlineStatus::Connecting,2, this, 3, QStringList(),    i18n( "Connecting" ) )
+	
 {
 	if (s_protocol)
-		kdWarning( 14160 ) << k_funcinfo << "s_protocol already defined!" << endl;
+		kWarning( 14160 ) << "s_protocol already defined!";
 	else
 		s_protocol = this;
 
@@ -51,8 +52,9 @@ SMSProtocol::~SMSProtocol()
 	s_protocol = 0L;
 }
 
-AddContactPage *SMSProtocol::createAddContactWidget(QWidget *parent, Kopete::Account */*i*/)
+AddContactPage *SMSProtocol::createAddContactWidget(QWidget *parent, Kopete::Account *i)
 {
+	Q_UNUSED( i );
 	return new SMSAddContactPage(parent);
 }
 
@@ -74,12 +76,22 @@ Kopete::Contact *SMSProtocol::deserializeContact(Kopete::MetaContact *metaContac
 	QString accountId = serializedData["accountId"];
 	QString displayName = serializedData["displayName"];
 
-	QDict<Kopete::Account> accounts=Kopete::AccountManager::self()->accounts(this);
+	QList<Kopete::Account*> accounts=Kopete::AccountManager::self()->accounts(this);
+
+   QList<Kopete::Account*>::iterator curacct, lastacct = accounts.end();
+	Kopete::Account *account = (Kopete::Account*) NULL;
+
+   for (curacct = accounts.begin(); curacct != lastacct; curacct++) {
+      Kopete::Account *one = static_cast<Kopete::Account*>(*curacct);
+      if (one->accountId() == accountId) {
+         account = one;
+         break;
+      }
+   }
 
-	Kopete::Account *account = accounts[accountId];
 	if (!account)
 	{
-		kdDebug(14160) << "Account doesn't exist, skipping" << endl;
+		kDebug(14160) << "Account doesn't exist, skipping";
 		return 0;
 	}
 
