@@ -19,6 +19,8 @@
  ***************************************************************************/
 // QT Includes
 #include <qlayout.h>
+//Added by qt3to4:
+#include <QVBoxLayout>
 
 // KDE Includes
 #include <kcombobox.h>
@@ -32,19 +34,23 @@
 #include <addcontactpage.h>
 
 // Local Includes
-#include "wpaddcontactbase.h"
+#include "ui_wpaddcontactbase.h"
 #include "wpaccount.h"
 #include "wpaddcontact.h"
 
-WPAddContact::WPAddContact(QWidget *parent, WPAccount *newAccount, const char *name) : AddContactPage(parent, name)
+WPAddContact::WPAddContact(QWidget *parent, WPAccount *newAccount) : AddContactPage(parent)
 {
-//	kdDebug(14170) << "WPAddContact::WPAddContact(<owner>, " << newAccount << ", <parent>, " << name << ")" << endl;
+//	kDebug(14170) << "WPAddContact::WPAddContact(<owner>, " << newAccount << ", <parent>, " << name << ")";
+
+	QVBoxLayout *topLayout = new QVBoxLayout( this );
+	QWidget* w = new QWidget( this );
+	topLayout->addWidget( w );
+	theDialog = new Ui::WPAddContactBase();
+	theDialog->setupUi( w );
 
-	(new QVBoxLayout(this))->setAutoAdd(true);
-	theDialog = new WPAddContactBase(this);
 	connect(theDialog->mHostGroup, SIGNAL(activated(const QString &)), this, SLOT(slotSelected(const QString &)));
 	connect(theDialog->mRefresh, SIGNAL(clicked()), this, SLOT(slotUpdateGroups()));
-	theDialog->show();
+	w->show();
 
 	theAccount = newAccount;
 
@@ -54,35 +60,36 @@ WPAddContact::WPAddContact(QWidget *parent, WPAccount *newAccount, const char *n
 
 WPAddContact::~WPAddContact()
 {
+	delete theDialog;
 }
 
 void WPAddContact::slotUpdateGroups()
 {
-	kdDebug(14170) << "WPAddContact::slotUpdateGroups()" << endl;
+	kDebug(14170) << "WPAddContact::slotUpdateGroups()";
 
 	theDialog->mHostGroup->clear();
 	QStringList Groups = theAccount->getGroups();
 	QStringList::ConstIterator end = Groups.end();
 	for (QStringList::ConstIterator i = Groups.begin(); i != end; i++)
-		theDialog->mHostGroup->insertItem(SmallIcon("network"), *i);
+		theDialog->mHostGroup->addItem( QIcon(SmallIcon("network-wired")), *i);
 	slotSelected(theDialog->mHostGroup->currentText());
 }
 
 void WPAddContact::slotSelected(const QString &Group)
 {
-	kdDebug(14170) << "WPAddContact::slotSelected(" << Group << ")" << endl;
+	kDebug(14170) << "WPAddContact::slotSelected(" << Group << ")";
 
 	theDialog->mHostName->clear();
 	QStringList Hosts = theAccount->getHosts(Group);
 	QString ownHost = theAccount->myself()->contactId();
 	QStringList::ConstIterator end = Hosts.end();
 	for (QStringList::ConstIterator i = Hosts.begin(); i != end; i++)
-		if (*i != ownHost) theDialog->mHostName->insertItem(SmallIcon("personal"), *i);
+		if (*i != ownHost) theDialog->mHostName->addItem( QIcon(SmallIcon("user-identity")), *i);
 }
 
 bool WPAddContact::validateData()
 {
-	kdDebug(14170) << "WPAddContact::validateData()" << endl;
+	kDebug(14170) << "WPAddContact::validateData()";
 
 	QString tmpHostName = theDialog->mHostName->currentText();
 
@@ -93,8 +100,8 @@ bool WPAddContact::validateData()
 
 	// If our own host is not allowed as contact localhost should be forbidden as well,
 	// additionally somehow localhost as contact crashes when receiving a message from it?? GF
-	if (tmpHostName.upper() == QString::fromLatin1("LOCALHOST")) {
-		KMessageBox::sorry(this, i18n("<qt>LOCALHOST is not allowed as contact.</qt>"), i18n("WinPopup"));
+	if (tmpHostName.toUpper() == QString::fromLatin1("LOCALHOST")) {
+		KMessageBox::sorry(this, i18n("<qt>LOCALHOST is not allowed as a contact.</qt>"), i18n("WinPopup"));
 		return false;
 	}
 
@@ -103,7 +110,7 @@ bool WPAddContact::validateData()
 
 bool WPAddContact::apply(Kopete::Account *theAccount, Kopete::MetaContact *theMetaContact)
 {
-	kdDebug(14170) << "WPAddContact::apply(" << theAccount << ", " << theMetaContact << ")" << endl;
+	kDebug(14170) << "WPAddContact::apply(" << theAccount << ", " << theMetaContact << ")";
 
 	// TODO: make the nickname an option
 	return theAccount->addContact(theDialog->mHostName->currentText(), theMetaContact, Kopete::Account::ChangeKABC );
