@@ -27,13 +27,13 @@
 
 // KDE Includes
 #include <kdebug.h>
+#include <kdefakes.h> // gethostname
 #include <klocale.h>
 #include <kurlrequester.h>
 #include <knuminput.h>
 #include <klineedit.h>
 #include <kmessagebox.h>
 #include <kconfig.h>
-#include <kapplication.h>
 #include <kstandarddirs.h>
 
 
@@ -46,9 +46,10 @@
 #include "wpprotocol.h"
 
 WPEditAccount::WPEditAccount(QWidget *parent, Kopete::Account *theAccount)
-	: WPEditAccountBase(parent), KopeteEditAccountWidget(theAccount)
+	: QWidget(parent), KopeteEditAccountWidget(theAccount)
 {
-	kdDebug(14170) << "WPEditAccount::WPEditAccount(<parent>, <theAccount>)";
+	setupUi(this);
+	kDebug(14170) << "WPEditAccount::WPEditAccount(<parent>, <theAccount>)";
 
 	mProtocol = WPProtocol::protocol();
 
@@ -58,21 +59,21 @@ WPEditAccount::WPEditAccount(QWidget *parent, Kopete::Account *theAccount)
 		mHostName->setText(account()->accountId());
 //		mAutoConnect->setChecked(account()->excludeConnect());
 		mHostName->setReadOnly(true);
-		KGlobal::config()->setGroup("WinPopup");
-		mHostCheckFreq->setValue(KGlobal::config()->readNumEntry("HostCheckFreq", 60));
-		mSmbcPath->setURL(KGlobal::config()->readEntry("SmbcPath", tmpSmbcPath));
+		KConfigGroup group = KGlobal::config()->group("WinPopup");
+		mHostCheckFreq->setValue(group.readEntry("HostCheckFreq", 60));
+		mSmbcPath->setUrl(group.readEntry("SmbcPath", tmpSmbcPath));
 
 	}
 	else {
 		// no QT/KDE function? GF
-		QString theHostName = QString::null;
+		QString theHostName = QString();
 		char *tmp = new char[255];
 
 		if (tmp != 0) {
 			gethostname(tmp, 255);
 			theHostName = tmp;
-			if (theHostName.contains('.') != 0) theHostName.remove(theHostName.find('.'), theHostName.length());
-			theHostName = theHostName.upper();
+			if (theHostName.contains('.') != 0) theHostName.remove(theHostName.indexOf('.'), theHostName.length());
+			theHostName = theHostName.toUpper();
 		}
 
 		if (!theHostName.isEmpty())
@@ -81,7 +82,7 @@ WPEditAccount::WPEditAccount(QWidget *parent, Kopete::Account *theAccount)
 			mHostName->setText("LOCALHOST");
 
 		mHostCheckFreq->setValue(60);
-		mSmbcPath->setURL(tmpSmbcPath);
+		mSmbcPath->setUrl(tmpSmbcPath);
 	}
 
 	show();
@@ -94,14 +95,14 @@ void WPEditAccount::installSamba()
 
 bool WPEditAccount::validateData()
 {
-	kdDebug(14170) << "WPEditAccount::validateData()";
+	kDebug(14170) << "WPEditAccount::validateData()";
 
 	if(mHostName->text().isEmpty()) {
 		KMessageBox::sorry(this, i18n("<qt>You must enter a valid screen name.</qt>"), i18n("WinPopup"));
 		return false;
 	}
 
-	QFile smbc(mSmbcPath->url());
+	QFile smbc(mSmbcPath->url().path());
 	if (!smbc.exists()) {
 		KMessageBox::sorry(this, i18n("<qt>You must enter a valid smbclient path.</qt>"), i18n("WinPopup"));
 		return false;
@@ -112,14 +113,14 @@ bool WPEditAccount::validateData()
 
 void WPEditAccount::writeConfig()
 {
-	KGlobal::config()->setGroup("WinPopup");
-	KGlobal::config()->writeEntry("SmbcPath", mSmbcPath->url());
-	KGlobal::config()->writeEntry("HostCheckFreq", mHostCheckFreq->text());
+	KConfigGroup group = KGlobal::config()->group("WinPopup");
+	group.writeEntry("SmbcPath", mSmbcPath->url().path());
+	group.writeEntry("HostCheckFreq", mHostCheckFreq->text());
 }
 
 Kopete::Account *WPEditAccount::apply()
 {
-	kdDebug(14170) << "WPEditAccount::apply()";
+	kDebug(14170) << "WPEditAccount::apply()";
 
 	if(!account())
 		setAccount(new WPAccount(mProtocol, mHostName->text()));
