@@ -23,20 +23,22 @@
 
 /* Kopete Includes */
 #include "kopetecontact.h"
+//Added by qt3to4:
+#include <QPixmap>
+#include <QList>
+#include <kurl.h>
 
 class KAction;
-class KTempFile;
+class KTemporaryFile;
 
 namespace Kopete { class ChatSession; }
 namespace Kopete { class MetaContact; }
 namespace Kopete { class OnlineStatus; }
 namespace Kopete { class Message; }
-class YahooProtocol;
 class YahooAccount;
 class YahooWebcamDialog;
 class YahooChatSession;
-class YABEntry;
-struct KURL;
+struct YABEntry;
 
 class YahooContact : public Kopete::Contact
 {
@@ -48,7 +50,7 @@ public:
 	/** Base Class Reimplementations **/
 	virtual bool isOnline() const;
 	virtual bool isReachable();
-	virtual QPtrList<KAction> *customContextMenuActions();
+	virtual QList<KAction*> *customContextMenuActions();
 	virtual Kopete::ChatSession *manager( Kopete::Contact::CanCreateFlags canCreate= Kopete::Contact::CanCreate );
 	virtual void serialize( QMap<QString, QString> &serializedData, QMap<QString, QString> &addressBookData );
 
@@ -75,18 +77,15 @@ public:
 
 public slots:
 	virtual void slotUserInfo();
-	virtual void slotSendFile( const KURL &file );
+	virtual void slotSendFile( const KUrl &file );
 	virtual void deleteContact();
-	virtual void sendFile( const KURL &sourceURL = KURL(), const QString &fileName = QString::null, uint fileSize = 0L );
+	virtual void sendFile( const KUrl &sourceURL = KUrl(), const QString &fileName = QString(), uint fileSize = 0L );
 	void slotUserProfile();
 	void stealthContact();
 	void requestWebcam();
 	void inviteWebcam();
 	void buzzContact();
-	void setDisplayPicture(KTempFile *f, int checksum);
-	void sendBuddyIconInfo( const QString &url, int checksum );
-	void sendBuddyIconUpdate( int type );
-	void sendBuddyIconChecksum( int checksum );
+	void setDisplayPicture(KTemporaryFile *f, int checksum);
 	void setYABEntry( YABEntry *, bool show = false );
 
 	/**
@@ -107,7 +106,6 @@ private slots:
 	void slotChatSessionDestroyed();
 	void slotSendMessage( Kopete::Message& );
 	void slotTyping( bool );
-	void slotEmitDisplayPictureChanged();
 
 	void closeWebcamDialog();
 	void initWebcamViewer();
